@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,7 +21,6 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
 #include <string.h>
 
 #include "config.h"
@@ -31,42 +31,60 @@
 static void
 load_callback (void *callback_data, char *element, char *key, char *value)
 {
-  _LW6CFG_CONTEXT *context;
+  _lw6cfg_context_t *cfg_context;
 
-  context = (_LW6CFG_CONTEXT *) callback_data;
+  cfg_context = (_lw6cfg_context_t *) callback_data;
 
-  if (!strcmp (element, "option"))
+  if (lw6cfg_must_be_saved (key))
     {
-      lw6sys_assoc_set (&(context->options), key, lw6sys_str_copy (value));
+      lw6sys_assoc_set (&(cfg_context->options), key,
+			lw6sys_str_copy (value));
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("option \"%s\" not loaded"), key);
     }
 }
 
 int
-_lw6cfg_load (_LW6CFG_CONTEXT * context, char *filename)
+_lw6cfg_load (_lw6cfg_context_t * cfg_context, char *filename)
 {
   int ret = 0;
 
+  lw6sys_log (LW6SYS_LOG_INFO, _("loading config from \"%s\""), filename);
+
   if (lw6sys_file_exists (filename))
     {
-      lw6sys_log (LW6SYS_LOG_INFO, "cfg", _("loading config from \"%s\""),
-		  filename);
-
-
       ret =
 	lw6cfg_read_key_value_xml_file (filename, load_callback,
-					(void *) context);
+					(void *) cfg_context);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_INFO, "cfg", _("ignoring config file \"%s\""),
+      lw6sys_log (LW6SYS_LOG_INFO,
+		  _("config file \"%s\" doesn't exist, using defaults"),
 		  filename);
     }
 
+  _lw6cfg_parse_command_line (cfg_context);
+
   return ret;
 }
 
+/**
+ * lw6cfg_load
+ *
+ * @cfg_context: a context returned by @lw6cfg_init
+ * @filename: a file path, absolute or relative
+ *
+ * Loads the given config file, and stores its values into the current 
+ * context. Parameters which are both in the config file and given
+ * as command line parameters, will be taken from the command-line.
+ *
+ * Return value: 1 if successfull, 0 if error.
+ */
 int
-lw6cfg_load (void *context, char *filename)
+lw6cfg_load (void *cfg_context, char *filename)
 {
-  return _lw6cfg_load ((_LW6CFG_CONTEXT *) context, filename);
+  return _lw6cfg_load ((_lw6cfg_context_t *) cfg_context, filename);
 }
