@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,24 +20,22 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
-
 #include "config.h"
 #include "gfx.h"
 
 static void
 warning (char *func_name)
 {
-  lw6sys_log (LW6SYS_LOG_WARNING, "gfx",
+  lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("gfx backend function \"%s\" is not defined"), func_name);
 }
 
 void
-lw6gfx_display_background (LW6GFX_BACKEND * backend, char *skin)
+lw6gfx_display_background (lw6gfx_backend_t * backend, lw6gui_look_t * look)
 {
   if (backend->display_background)
     {
-      backend->display_background (backend->gfx_context, skin);
+      backend->display_background (backend->gfx_context, look);
     }
   else
     {
@@ -46,52 +44,38 @@ lw6gfx_display_background (LW6GFX_BACKEND * backend, char *skin)
 }
 
 void
-lw6gfx_display_hud (LW6GFX_BACKEND * backend, LW6KER_GAME_STATE * game_state,
-		    LW6GFX_HUD_STEP step, char *skin)
+lw6gfx_display_hud (lw6gfx_backend_t * backend, lw6gui_look_t * look,
+		    lw6ker_game_state_t * game_state)
 {
   if (backend->display_hud)
     {
-      backend->display_hud (backend->gfx_context, game_state, step, skin);
+      backend->display_hud (backend->gfx_context, look, game_state);
     }
   else
     {
-      warning ("display_hud");
-    }
-}
-
-void
-lw6gfx_display_hud_preview (LW6GFX_BACKEND * backend, LW6GFX_HUD_STEP step,
-			    char *skin)
-{
-  if (backend->display_hud_preview)
-    {
-      backend->display_hud_preview (backend->gfx_context, step, skin);
-    }
-  else
-    {
-      warning ("display_hud_preview");
+      warning ("display_hud_fg");
     }
 }
 
 int
-lw6gfx_poll_keypress (LW6GFX_BACKEND * backend, LW6GFX_KEYPRESS * keypress)
+lw6gfx_poll_key (lw6gfx_backend_t * backend, lw6gui_keypress_t * keypress)
 {
   int ret = 0;
 
-  if (backend->poll_keypress)
+  if (backend->poll_key)
     {
-      ret = backend->poll_keypress (backend->gfx_context, keypress);
+      ret = backend->poll_key (backend->gfx_context, keypress);
     }
   else
     {
-      warning ("poll_keypress");
+      warning ("poll_key");
     }
 
   return ret;
 }
 
 int
-lw6gfx_is_key_esc (LW6GFX_BACKEND * backend, int keysym)
+lw6gfx_is_key_esc (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
@@ -108,75 +92,7 @@ lw6gfx_is_key_esc (LW6GFX_BACKEND * backend, int keysym)
 }
 
 int
-lw6gfx_is_key_up (LW6GFX_BACKEND * backend, int keysym)
-{
-  int ret = 0;
-
-  if (backend->is_key_up)
-    {
-      ret = backend->is_key_up (backend->gfx_context, keysym);
-    }
-  else
-    {
-      warning ("is_key_up");
-    }
-
-  return ret;
-}
-
-int
-lw6gfx_is_key_down (LW6GFX_BACKEND * backend, int keysym)
-{
-  int ret = 0;
-
-  if (backend->is_key_down)
-    {
-      ret = backend->is_key_down (backend->gfx_context, keysym);
-    }
-  else
-    {
-      warning ("is_key_down");
-    }
-
-  return ret;
-}
-
-int
-lw6gfx_is_key_left (LW6GFX_BACKEND * backend, int keysym)
-{
-  int ret = 0;
-
-  if (backend->is_key_left)
-    {
-      ret = backend->is_key_left (backend->gfx_context, keysym);
-    }
-  else
-    {
-      warning ("is_key_left");
-    }
-
-  return ret;
-}
-
-int
-lw6gfx_is_key_right (LW6GFX_BACKEND * backend, int keysym)
-{
-  int ret = 0;
-
-  if (backend->is_key_right)
-    {
-      ret = backend->is_key_right (backend->gfx_context, keysym);
-    }
-  else
-    {
-      warning ("is_key_right");
-    }
-
-  return ret;
-}
-
-int
-lw6gfx_is_key_enter (LW6GFX_BACKEND * backend, int keysym)
+lw6gfx_is_key_enter (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
@@ -193,75 +109,75 @@ lw6gfx_is_key_enter (LW6GFX_BACKEND * backend, int keysym)
 }
 
 int
-lw6gfx_is_key_del (LW6GFX_BACKEND * backend, int keysym)
+lw6gfx_is_key_up (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  if (backend->is_key_del)
+  if (backend->is_key_up)
     {
-      ret = backend->is_key_del (backend->gfx_context, keysym);
+      ret = backend->is_key_up (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_del");
+      warning ("is_key_up");
     }
 
   return ret;
 }
 
 int
-lw6gfx_is_key_backspace (LW6GFX_BACKEND * backend, int keysym)
+lw6gfx_is_key_down (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  if (backend->is_key_backspace)
+  if (backend->is_key_down)
     {
-      ret = backend->is_key_backspace (backend->gfx_context, keysym);
+      ret = backend->is_key_down (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_backspace");
+      warning ("is_key_down");
     }
 
   return ret;
 }
 
 int
-lw6gfx_is_key_help (LW6GFX_BACKEND * backend, int keysym)
+lw6gfx_is_key_left (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  if (backend->is_key_help)
+  if (backend->is_key_left)
     {
-      ret = backend->is_key_help (backend->gfx_context, keysym);
+      ret = backend->is_key_left (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_help");
+      warning ("is_key_left");
     }
 
   return ret;
 }
 
 int
-lw6gfx_is_key_quit (LW6GFX_BACKEND * backend, int keysym)
+lw6gfx_is_key_right (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  if (backend->is_key_quit)
+  if (backend->is_key_right)
     {
-      ret = backend->is_key_quit (backend->gfx_context, keysym);
+      ret = backend->is_key_right (backend->gfx_context, keysym);
     }
   else
     {
-      warning ("is_key_quit");
+      warning ("is_key_right");
     }
 
   return ret;
 }
 
 int
-lw6gfx_poll_quit (LW6GFX_BACKEND * backend)
+lw6gfx_poll_quit (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
@@ -278,7 +194,7 @@ lw6gfx_poll_quit (LW6GFX_BACKEND * backend)
 }
 
 void
-lw6gfx_send_quit (LW6GFX_BACKEND * backend)
+lw6gfx_send_quit (lw6gfx_backend_t * backend)
 {
   if (backend->send_quit)
     {
@@ -291,7 +207,7 @@ lw6gfx_send_quit (LW6GFX_BACKEND * backend)
 }
 
 int
-lw6gfx_get_key_state (LW6GFX_BACKEND * backend, int keysym)
+lw6gfx_get_key_state (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
@@ -308,11 +224,11 @@ lw6gfx_get_key_state (LW6GFX_BACKEND * backend, int keysym)
 }
 
 int
-lw6gfx_poll_mouse_move (LW6GFX_BACKEND * backend, int *x, int *y)
+lw6gfx_poll_mouse_move (lw6gfx_backend_t * backend, int *x, int *y)
 {
   int ret = 0;
 
-  if (backend->poll_mouse_button)
+  if (backend->poll_mouse_move)
     {
       ret = backend->poll_mouse_move (backend->gfx_context, x, y);
     }
@@ -325,24 +241,75 @@ lw6gfx_poll_mouse_move (LW6GFX_BACKEND * backend, int *x, int *y)
 }
 
 int
-lw6gfx_poll_mouse_button (LW6GFX_BACKEND * backend, int button)
+lw6gfx_poll_mouse_button_left (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
-  if (backend->poll_mouse_button)
+  if (backend->poll_mouse_button_left)
     {
-      ret = backend->poll_mouse_button (backend->gfx_context, button);
+      ret = backend->poll_mouse_button_left (backend->gfx_context);
     }
   else
     {
-      warning ("poll_mouse_button");
+      warning ("poll_mouse_button_left");
+    }
+
+  return ret;
+}
+
+int
+lw6gfx_poll_mouse_button_right (lw6gfx_backend_t * backend)
+{
+  int ret = 0;
+
+  if (backend->poll_mouse_button_right)
+    {
+      ret = backend->poll_mouse_button_right (backend->gfx_context);
+    }
+  else
+    {
+      warning ("poll_mouse_button_right");
+    }
+
+  return ret;
+}
+
+int
+lw6gfx_poll_mouse_wheel_up (lw6gfx_backend_t * backend)
+{
+  int ret = 0;
+
+  if (backend->poll_mouse_wheel_up)
+    {
+      ret = backend->poll_mouse_wheel_up (backend->gfx_context);
+    }
+  else
+    {
+      warning ("poll_mouse_wheel_up");
+    }
+
+  return ret;
+}
+
+int
+lw6gfx_poll_mouse_wheel_down (lw6gfx_backend_t * backend)
+{
+  int ret = 0;
+
+  if (backend->poll_mouse_wheel_down)
+    {
+      ret = backend->poll_mouse_wheel_down (backend->gfx_context);
+    }
+  else
+    {
+      warning ("poll_mouse_wheel_down");
     }
 
   return ret;
 }
 
 void
-lw6gfx_get_mouse_state (LW6GFX_BACKEND * backend, int *x, int *y,
+lw6gfx_get_mouse_state (lw6gfx_backend_t * backend, int *x, int *y,
 			int *button_left, int *button_right)
 {
   if (backend->get_mouse_state)
@@ -356,26 +323,130 @@ lw6gfx_get_mouse_state (LW6GFX_BACKEND * backend, int *x, int *y,
     }
 }
 
-void
-lw6gfx_display_sysinfo (LW6GFX_BACKEND * backend, int fps, int rps,
-			int bytes_in, int bytes_out)
+int
+lw6gfx_poll_joystick_up (lw6gfx_backend_t * backend, int i)
 {
-  if (backend->display_sysinfo)
+  int ret = 0;
+
+  if (backend->poll_joystick_up)
     {
-      backend->display_sysinfo (backend->gfx_context, fps, rps, bytes_in,
-				bytes_out);
+      ret = backend->poll_joystick_up (backend->gfx_context, i);
     }
   else
     {
-      warning ("display_sysinfo");
+      warning ("poll_joystick_up");
+    }
+
+  return ret;
+}
+
+int
+lw6gfx_poll_joystick_down (lw6gfx_backend_t * backend, int i)
+{
+  int ret = 0;
+
+  if (backend->poll_joystick_down)
+    {
+      ret = backend->poll_joystick_down (backend->gfx_context, i);
+    }
+  else
+    {
+      warning ("poll_joystick_down");
+    }
+
+  return ret;
+}
+
+int
+lw6gfx_poll_joystick_left (lw6gfx_backend_t * backend, int i)
+{
+  int ret = 0;
+
+  if (backend->poll_joystick_left)
+    {
+      ret = backend->poll_joystick_left (backend->gfx_context, i);
+    }
+  else
+    {
+      warning ("poll_joystick_left");
+    }
+
+  return ret;
+}
+
+int
+lw6gfx_poll_joystick_right (lw6gfx_backend_t * backend, int i)
+{
+  int ret = 0;
+
+  if (backend->poll_joystick_right)
+    {
+      ret = backend->poll_joystick_right (backend->gfx_context, i);
+    }
+  else
+    {
+      warning ("poll_joystick_right");
+    }
+
+  return ret;
+}
+
+int
+lw6gfx_poll_joystick_button_a (lw6gfx_backend_t * backend, int i)
+{
+  int ret = 0;
+
+  if (backend->poll_joystick_button_a)
+    {
+      ret = backend->poll_joystick_button_a (backend->gfx_context, i);
+    }
+  else
+    {
+      warning ("poll_joystick_button_a");
+    }
+
+  return ret;
+}
+
+int
+lw6gfx_poll_joystick_button_b (lw6gfx_backend_t * backend, int i)
+{
+  int ret = 0;
+
+  if (backend->poll_joystick_button_b)
+    {
+      ret = backend->poll_joystick_button_b (backend->gfx_context, i);
+    }
+  else
+    {
+      warning ("poll_joystick_button_b");
+    }
+
+  return ret;
+}
+
+void
+lw6gfx_get_joystick_state (lw6gfx_backend_t * backend, int *x, int *y,
+			   int *button_a, int *button_b, int i)
+{
+  if (backend->get_joystick_state)
+    {
+      backend->get_joystick_state (backend->gfx_context, x, y, button_a,
+				   button_b, i);
+    }
+  else
+    {
+      warning ("get_joystick_state");
     }
 }
+
 void
-lw6gfx_display_log (LW6GFX_BACKEND * backend, char **log)
+lw6gfx_display_log (lw6gfx_backend_t * backend, lw6gui_look_t * look,
+		    char **log_list)
 {
   if (backend->display_log)
     {
-      backend->display_log (backend->gfx_context, log);
+      backend->display_log (backend->gfx_context, look, log_list);
     }
   else
     {
@@ -383,37 +454,24 @@ lw6gfx_display_log (LW6GFX_BACKEND * backend, char **log)
     }
 }
 void
-lw6gfx_display_time (LW6GFX_BACKEND * backend, long long seconds)
+lw6gfx_display_fps (lw6gfx_backend_t * backend, lw6gui_look_t * look, int fps)
 {
-  if (backend->display_time)
+  if (backend->display_fps)
     {
-      backend->display_time (backend->gfx_context, seconds);
+      backend->display_fps (backend->gfx_context, look, fps);
     }
   else
     {
-      warning ("display_time");
+      warning ("display_fps");
     }
 }
 void
-lw6gfx_display_version (LW6GFX_BACKEND * backend)
-{
-  if (backend->display_version)
-    {
-      backend->display_version (backend->gfx_context);
-    }
-  else
-    {
-      warning ("display_version");
-    }
-}
-
-void
-lw6gfx_display_map_preview (LW6GFX_BACKEND * backend, LW6MAP_MAP * map,
-			    char *skin)
+lw6gfx_display_map_preview (lw6gfx_backend_t * backend, lw6gui_look_t * look,
+			    lw6map_level_t * level)
 {
   if (backend->display_map_preview)
     {
-      backend->display_map_preview (backend->gfx_context, map, skin);
+      backend->display_map_preview (backend->gfx_context, look, level);
     }
   else
     {
@@ -422,14 +480,12 @@ lw6gfx_display_map_preview (LW6GFX_BACKEND * backend, LW6MAP_MAP * map,
 }
 
 void
-lw6gfx_display_map_zones (LW6GFX_BACKEND * backend,
-			  LW6MAP_MAP * map,
-			  LW6KER_MAP_STRUCT * map_struct, char *skin)
+lw6gfx_display_map_zones (lw6gfx_backend_t * backend, lw6gui_look_t * look,
+			  lw6ker_game_struct_t * game_struct)
 {
   if (backend->display_map_zones)
     {
-      backend->display_map_zones (backend->gfx_context, map, map_struct,
-				  skin);
+      backend->display_map_zones (backend->gfx_context, look, game_struct);
     }
   else
     {
@@ -438,15 +494,13 @@ lw6gfx_display_map_zones (LW6GFX_BACKEND * backend,
 }
 
 void
-lw6gfx_display_map_gradient (LW6GFX_BACKEND * backend,
-			     LW6MAP_MAP * map,
-			     LW6KER_MAP_STATE * map_state, int team_id,
-			     char *skin)
+lw6gfx_display_map_gradient (lw6gfx_backend_t * backend, lw6gui_look_t * look,
+			     lw6ker_game_state_t * game_state, int team_id)
 {
   if (backend->display_map_gradient)
     {
-      backend->display_map_gradient (backend->gfx_context, map, map_state,
-				     team_id, skin);
+      backend->display_map_gradient (backend->gfx_context, look, game_state,
+				     team_id);
     }
   else
     {
@@ -455,14 +509,12 @@ lw6gfx_display_map_gradient (LW6GFX_BACKEND * backend,
 }
 
 void
-lw6gfx_display_game (LW6GFX_BACKEND * backend, LW6MAP_MAP * map,
-		     LW6KER_GAME_STATE * game_state,
-		     LW6GFX_GAME_LOOK * game_look, char *skin)
+lw6gfx_display_game (lw6gfx_backend_t * backend,
+		     lw6gui_look_t * look, lw6ker_game_state_t * game_state)
 {
   if (backend->display_game)
     {
-      backend->display_game (backend->gfx_context, map, game_state, game_look,
-			     skin);
+      backend->display_game (backend->gfx_context, look, game_state);
     }
   else
     {
@@ -471,14 +523,15 @@ lw6gfx_display_game (LW6GFX_BACKEND * backend, LW6MAP_MAP * map,
 }
 
 void
-lw6gfx_pick_map_coord (LW6GFX_BACKEND * backend, int *map_x, int *map_y,
-		       LW6MAP_MAP * map, LW6KER_GAME_STATE * game_state,
-		       int screen_x, int screen_y, char *skin)
+lw6gfx_pick_map_coord (lw6gfx_backend_t * backend, lw6gui_look_t * look,
+		       int *map_x, int *map_y,
+		       lw6ker_game_state_t * game_state, int screen_x,
+		       int screen_y)
 {
   if (backend->pick_map_coord)
     {
-      backend->pick_map_coord (backend->gfx_context, map_x, map_y, map,
-			       game_state, screen_x, screen_y, skin);
+      backend->pick_map_coord (backend->gfx_context, look, map_x, map_y,
+			       game_state, screen_x, screen_y);
     }
   else
     {
@@ -487,11 +540,12 @@ lw6gfx_pick_map_coord (LW6GFX_BACKEND * backend, int *map_x, int *map_y,
 }
 
 void
-lw6gfx_display_menu (LW6GFX_BACKEND * backend, LW6GFX_MENU * menu, char *skin)
+lw6gfx_display_menu (lw6gfx_backend_t * backend, lw6gui_look_t * look,
+		     lw6gui_menu_t * menu)
 {
   if (backend->display_menu)
     {
-      backend->display_menu (backend->gfx_context, menu, skin);
+      backend->display_menu (backend->gfx_context, look, menu);
     }
   else
     {
@@ -499,32 +553,48 @@ lw6gfx_display_menu (LW6GFX_BACKEND * backend, LW6GFX_MENU * menu, char *skin)
     }
 }
 
-int
-lw6gfx_pick_menuitem (LW6GFX_BACKEND * backend, LW6GFX_MENU * menu,
-		      int screen_x, int screen_y, char *skin)
+void
+lw6gfx_pick_menuitem (lw6gfx_backend_t * backend, lw6gui_look_t * look,
+		      int *position, int *scroll, lw6gui_menu_t * menu,
+		      int screen_x, int screen_y)
 {
-  int ret = 0;
-
   if (backend->pick_menuitem)
     {
-      ret =
-	backend->pick_menuitem (backend->gfx_context, menu, screen_x,
-				screen_y, skin);
+      backend->pick_menuitem (backend->gfx_context, look, position, scroll,
+			      menu, screen_x, screen_y);
     }
   else
     {
       warning ("pick_menuitem");
     }
+}
+
+int
+lw6gfx_warp_mouse_on_menuitem (lw6gfx_backend_t * backend,
+			       lw6gui_look_t * look, lw6gui_menu_t * menu,
+			       int position)
+{
+  int ret = 0;
+
+  if (backend->warp_mouse_on_menuitem)
+    {
+      ret = backend->warp_mouse_on_menuitem (backend->gfx_context, look, menu,
+					     position);
+    }
+  else
+    {
+      warning ("warp_mouse_on_menuitem");
+    }
 
   return ret;
 }
 
 void
-lw6gfx_prepare_buffer (LW6GFX_BACKEND * backend)
+lw6gfx_prepare_buffer (lw6gfx_backend_t * backend, lw6gui_look_t * look)
 {
   if (backend->prepare_buffer)
     {
-      backend->prepare_buffer (backend->gfx_context);
+      backend->prepare_buffer (backend->gfx_context, look);
     }
   else
     {
@@ -532,7 +602,7 @@ lw6gfx_prepare_buffer (LW6GFX_BACKEND * backend)
     }
 }
 void
-lw6gfx_swap_buffers (LW6GFX_BACKEND * backend)
+lw6gfx_swap_buffers (lw6gfx_backend_t * backend)
 {
   if (backend->swap_buffers)
     {
@@ -544,7 +614,7 @@ lw6gfx_swap_buffers (LW6GFX_BACKEND * backend)
     }
 }
 int
-lw6gfx_init (LW6GFX_BACKEND * backend, int width,
+lw6gfx_init (lw6gfx_backend_t * backend, int width,
 	     int height, int fullscreen,
 	     void (*resize_callback) (int width, int height, int fullscreen),
 	     int ticks)
@@ -552,7 +622,8 @@ lw6gfx_init (LW6GFX_BACKEND * backend, int width,
   if (backend->init)
     {
       backend->gfx_context =
-	backend->init (width, height, fullscreen, resize_callback, ticks);
+	backend->init (backend->argc, backend->argv, width, height,
+		       fullscreen, resize_callback, ticks);
     }
   else
     {
@@ -563,7 +634,7 @@ lw6gfx_init (LW6GFX_BACKEND * backend, int width,
 }
 
 int
-lw6gfx_set_video_mode (LW6GFX_BACKEND * backend, int width, int height,
+lw6gfx_set_video_mode (lw6gfx_backend_t * backend, int width, int height,
 		       int fullscreen, void (*resize_callback) (int width,
 								int height,
 								int
@@ -585,8 +656,28 @@ lw6gfx_set_video_mode (LW6GFX_BACKEND * backend, int width, int height,
   return ret;
 }
 
+int
+lw6gfx_get_video_mode (lw6gfx_backend_t * backend, int *width, int *height,
+		       int *fullscreen)
+{
+  int ret = 0;
+
+  if (backend->get_video_mode)
+    {
+      ret =
+	backend->get_video_mode (backend->gfx_context, width, height,
+				 fullscreen);
+    }
+  else
+    {
+      warning ("get_video_mode");
+    }
+
+  return ret;
+}
+
 void
-lw6gfx_quit (LW6GFX_BACKEND * backend)
+lw6gfx_quit (lw6gfx_backend_t * backend)
 {
   if (backend->quit)
     {
@@ -599,7 +690,7 @@ lw6gfx_quit (LW6GFX_BACKEND * backend)
     }
 }
 void
-lw6gfx_delay (LW6GFX_BACKEND * backend, int ms)
+lw6gfx_delay (lw6gfx_backend_t * backend, int ms)
 {
   if (backend->delay)
     {
@@ -611,7 +702,7 @@ lw6gfx_delay (LW6GFX_BACKEND * backend, int ms)
     }
 }
 int
-lw6gfx_get_ticks (LW6GFX_BACKEND * backend)
+lw6gfx_get_ticks (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
