@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,21 +21,19 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
-
 #include "config.h"
 #include "gfx.h"
 
-LW6SYS_ASSOC *
-lw6gfx_get_backends ()
+lw6sys_assoc_t *
+lw6gfx_get_backends (int argc, char *argv[])
 {
-  LW6SYS_ASSOC *ret = NULL;
+  lw6sys_assoc_t *ret = NULL;
   char *path;
 
   ret = lw6sys_assoc_new (NULL);
   if (ret)
     {
-      path = lw6dyn_path_find_backend ("gfx", "gl");
+      path = lw6dyn_path_find_backend (argc, argv, "gfx", "gl");
       if (path)
 	{
 	  lw6sys_assoc_set (&ret, "gl", (void *) _("SDL/OpenGL"));
@@ -45,18 +44,18 @@ lw6gfx_get_backends ()
   return ret;
 }
 
-LW6GFX_BACKEND *
-lw6gfx_create_backend (char *name)
+lw6gfx_backend_t *
+lw6gfx_create_backend (int argc, char *argv[], char *name)
 {
-  LW6GFX_BACKEND *backend = NULL;
-  LW6DYN_DL_HANDLE *backend_handle = NULL;
+  lw6gfx_backend_t *backend = NULL;
+  lw6dyn_dl_handle_t *backend_handle = NULL;
 
-  backend_handle = lw6dyn_dlopen_backend ("gfx", name);
+  backend_handle = lw6dyn_dlopen_backend (argc, argv, "gfx", name);
 
   if (backend_handle)
     {
       char *init_func_name;
-      LW6GFX_BACKEND *(*init_func) ();
+      lw6gfx_backend_t *(*init_func) ();
 
       init_func_name = lw6sys_new_sprintf ("mod_%s_create_backend", name);
       if (init_func_name)
@@ -68,9 +67,9 @@ lw6gfx_create_backend (char *name)
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, "gfx",
+	      lw6sys_log (LW6SYS_LOG_WARNING,
 			  _
-			  ("unable to find function \"%s\" in sound backend \"%s\""),
+			  ("unable to find function \"%s\" in gfx backend \"%s\""),
 			  init_func_name, name);
 	    }
 
@@ -82,18 +81,20 @@ lw6gfx_create_backend (char *name)
   if (backend && backend_handle)
     {
       backend->dl_handle = backend_handle;
+      backend->argc = argc;
+      backend->argv = argv;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx",
-		  _("unable to open sound backend \"%s\""), name);
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to open gfx backend \"%s\""), name);
     }
 
   return backend;
 }
 
 void
-lw6gfx_destroy_backend (LW6GFX_BACKEND * backend)
+lw6gfx_destroy_backend (lw6gfx_backend_t * backend)
 {
   lw6dyn_dlclose_backend (backend->dl_handle);
   LW6SYS_FREE (backend);
