@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,13 +26,13 @@
 static void
 warning (char *func_name)
 {
-  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+  lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("background backend function \"%s\" is not defined"));
 }
 
 int
-mod_gl_background_init (MOD_GL_UTILS_CONTEXT * utils_context,
-			MOD_GL_BACKGROUND_BACKEND * backend)
+mod_gl_background_init (mod_gl_utils_context_t * utils_context,
+			mod_gl_background_backend_t * backend)
 {
   if (backend->init)
     {
@@ -47,8 +47,8 @@ mod_gl_background_init (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_background_quit (MOD_GL_UTILS_CONTEXT * utils_context,
-			MOD_GL_BACKGROUND_BACKEND * backend)
+mod_gl_background_quit (mod_gl_utils_context_t * utils_context,
+			mod_gl_background_backend_t * backend)
 {
   if (backend->quit)
     {
@@ -61,12 +61,13 @@ mod_gl_background_quit (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_background_display (MOD_GL_UTILS_CONTEXT * utils_context,
-			   MOD_GL_BACKGROUND_BACKEND * backend)
+mod_gl_background_display (mod_gl_utils_context_t * utils_context,
+			   mod_gl_background_backend_t * backend,
+			   lw6gui_look_t * look)
 {
   if (backend->display)
     {
-      backend->display (utils_context, backend->background_context);
+      backend->display (utils_context, backend->background_context, look);
     }
   else
     {
