@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,38 +26,28 @@
 #include "config.h"
 #include "../mod-gl.h"
 
-#include "gl-air/gl-air.h"
-#include "gl-earth/gl-earth.h"
-#include "gl-fire/gl-fire.h"
-#include "gl-water/gl-water.h"
+#include "gl-bubbles/gl-bubbles.h"
+#include "gl-void/gl-void.h"
 
-MOD_GL_BACKGROUND_BACKEND *
-mod_gl_background_create_backend (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_background_backend_t *
+mod_gl_background_create_backend (mod_gl_utils_context_t * utils_context,
 				  char *name)
 {
-  MOD_GL_BACKGROUND_BACKEND *(*init_func) (MOD_GL_UTILS_CONTEXT *
-					   utils_context) = NULL;
-  MOD_GL_BACKGROUND_BACKEND *backend = NULL;
+  mod_gl_background_backend_t *(*init_func) (mod_gl_utils_context_t *
+					     utils_context) = NULL;
+  mod_gl_background_backend_t *backend = NULL;
 
-  if (strcmp (name, "air") == 0)
+  if (strcmp (name, "bubbles") == 0)
     {
-      init_func = mod_gl_background_air_create_backend;
+      init_func = mod_gl_background_bubbles_create_backend;
     }
-  else if (strcmp (name, "earth") == 0)
+  else if (strcmp (name, "void") == 0)
     {
-      init_func = mod_gl_background_earth_create_backend;
-    }
-  else if (strcmp (name, "fire") == 0)
-    {
-      init_func = mod_gl_background_fire_create_backend;
-    }
-  else if (strcmp (name, "water") == 0)
-    {
-      init_func = mod_gl_background_water_create_backend;
+      init_func = mod_gl_background_void_create_backend;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("background backend \"%s\" does not exists"), name);
     }
 
@@ -73,8 +64,8 @@ mod_gl_background_create_backend (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_background_destroy_backend (MOD_GL_UTILS_CONTEXT * utils_context,
-				   MOD_GL_BACKGROUND_BACKEND * backend)
+mod_gl_background_destroy_backend (mod_gl_utils_context_t * utils_context,
+				   mod_gl_background_backend_t * backend)
 {
   if (backend)
     {
