@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,9 +22,7 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-
 #include <GL/glu.h>
 #include <SDL/SDL_image.h>
 
@@ -33,14 +32,14 @@
 #include "gl-floating.h"
 #include "gl-floating-internal.h"
 
-#define CONST_FILE "gfx/gl/hud/floating/const.xml"
+#define CONST_FILE "hud/floating/gl-floating-const.xml"
 
 static void
 read_callback (void *callback_data, char *element, char *key, char *value)
 {
-  _MOD_GL_HUD_FLOATING_CONST_DATA *const_data;
+  _mod_gl_hud_floating_const_data_t *const_data;
 
-  const_data = (_MOD_GL_HUD_FLOATING_CONST_DATA *) callback_data;
+  const_data = (_mod_gl_hud_floating_const_data_t *) callback_data;
 
   if (!strcmp (element, "float"))
     {
@@ -52,18 +51,17 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 }
 
 static int
-load_consts (MOD_GL_UTILS_CONTEXT * utils_context,
-	     _MOD_GL_HUD_FLOATING_CONTEXT * floating_context)
+load_consts (mod_gl_utils_context_t * utils_context,
+	     _mod_gl_hud_floating_context_t * floating_context)
 {
   int ret = 0;
   char *const_file = NULL;
 
-  const_file = lw6sys_find_data_file (CONST_FILE);
+  const_file = lw6sys_path_concat (utils_context->path.data_dir, CONST_FILE);
 
   if (const_file)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("reading \"%s\""),
-		  const_file);
+      lw6sys_log (LW6SYS_LOG_INFO, _("reading \"%s\""), const_file);
 
       ret =
 	lw6cfg_read_key_value_xml_file (const_file, read_callback,
@@ -82,27 +80,27 @@ load_consts (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 static void
-unload_consts (MOD_GL_UTILS_CONTEXT * utils_context,
-	       _MOD_GL_HUD_FLOATING_CONTEXT * floating_context)
+unload_consts (mod_gl_utils_context_t * utils_context,
+	       _mod_gl_hud_floating_context_t * floating_context)
 {
   memset (&floating_context->const_data, 0,
-	  sizeof (_MOD_GL_HUD_FLOATING_CONST_DATA));
+	  sizeof (_mod_gl_hud_floating_const_data_t));
 }
 
 /*
  * Putting all the load/unload functions together
  */
 int
-_mod_gl_hud_floating_load_data (MOD_GL_UTILS_CONTEXT * utils_context,
-				_MOD_GL_HUD_FLOATING_CONTEXT *
+_mod_gl_hud_floating_load_data (mod_gl_utils_context_t * utils_context,
+				_mod_gl_hud_floating_context_t *
 				floating_context)
 {
   return load_consts (utils_context, floating_context);
 }
 
 void
-_mod_gl_hud_floating_unload_data (MOD_GL_UTILS_CONTEXT * utils_context,
-				  _MOD_GL_HUD_FLOATING_CONTEXT *
+_mod_gl_hud_floating_unload_data (mod_gl_utils_context_t * utils_context,
+				  _mod_gl_hud_floating_context_t *
 				  floating_context)
 {
   unload_consts (utils_context, floating_context);
