@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,13 +27,13 @@
 static void
 warning (char *func_name)
 {
-  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+  lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("hud backend function \"%s\" is not defined"));
 }
 
 int
-mod_gl_hud_init (MOD_GL_UTILS_CONTEXT * utils_context,
-		 MOD_GL_HUD_BACKEND * backend)
+mod_gl_hud_init (mod_gl_utils_context_t * utils_context,
+		 mod_gl_hud_backend_t * backend)
 {
   if (backend->init)
     {
@@ -47,8 +48,8 @@ mod_gl_hud_init (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_hud_quit (MOD_GL_UTILS_CONTEXT * utils_context,
-		 MOD_GL_HUD_BACKEND * backend)
+mod_gl_hud_quit (mod_gl_utils_context_t * utils_context,
+		 mod_gl_hud_backend_t * backend)
 {
   if (backend->quit)
     {
@@ -61,32 +62,17 @@ mod_gl_hud_quit (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_hud_display (MOD_GL_UTILS_CONTEXT * utils_context,
-		    MOD_GL_HUD_BACKEND * backend,
-		    LW6KER_GAME_STATE * game_state, LW6GFX_HUD_STEP step)
+mod_gl_hud_display (mod_gl_utils_context_t * utils_context,
+		    mod_gl_hud_backend_t * backend,
+		    lw6gui_look_t * look, lw6ker_game_state_t * game_state)
 {
   if (backend->display)
     {
-      backend->display (utils_context, backend->hud_context, game_state,
-			step);
+      backend->display (utils_context, backend->hud_context, look,
+			game_state);
     }
   else
     {
       warning ("hud_display");
     }
 }
-
-void
-mod_gl_hud_display_preview (MOD_GL_UTILS_CONTEXT * utils_context,
-			    MOD_GL_HUD_BACKEND * backend,
-			    LW6GFX_HUD_STEP step)
-{
-  if (backend->display_preview)
-    {
-      backend->display_preview (utils_context, backend->hud_context, step);
-    }
-  else
-    {
-      warning ("hud_display_preview");
-    }
-}
