@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,9 +22,7 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-
 #include <GL/glu.h>
 #include <SDL/SDL_image.h>
 
@@ -33,18 +32,18 @@
 #include "gl-tactical.h"
 #include "gl-tactical-internal.h"
 
-#define CONST_FILE "gfx/gl/hud/tactical/const.xml"
+#define CONST_FILE "hud/tactical/const.xml"
 
-#define IMAGE_DIR "gfx/gl/hud/tactical/image/"
+#define IMAGE_DIR "hud/tactical/image/"
 
 #define IMAGE_FRAME "frame.png"
 
 static void
 read_callback (void *callback_data, char *element, char *key, char *value)
 {
-  _MOD_GL_HUD_TACTICAL_CONST_DATA *const_data;
+  _mod_gl_hud_tactical_const_data_t *const_data;
 
-  const_data = (_MOD_GL_HUD_TACTICAL_CONST_DATA *) callback_data;
+  const_data = (_mod_gl_hud_tactical_const_data_t *) callback_data;
 
   if (!strcmp (element, "float"))
     {
@@ -60,18 +59,17 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 }
 
 static int
-load_consts (MOD_GL_UTILS_CONTEXT * utils_context,
-	     _MOD_GL_HUD_TACTICAL_CONTEXT * tactical_context)
+load_consts (mod_gl_utils_context_t * utils_context,
+	     _mod_gl_hud_tactical_context_t * tactical_context)
 {
   int ret = 0;
   char *const_file = NULL;
 
-  const_file = lw6sys_find_data_file (CONST_FILE);
+  const_file = lw6sys_path_concat (utils_context->path.data_dir, CONST_FILE);
 
   if (const_file)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("reading \"%s\""),
-		  const_file);
+      lw6sys_log (LW6SYS_LOG_INFO, _("reading \"%s\""), const_file);
 
       ret =
 	lw6cfg_read_key_value_xml_file (const_file, read_callback,
@@ -94,28 +92,28 @@ load_consts (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 static void
-unload_consts (MOD_GL_UTILS_CONTEXT * utils_context,
-	       _MOD_GL_HUD_TACTICAL_CONTEXT * tactical_context)
+unload_consts (mod_gl_utils_context_t * utils_context,
+	       _mod_gl_hud_tactical_context_t * tactical_context)
 {
   memset (&tactical_context->const_data, 0,
-	  sizeof (_MOD_GL_HUD_TACTICAL_CONST_DATA));
+	  sizeof (_mod_gl_hud_tactical_const_data_t));
 }
 
 /*
  * Loads images from disk.
  */
 static int
-load_images (MOD_GL_UTILS_CONTEXT * utils_context,
-	     _MOD_GL_HUD_TACTICAL_CONTEXT * tactical_context)
+load_images (mod_gl_utils_context_t * utils_context,
+	     _mod_gl_hud_tactical_context_t * tactical_context)
 {
   int ret = 0;
 
-  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("loading images"));
+  lw6sys_log (LW6SYS_LOG_INFO, _("loading images"));
 
   ret =
     ((tactical_context->image_data.frame =
-      mod_gl_utils_load_image (utils_context, IMAGE_DIR,
-			       IMAGE_FRAME)) != NULL);
+      mod_gl_utils_load_image (utils_context,
+			       IMAGE_DIR IMAGE_FRAME)) != NULL);
 
   if (!ret)
     {
@@ -132,22 +130,22 @@ load_images (MOD_GL_UTILS_CONTEXT * utils_context,
  * Free memory.
  */
 static void
-unload_images (MOD_GL_UTILS_CONTEXT * utils_context,
-	       _MOD_GL_HUD_TACTICAL_CONTEXT * tactical_context)
+unload_images (mod_gl_utils_context_t * utils_context,
+	       _mod_gl_hud_tactical_context_t * tactical_context)
 {
   mod_gl_utils_unload_image (utils_context,
 			     tactical_context->image_data.frame);
 
   memset (&tactical_context->image_data, 0,
-	  sizeof (_MOD_GL_HUD_TACTICAL_IMAGE_DATA));
+	  sizeof (_mod_gl_hud_tactical_image_data_t));
 }
 
 /*
  * Loads textures from disk.
  */
 static int
-load_textures (MOD_GL_UTILS_CONTEXT * utils_context,
-	       _MOD_GL_HUD_TACTICAL_CONTEXT * tactical_context)
+load_textures (mod_gl_utils_context_t * utils_context,
+	       _mod_gl_hud_tactical_context_t * tactical_context)
 {
   int ret = 0;
 
@@ -171,8 +169,8 @@ load_textures (MOD_GL_UTILS_CONTEXT * utils_context,
  * Free memory.
  */
 static void
-unload_textures (MOD_GL_UTILS_CONTEXT * utils_context,
-		 _MOD_GL_HUD_TACTICAL_CONTEXT * tactical_context)
+unload_textures (mod_gl_utils_context_t * utils_context,
+		 _mod_gl_hud_tactical_context_t * tactical_context)
 {
   mod_gl_utils_unload_texture (utils_context,
 			       tactical_context->texture_data.frame);
@@ -182,8 +180,8 @@ unload_textures (MOD_GL_UTILS_CONTEXT * utils_context,
  * Putting all the load/unload functions together
  */
 int
-_mod_gl_hud_tactical_load_data (MOD_GL_UTILS_CONTEXT * utils_context,
-				_MOD_GL_HUD_TACTICAL_CONTEXT *
+_mod_gl_hud_tactical_load_data (mod_gl_utils_context_t * utils_context,
+				_mod_gl_hud_tactical_context_t *
 				tactical_context)
 {
   return load_consts (utils_context, tactical_context) &&
@@ -192,8 +190,8 @@ _mod_gl_hud_tactical_load_data (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-_mod_gl_hud_tactical_unload_data (MOD_GL_UTILS_CONTEXT * utils_context,
-				  _MOD_GL_HUD_TACTICAL_CONTEXT *
+_mod_gl_hud_tactical_unload_data (mod_gl_utils_context_t * utils_context,
+				  _mod_gl_hud_tactical_context_t *
 				  tactical_context)
 {
   unload_consts (utils_context, tactical_context);
