@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,9 +21,7 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
-
 #include <GL/glu.h>
 
 #include "config.h"
@@ -36,8 +34,8 @@
  * OpenGL wizardry, to prepare view parameters.
  */
 static void
-prepare_view (MOD_GL_UTILS_CONTEXT * utils_context,
-	      _MOD_GL_MENU_CYLINDER_CONTEXT * cylinder_context)
+prepare_view (mod_gl_utils_context_t * utils_context,
+	      _mod_gl_menu_cylinder_context_t * cylinder_context)
 {
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
@@ -46,61 +44,94 @@ prepare_view (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 static void
-draw_cylinder (MOD_GL_UTILS_CONTEXT * utils_context,
-	       _MOD_GL_MENU_CYLINDER_CONTEXT * cylinder_context,
+draw_cylinder (mod_gl_utils_context_t * utils_context,
+	       _mod_gl_menu_cylinder_context_t * cylinder_context,
 	       int i, int n, float ratio)
 {
   _mod_gl_menu_cylinder_draw_cylinder (utils_context, cylinder_context,
 				       GL_RENDER, i, n, ratio);
 }
 
+static void
+draw_sphere (mod_gl_utils_context_t * utils_context,
+	     _mod_gl_menu_cylinder_context_t * cylinder_context, int i, int n,
+	     int sphere_i, int nb_spheres)
+{
+  _mod_gl_menu_cylinder_draw_sphere (utils_context, cylinder_context,
+				     GL_RENDER, i, n, sphere_i, nb_spheres);
+}
+
 static SDL_Color
-get_fg_color (MOD_GL_UTILS_CONTEXT * utils_context,
-	      _MOD_GL_MENU_CYLINDER_CONTEXT * cylinder_context, int select)
+get_fg_color (lw6gui_look_t * look, lw6gui_menuitem_t * menuitem)
 {
   SDL_Color color;
 
-  if (select)
+  if (!menuitem->enabled)
     {
-      color = mod_gl_utils_color_sys2sdl (&(utils_context->const_data.
-					    menu_fg_selected));
+      color =
+	mod_gl_utils_color_8_to_sdl (look->style.menu_color_disabled.fg);
+    }
+  else if (menuitem->selected)
+    {
+      color =
+	mod_gl_utils_color_8_to_sdl (look->style.menu_color_selected.fg);
     }
   else
     {
-      color =
-	mod_gl_utils_color_sys2sdl (&(utils_context->const_data.menu_fg));
+      color = mod_gl_utils_color_8_to_sdl (look->style.menu_color_default.fg);
     }
 
   return color;
 }
 
 static SDL_Color
-get_bg_color (MOD_GL_UTILS_CONTEXT * utils_context,
-	      _MOD_GL_MENU_CYLINDER_CONTEXT * cylinder_context, int select)
+get_bg_color (lw6gui_look_t * look, lw6gui_menuitem_t * menuitem)
 {
   SDL_Color color;
 
-  if (select)
+  if (!menuitem->enabled)
     {
-      color = mod_gl_utils_color_sys2sdl (&(utils_context->const_data.
-					    menu_bg_selected));
+      color =
+	mod_gl_utils_color_8_to_sdl (look->style.menu_color_disabled.bg);
+    }
+  else if (menuitem->colored)
+    {
+      if (menuitem->value >= 0 && menuitem->value < LW6MAP_NB_TEAM_COLORS)
+	{
+	  // todo, get it from config...
+	  color =
+	    mod_gl_utils_color_8_to_sdl (look->style.
+					 team_colors[menuitem->value]);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("invalid value %d for colored menu item"),
+		      menuitem->value);
+	  color = mod_gl_utils_color_8_to_sdl (LW6SYS_COLOR_8_WHITE);
+	}
+    }
+  else if (menuitem->selected)
+    {
+      color =
+	mod_gl_utils_color_8_to_sdl (look->style.menu_color_selected.bg);
     }
   else
     {
-      color =
-	mod_gl_utils_color_sys2sdl (&(utils_context->const_data.menu_bg));
+      color = mod_gl_utils_color_8_to_sdl (look->style.menu_color_default.bg);
     }
 
   return color;
 }
 
+
 /*
  * Draw a basic text menu item (button).
  */
 static void
-draw_button (MOD_GL_UTILS_CONTEXT * utils_context,
-	     _MOD_GL_MENU_CYLINDER_CONTEXT * cylinder_context, char *text,
-	     int select, int i, int n)
+draw_button (mod_gl_utils_context_t * utils_context,
+	     _mod_gl_menu_cylinder_context_t * cylinder_context,
+	     lw6gui_look_t * look, lw6gui_menuitem_t * menuitem, int i, int n)
 {
   SDL_Surface *text_surface = NULL;
   SDL_Surface *outline_surface = NULL;
@@ -113,15 +144,15 @@ draw_button (MOD_GL_UTILS_CONTEXT * utils_context,
   SDL_Rect outline_rect;
 
   outline_surface =
-    mod_gl_utils_get_button_from_menucache (utils_context, text, select);
+    mod_gl_utils_get_button_from_menucache (utils_context, look, menuitem);
 
   if (outline_surface == NULL)
     {
-      utf8 = lw6sys_locale_to_utf8 (text);
+      utf8 = lw6sys_locale_to_utf8 (menuitem->label);
       if (utf8 != NULL)
 	{
-	  fg_color = get_fg_color (utils_context, cylinder_context, select);
-	  bg_color = get_bg_color (utils_context, cylinder_context, select);
+	  fg_color = get_fg_color (look, menuitem);
+	  bg_color = get_bg_color (look, menuitem);
 	  text_surface =
 	    TTF_RenderUTF8_Shaded (utils_context->font_data.menu, utf8,
 				   fg_color, bg_color);
@@ -152,7 +183,7 @@ draw_button (MOD_GL_UTILS_CONTEXT * utils_context,
 				   &outline_rect);
 
 		  if (!mod_gl_utils_store_button_in_menucache
-		      (utils_context, text, select, outline_surface))
+		      (utils_context, look, menuitem, outline_surface))
 		    {
 		      /*
 		       * Storing stuff in menucache should always work, but in
@@ -189,11 +220,13 @@ draw_button (MOD_GL_UTILS_CONTEXT * utils_context,
 						       2,
 						       MOD_GL_UTILS_MENU_TEXTURE_W,
 						       MOD_GL_UTILS_MENU_TEXTURE_H,
-						       text, select);
+						       menuitem->label,
+						       lw6gui_menuitem_checksum
+						       (menuitem));
       if (text_texture)
 	{
 	  glEnable (GL_TEXTURE_2D);
-	  glColor3f (1.0f, 1.0f, 0.0f);
+	  glColor3f (1.0f, 1.0f, 1.0f);
 	  glBindTexture (GL_TEXTURE_2D, text_texture);
 
 	  glMatrixMode (GL_TEXTURE);
@@ -226,8 +259,34 @@ draw_button (MOD_GL_UTILS_CONTEXT * utils_context,
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
-		  _("unable to draw button \"%s\""), text);
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to draw button \"%s\""), menuitem->label);
+    }
+}
+
+static void
+draw_spheres (mod_gl_utils_context_t * utils_context,
+	      _mod_gl_menu_cylinder_context_t * cylinder_context, int i,
+	      int n, int blink_state, int nb_spheres)
+{
+  int sphere_i;
+
+  glEnable (GL_TEXTURE_2D);
+  glColor3f (1.0f, 1.0f, 1.0f);
+
+  if (blink_state)
+    {
+      glBindTexture (GL_TEXTURE_2D, utils_context->textures_1x1.menu_fg);
+    }
+  else
+    {
+      glBindTexture (GL_TEXTURE_2D, utils_context->textures_1x1.menu_bg);
+    }
+
+  for (sphere_i = 0; sphere_i < nb_spheres; ++sphere_i)
+    {
+      draw_sphere (utils_context, cylinder_context, i, n, sphere_i,
+		   nb_spheres);
     }
 }
 
@@ -235,65 +294,53 @@ draw_button (MOD_GL_UTILS_CONTEXT * utils_context,
  * Display a menu.
  */
 void
-_mod_gl_menu_cylinder_display (MOD_GL_UTILS_CONTEXT * utils_context,
-			       _MOD_GL_MENU_CYLINDER_CONTEXT *
-			       cylinder_context, LW6GFX_MENU * menu)
+_mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
+			       _mod_gl_menu_cylinder_context_t *
+			       cylinder_context, lw6gui_look_t * look,
+			       lw6gui_menu_t * menu)
 {
-  int i;
-  LW6GFX_MENUITEM *menuitem;
-  LW6GFX_MENU_STATE *menu_state;
+  int i, j, n;
+  int blink_state;
+  lw6gui_menuitem_t *menuitem;
 
   mod_gl_utils_set_render_mode_3d_menu (utils_context);
+  mod_gl_utils_texture_1x1_update (utils_context, look);
 
   prepare_view (utils_context, cylinder_context);
 
-  if (lw6sys_assoc_has_key (cylinder_context->menu_states, menu->id))
-    {
-      menu_state =
-	(LW6GFX_MENU_STATE *) lw6sys_assoc_get (cylinder_context->menu_states,
-						menu->id);
-    }
-  else
-    {
-      menu_state = lw6gfx_menu_state_new ();
-      lw6sys_assoc_set (&(cylinder_context->menu_states), menu->id,
-			(void *) menu_state);
-    }
-  lw6gfx_menu_state_update (menu_state, menu,
-			    utils_context->const_data.
-			    menu_max_displayed_items);
+  lw6gui_menu_update_display_range (menu,
+				    cylinder_context->const_data.
+				    max_displayed_items);
 
-  for (i = 0; i < menu_state->nb_items_displayed; ++i)
+  blink_state =
+    mod_gl_utils_get_ticks (utils_context) /
+    (cylinder_context->const_data.sphere_blink_period / 2) % 2;
+  n = menu->nb_items_displayed + 2;
+  if (menu->first_item_displayed > 0)
     {
-      menuitem = menu->items[i + menu_state->first_item_displayed];
-      switch (menuitem->type)
-	{
-	case LW6GFX_MENUITEM_NONE:
-	  break;
-	case LW6GFX_MENUITEM_BUTTON:
-	  draw_button (utils_context,
-		       cylinder_context,
-		       menuitem->label,
-		       i + menu_state->first_item_displayed ==
-		       menu->selected_item, i,
-		       menu_state->nb_items_displayed);
-	  break;
-	case LW6GFX_MENUITEM_EDIT:
-	  break;
-	case LW6GFX_MENUITEM_SLIDER:
-	  break;
-	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
-		      _("unknown menuitem type %d"), menuitem->type);
-	}
+      draw_spheres (utils_context, cylinder_context, 0, n,
+		    blink_state, cylinder_context->const_data.nb_spheres);
+    }
+  for (i = 0; i < menu->nb_items_displayed; ++i)
+    {
+      j = i + menu->first_item_displayed;
+      menuitem = menu->items[j];
+      draw_button (utils_context, cylinder_context, look, menuitem, i + 1, n);
+    }
+  if (menu->first_item_displayed + menu->nb_items_displayed < menu->nb_items)
+    {
+      draw_spheres (utils_context, cylinder_context, n - 1, n,
+		    blink_state ? 0 : 1,
+		    cylinder_context->const_data.nb_spheres);
     }
 }
 
 void
-mod_gl_menu_cylinder_display (MOD_GL_UTILS_CONTEXT * utils_context,
-			      void *cylinder_context, LW6GFX_MENU * menu)
+mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
+			      void *cylinder_context, lw6gui_look_t * look,
+			      lw6gui_menu_t * menu)
 {
   _mod_gl_menu_cylinder_display (utils_context,
-				 (_MOD_GL_MENU_CYLINDER_CONTEXT *)
-				 cylinder_context, menu);
+				 (_mod_gl_menu_cylinder_context_t *)
+				 cylinder_context, look, menu);
 }
