@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,21 +22,31 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
-
 #include <GL/glu.h>
 
 #include "config.h"
 #include "../../mod-gl.h"
 #include "gl-cylinder-internal.h"
 
+float
+_mod_gl_menu_cylinder_get_cylinder_y (mod_gl_utils_context_t * utils_context,
+				      _mod_gl_menu_cylinder_context_t *
+				      cylinder_context, int i, int n)
+{
+  float y;
+
+  y = -cylinder_context->const_data.between1 * (i - (n - 1) / 2.0f) / n;
+
+  return y;
+}
+
 /*
  * Display a horizontal  cylinder.
  */
 void
-_mod_gl_menu_cylinder_draw_cylinder (MOD_GL_UTILS_CONTEXT * utils_context,
-				     _MOD_GL_MENU_CYLINDER_CONTEXT *
+_mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t * utils_context,
+				     _mod_gl_menu_cylinder_context_t *
 				     cylinder_context, GLenum mode, int i,
 				     int n, float ratio)
 {
@@ -60,10 +71,11 @@ _mod_gl_menu_cylinder_draw_cylinder (MOD_GL_UTILS_CONTEXT * utils_context,
 	cylinder_context->const_data.height *
 	((float) utils_context->screen.width) /
 	((float) utils_context->screen.height);
-      y = -cylinder_context->const_data.between1 * (i - (n - 1) / 2.0f) / n;
+      y =
+	_mod_gl_menu_cylinder_get_cylinder_y (utils_context, cylinder_context,
+					      i, n);
       dy =
-	(cylinder_context->const_data.oscil_range1 / n) * sin (2.0f *
-							       M_PI *
+	(cylinder_context->const_data.oscil_range1 / n) * sin (2.0f * M_PI *
 							       (((((float)
 								   mod_gl_utils_get_ticks
 								   (utils_context)))
@@ -99,7 +111,57 @@ _mod_gl_menu_cylinder_draw_cylinder (MOD_GL_UTILS_CONTEXT * utils_context,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
-		  _("unable to create quadric"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create quadric"));
+    }
+}
+
+void
+_mod_gl_menu_cylinder_draw_sphere (mod_gl_utils_context_t * utils_context,
+				   _mod_gl_menu_cylinder_context_t *
+				   cylinder_context, GLenum mode, int i,
+				   int n, int sphere_i, int nb_spheres)
+{
+  GLUquadricObj *cyl;
+
+  cyl = gluNewQuadric ();
+  if (cyl != NULL)
+    {
+      float radius;
+      int slices;
+      int stacks;
+      float y;
+      float x;
+
+      if (mode == GL_RENDER)
+	{
+	  gluQuadricTexture (cyl, GL_TRUE);
+	}
+
+      radius = cylinder_context->const_data.sphere_radius1 / n;
+      y = -cylinder_context->const_data.between1 * (i - (n - 1) / 2.0f) / n;
+      x =
+	(cylinder_context->const_data.sphere_between1 *
+	 (sphere_i + 0.5f - nb_spheres / 2.0f)) / n;
+      slices = cylinder_context->const_data.sphere_slices1 / n;
+      if (slices < cylinder_context->const_data.sphere_slices_min)
+	{
+	  slices = cylinder_context->const_data.sphere_slices_min;
+	}
+      stacks = slices;
+      glMatrixMode (GL_MODELVIEW);
+      glPushMatrix ();
+      glLoadIdentity ();
+      glTranslatef (x, y, -1.0f);
+
+      gluSphere (cyl, radius, slices, stacks);
+
+      glMatrixMode (GL_MODELVIEW);
+      glPopMatrix ();
+
+      gluDeleteQuadric (cyl);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create quadric"));
     }
 }
