@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,32 +22,54 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
-
 #include <GL/glu.h>
 
 #include "config.h"
 #include "../../mod-gl.h"
 #include "gl-cylinder-internal.h"
 
-#define SELECT_BUFFER_SIZE 1024
+#define SELECT_BUFFER_SIZE 4096
+
+#define NAME_DEFAULT -1
+#define NAME_PREV -2
+#define NAME_NEXT -3
 
 static void
-draw_button_shape (MOD_GL_UTILS_CONTEXT * utils_context,
-		   _MOD_GL_MENU_CYLINDER_CONTEXT * cylinder_context,
-		   char *label, int i, int n, int name)
+draw_button_shape (mod_gl_utils_context_t * utils_context,
+		   _mod_gl_menu_cylinder_context_t * cylinder_context,
+		   int i, int n, int name)
 {
   glLoadName (name);
   _mod_gl_menu_cylinder_draw_cylinder (utils_context, cylinder_context,
 				       GL_SELECT, i, n, 1.0f);
 }
 
+static void
+draw_spheres_shape (mod_gl_utils_context_t * utils_context,
+		    _mod_gl_menu_cylinder_context_t * cylinder_context, int i,
+		    int n, int nb_spheres, int name)
+{
+  int sphere_i;
+
+  glLoadName (name);
+
+  for (sphere_i = 0; sphere_i < nb_spheres; ++sphere_i)
+    {
+      _mod_gl_menu_cylinder_draw_sphere (utils_context, cylinder_context,
+					 GL_SELECT, i, n, sphere_i,
+					 nb_spheres);
+    }
+  // we also draw the cylinder, lazy pick...
+  _mod_gl_menu_cylinder_draw_cylinder (utils_context, cylinder_context,
+				       GL_SELECT, i, n, 1.0f);
+}
+
 static int
 process_select_hits (GLint select_hits,
 		     GLuint select_buffer[SELECT_BUFFER_SIZE], int x, int y)
 {
-  int ret = -1;
+  int ret = NAME_DEFAULT;
   unsigned int i, j;
   GLuint names, *ptr;
 
@@ -73,79 +96,78 @@ process_select_hits (GLint select_hits,
   return ret;
 }
 
-int
-_mod_gl_menu_cylinder_pick_item (MOD_GL_UTILS_CONTEXT * utils_context,
-				 _MOD_GL_MENU_CYLINDER_CONTEXT *
-				 cylinder_context, LW6GFX_MENU * menu,
-				 int screen_x, int screen_y)
+void
+_mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
+				 _mod_gl_menu_cylinder_context_t *
+				 cylinder_context, lw6gui_look_t * look,
+				 int *position, int *scroll,
+				 lw6gui_menu_t * menu, int screen_x,
+				 int screen_y)
 {
-  int ret = -1;
-  int i;
-  LW6GFX_MENUITEM *menuitem;
-  LW6GFX_MENU_STATE *menu_state;
+  int ret = NAME_DEFAULT;
+  int i, n;
+  lw6gui_menuitem_t *menuitem;
   GLuint select_buffer[SELECT_BUFFER_SIZE];
   GLint select_hits;
 
+  lw6gui_menu_update_display_range (menu,
+				    cylinder_context->const_data.
+				    max_displayed_items);
+
   glSelectBuffer (SELECT_BUFFER_SIZE, select_buffer);
   glRenderMode (GL_SELECT);
   glInitNames ();
-  glPushName (-1);
+  glPushName (NAME_DEFAULT);
 
   mod_gl_utils_set_render_mode_3d_pick (utils_context, screen_x, screen_y);
 
-  if (lw6sys_assoc_has_key (cylinder_context->menu_states, menu->id))
+  n = menu->nb_items_displayed + 2;
+  if (menu->first_item_displayed > 0)
     {
-      menu_state =
-	(LW6GFX_MENU_STATE *) lw6sys_assoc_get (cylinder_context->menu_states,
-						menu->id);
+      draw_spheres_shape (utils_context, cylinder_context, 0, n,
+			  cylinder_context->const_data.nb_spheres, NAME_PREV);
     }
-  else
+  for (i = 0; i < menu->nb_items_displayed; ++i)
     {
-      menu_state = lw6gfx_menu_state_new ();
-      lw6sys_assoc_set (&(cylinder_context->menu_states), menu->id,
-			(void *) menu_state);
-      lw6gfx_menu_state_update (menu_state, menu,
-				utils_context->const_data.
-				menu_max_displayed_items);
+      menuitem = menu->items[i + menu->first_item_displayed];
+      draw_button_shape (utils_context,
+			 cylinder_context,
+			 i + 1, n, i + menu->first_item_displayed);
     }
-
-  for (i = 0; i < menu_state->nb_items_displayed; ++i)
+  if (menu->first_item_displayed + menu->nb_items_displayed < menu->nb_items)
     {
-      menuitem = menu->items[i + menu_state->first_item_displayed];
-      switch (menuitem->type)
-	{
-	case LW6GFX_MENUITEM_NONE:
-	  break;
-	case LW6GFX_MENUITEM_BUTTON:
-	  draw_button_shape (utils_context,
-			     cylinder_context,
-			     menuitem->label,
-			     i, menu_state->nb_items_displayed,
-			     i + menu_state->first_item_displayed);
-	  break;
-	case LW6GFX_MENUITEM_EDIT:
-	  break;
-	case LW6GFX_MENUITEM_SLIDER:
-	  break;
-	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
-		      _("unknown menuitem type %d"), menuitem->type);
-	}
+      draw_spheres_shape (utils_context, cylinder_context, n - 1, n,
+			  cylinder_context->const_data.nb_spheres, NAME_NEXT);
     }
 
   select_hits = glRenderMode (GL_RENDER);
   ret = process_select_hits (select_hits, select_buffer, screen_x, screen_y);
 
-  return ret;
+  switch (ret)
+    {
+    case NAME_PREV:
+      (*scroll) = -1;
+      (*position) = NAME_DEFAULT;
+      break;
+    case NAME_NEXT:
+      (*scroll) = +1;
+      (*position) = NAME_DEFAULT;
+      break;
+    default:
+      (*position) = ret;
+      (*scroll) = 0;
+    }
 }
 
-int
-mod_gl_menu_cylinder_pick_item (MOD_GL_UTILS_CONTEXT * utils_context,
-				void *cylinder_context, LW6GFX_MENU * menu,
+void
+mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
+				void *cylinder_context, lw6gui_look_t * look,
+				int *position,
+				int *scroll, lw6gui_menu_t * menu,
 				int screen_x, int screen_y)
 {
-  return _mod_gl_menu_cylinder_pick_item (utils_context,
-					  (_MOD_GL_MENU_CYLINDER_CONTEXT *)
-					  cylinder_context, menu, screen_x,
-					  screen_y);
+  _mod_gl_menu_cylinder_pick_item (utils_context,
+				   (_mod_gl_menu_cylinder_context_t *)
+				   cylinder_context, look, position, scroll,
+				   menu, screen_x, screen_y);
 }
