@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,13 +27,13 @@
 static void
 warning (char *func_name)
 {
-  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+  lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("menu backend function \"%s\" is not defined"));
 }
 
 int
-mod_gl_menu_init (MOD_GL_UTILS_CONTEXT * utils_context,
-		  MOD_GL_MENU_BACKEND * backend)
+mod_gl_menu_init (mod_gl_utils_context_t * utils_context,
+		  mod_gl_menu_backend_t * backend)
 {
   if (backend->init)
     {
@@ -47,8 +48,8 @@ mod_gl_menu_init (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_menu_quit (MOD_GL_UTILS_CONTEXT * utils_context,
-		  MOD_GL_MENU_BACKEND * backend)
+mod_gl_menu_quit (mod_gl_utils_context_t * utils_context,
+		  mod_gl_menu_backend_t * backend)
 {
   if (backend->quit)
     {
@@ -61,12 +62,13 @@ mod_gl_menu_quit (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_menu_display (MOD_GL_UTILS_CONTEXT * utils_context,
-		     MOD_GL_MENU_BACKEND * backend, LW6GFX_MENU * menu)
+mod_gl_menu_display (mod_gl_utils_context_t * utils_context,
+		     mod_gl_menu_backend_t * backend, lw6gui_look_t * look,
+		     lw6gui_menu_t * menu)
 {
   if (backend->display)
     {
-      backend->display (utils_context, backend->menu_context, menu);
+      backend->display (utils_context, backend->menu_context, look, menu);
     }
   else
     {
@@ -74,23 +76,42 @@ mod_gl_menu_display (MOD_GL_UTILS_CONTEXT * utils_context,
     }
 }
 
-int
-mod_gl_menu_pick_item (MOD_GL_UTILS_CONTEXT * utils_context,
-		       MOD_GL_MENU_BACKEND * backend, LW6GFX_MENU * menu,
-		       int screen_x, int screen_y)
+void
+mod_gl_menu_pick_item (mod_gl_utils_context_t * utils_context,
+		       mod_gl_menu_backend_t * backend, lw6gui_look_t * look,
+		       int *position,
+		       int *scroll, lw6gui_menu_t * menu, int screen_x,
+		       int screen_y)
 {
-  int ret = 0;
-
   if (backend->pick_item)
     {
-      ret =
-	backend->pick_item (utils_context, backend->menu_context, menu,
-			    screen_x, screen_y);
+      backend->pick_item (utils_context, backend->menu_context, look,
+			  position, scroll, menu, screen_x, screen_y);
     }
   else
     {
       warning ("menu_pick_item");
     }
+}
+
+int
+mod_gl_menu_warp_mouse_on_menuitem (mod_gl_utils_context_t * utils_context,
+				    mod_gl_menu_backend_t * backend,
+				    lw6gui_look_t * look,
+				    lw6gui_menu_t * menu, int position)
+{
+  int ret = 0;
+
+  if (backend->warp_mouse_on_menuitem)
+    {
+      ret =
+	backend->warp_mouse_on_menuitem (utils_context, backend->menu_context,
+					 look, menu, position);
+    }
+  else
+    {
+      warning ("menu_warp_mouse_on_menuitem");
+    }
 
   return ret;
 }
