@@ -1,7 +1,7 @@
 
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,10 +22,7 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-#include <locale.h>
-
 #include <GL/glu.h>
 #include <SDL/SDL_image.h>
 
@@ -35,19 +32,17 @@
 #include "gl-utils.h"
 #include "gl-utils-internal.h"
 
-#define CONST_FILE "gfx/gl/utils/const.xml"
+#define CONST_FILE "utils/gl-utils-const.xml"
 
 static void
 read_callback (void *callback_data, char *element, char *key, char *value)
 {
-  MOD_GL_UTILS_CONST_DATA *const_data;
+  mod_gl_utils_const_data_t *const_data;
 
-  const_data = (MOD_GL_UTILS_CONST_DATA *) callback_data;
+  const_data = (mod_gl_utils_const_data_t *) callback_data;
 
   if (!strcmp (element, "int"))
     {
-      lw6cfg_read_xml_int (key, value, "menu-max-displayed-items",
-			   &const_data->menu_max_displayed_items);
       lw6cfg_read_xml_int (key, value, "menu-font-size",
 			   &const_data->menu_font_size);
       lw6cfg_read_xml_int (key, value, "system-font-size",
@@ -56,6 +51,14 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			   &const_data->system_font_dw);
       lw6cfg_read_xml_int (key, value, "system-font-dh",
 			   &const_data->system_font_dh);
+      lw6cfg_read_xml_int (key, value, "joystick-limit-up",
+			   &const_data->joystick_limit_up);
+      lw6cfg_read_xml_int (key, value, "joystick-limit-down",
+			   &const_data->joystick_limit_down);
+      lw6cfg_read_xml_int (key, value, "joystick-limit-left",
+			   &const_data->joystick_limit_left);
+      lw6cfg_read_xml_int (key, value, "joystick-limit-right",
+			   &const_data->joystick_limit_right);
     }
 
   if (!strcmp (element, "float"))
@@ -74,14 +77,20 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			     &const_data->gradient_opacity);
       lw6cfg_read_xml_float (key, value, "zones-opacity",
 			     &const_data->zones_opacity);
-    }
-
-  if (!strcmp (element, "color"))
-    {
-      lw6cfg_read_xml_color (key, value, "system-font-fg",
-			     &const_data->system_font_fg);
-      lw6cfg_read_xml_color (key, value, "system-font-shade",
-			     &const_data->system_font_shade);
+      lw6cfg_read_xml_float (key, value, "mainlight-r",
+			     &const_data->mainlight_r);
+      lw6cfg_read_xml_float (key, value, "mainlight-g",
+			     &const_data->mainlight_g);
+      lw6cfg_read_xml_float (key, value, "mainlight-b",
+			     &const_data->mainlight_b);
+      lw6cfg_read_xml_float (key, value, "mainlight-a",
+			     &const_data->mainlight_a);
+      lw6cfg_read_xml_float (key, value, "mainlight-x",
+			     &const_data->mainlight_x);
+      lw6cfg_read_xml_float (key, value, "mainlight-y",
+			     &const_data->mainlight_y);
+      lw6cfg_read_xml_float (key, value, "mainlight-z",
+			     &const_data->mainlight_z);
     }
 }
 
@@ -89,17 +98,16 @@ read_callback (void *callback_data, char *element, char *key, char *value)
  * Loads constants.
  */
 int
-_mod_gl_utils_load_consts (MOD_GL_UTILS_CONTEXT * context)
+_mod_gl_utils_load_consts (mod_gl_utils_context_t * context)
 {
   int ret = 0;
   char *const_file = NULL;
 
-  const_file = lw6sys_find_data_file (CONST_FILE);
+  const_file = lw6sys_path_concat (context->path.data_dir, CONST_FILE);
 
   if (const_file)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("reading \"%s\""),
-		  const_file);
+      lw6sys_log (LW6SYS_LOG_INFO, _("reading \"%s\""), const_file);
 
       ret =
 	lw6cfg_read_key_value_xml_file (const_file, read_callback,
@@ -115,7 +123,7 @@ _mod_gl_utils_load_consts (MOD_GL_UTILS_CONTEXT * context)
  * Unload constants, free memory
  */
 void
-_mod_gl_utils_unload_consts (MOD_GL_UTILS_CONTEXT * context)
+_mod_gl_utils_unload_consts (mod_gl_utils_context_t * context)
 {
-  memset (&context->const_data, 0, sizeof (MOD_GL_UTILS_CONST_DATA));
+  memset (&context->const_data, 0, sizeof (mod_gl_utils_const_data_t));
 }
