@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,9 +21,7 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-
 #include <GL/glu.h>
 #include <SDL/SDL_image.h>
 #include <expat.h>
@@ -33,34 +31,25 @@
 #include "gl-utils.h"
 #include "gl-utils-internal.h"
 
-#define FONT_DIR "gfx/gl/utils/font/"
-#define FONT_FILE "FreeSansBold.ttf"
+#define FONT_FILE "utils/font/FreeSansBold.ttf"
 
 /*
  * Dummy wrapper to handle cast & errors.
  */
 SDL_Surface *
-mod_gl_utils_load_image (MOD_GL_UTILS_CONTEXT * utils_context, char *dirname,
+mod_gl_utils_load_image (mod_gl_utils_context_t * utils_context,
 			 char *filename)
 {
   SDL_Surface *ret = NULL;
-  char *buf = NULL;
+  char *image_file = NULL;
 
-  buf = lw6sys_str_concat (dirname, filename);
-  if (buf)
+  image_file = lw6sys_path_concat (utils_context->path.data_dir, filename);
+
+  if (image_file)
     {
-      char *image_file;
-
-      image_file = lw6sys_find_data_file (buf);
-
-      if (image_file)
-	{
-	  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl",
-		      _("loading image \"%s\""), image_file);
-	  ret = IMG_Load (image_file);
-	  LW6SYS_FREE (image_file);
-	}
-      LW6SYS_FREE (buf);
+      lw6sys_log (LW6SYS_LOG_INFO, _("loading image \"%s\""), image_file);
+      ret = IMG_Load (image_file);
+      LW6SYS_FREE (image_file);
     }
 
   if (ret != NULL)
@@ -72,7 +61,7 @@ mod_gl_utils_load_image (MOD_GL_UTILS_CONTEXT * utils_context, char *dirname,
       /*
        * Carefull not to use buf in error message.
        */
-      lw6sys_log (LW6SYS_LOG_ERROR, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_ERROR,
 		  _("unable to load image \"%s\""), filename);
     }
 
@@ -83,7 +72,7 @@ mod_gl_utils_load_image (MOD_GL_UTILS_CONTEXT * utils_context, char *dirname,
  * Dummy wrapper to handle cast & errors.
  */
 void
-mod_gl_utils_unload_image (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_utils_unload_image (mod_gl_utils_context_t * utils_context,
 			   SDL_Surface * image)
 {
   mod_gl_utils_delete_surface (utils_context, image);
@@ -93,7 +82,7 @@ mod_gl_utils_unload_image (MOD_GL_UTILS_CONTEXT * utils_context,
  * Dummy wrapper to handle cast & errors.
  */
 GLuint
-mod_gl_utils_load_texture (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_utils_load_texture (mod_gl_utils_context_t * utils_context,
 			   SDL_Surface * surface)
 {
   GLuint ret = 0;
@@ -102,8 +91,7 @@ mod_gl_utils_load_texture (MOD_GL_UTILS_CONTEXT * utils_context,
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_ERROR, "gfx-mod-gl",
-		  _("unable to load texture"));
+      lw6sys_log (LW6SYS_LOG_ERROR, _("unable to load texture"));
     }
 
   return ret;
@@ -113,7 +101,7 @@ mod_gl_utils_load_texture (MOD_GL_UTILS_CONTEXT * utils_context,
  * Dummy wrapper to handle cast & errors.
  */
 void
-mod_gl_utils_unload_texture (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_utils_unload_texture (mod_gl_utils_context_t * utils_context,
 			     int texture)
 {
   if (texture != 0)
@@ -127,8 +115,7 @@ mod_gl_utils_unload_texture (MOD_GL_UTILS_CONTEXT * utils_context,
        * in doubt we issue a warning, if it ever shows up,
        * will be time to decide wether to disable this check or not.
        */
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
-		  _("trying to delete NULL texture"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to delete NULL texture"));
     }
 }
 
@@ -136,31 +123,23 @@ mod_gl_utils_unload_texture (MOD_GL_UTILS_CONTEXT * utils_context,
  * Dummy wrapper to handle cast & errors.
  */
 static TTF_Font *
-load_font (char *dirname, char *filename, int size)
+load_font (mod_gl_utils_context_t * utils_context, char *filename, int size)
 {
   TTF_Font *ret = NULL;
-  char *buf = NULL;
+  char *font_file;
 
-  buf = lw6sys_str_concat (dirname, filename);
-  if (buf)
+  font_file = lw6sys_path_concat (utils_context->path.data_dir, filename);
+  if (font_file)
     {
-      char *font_file;
-
-      font_file = lw6sys_find_data_file (buf);
-
-      if (font_file)
-	{
-	  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("loading font \"%s\""),
-		      font_file);
-	  ret = TTF_OpenFont (font_file, size);
-	  LW6SYS_FREE (font_file);
-	}
-      LW6SYS_FREE (buf);
+      lw6sys_log (LW6SYS_LOG_INFO, _("loading font \"%s\", size %d"),
+		  font_file, size);
+      ret = TTF_OpenFont (font_file, size);
+      LW6SYS_FREE (font_file);
     }
 
   if (ret == NULL)
     {
-      lw6sys_log (LW6SYS_LOG_ERROR, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_ERROR,
 		  _("unable to load font \"%s\""), filename);
     }
 
@@ -179,8 +158,7 @@ unload_font (TTF_Font * font)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
-		  _("trying to close NULL font"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to close NULL font"));
     }
 }
 
@@ -188,19 +166,19 @@ unload_font (TTF_Font * font)
  * Loads fonts
  */
 int
-mod_gl_utils_load_fonts (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context)
 {
   int ret = 0;
 
-  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("loading fonts"));
+  lw6sys_log (LW6SYS_LOG_INFO, _("loading fonts"));
 
   ret =
     ((utils_context->font_data.menu =
-      load_font (FONT_DIR, FONT_FILE,
+      load_font (utils_context, FONT_FILE,
 		 utils_context->const_data.menu_font_size)) != NULL)
     &&
     ((utils_context->font_data.system =
-      load_font (FONT_DIR, FONT_FILE,
+      load_font (utils_context, FONT_FILE,
 		 utils_context->const_data.system_font_size)) != NULL);
 
   if (!ret)
@@ -218,34 +196,46 @@ mod_gl_utils_load_fonts (MOD_GL_UTILS_CONTEXT * utils_context)
  * Unload fonts, free memory
  */
 void
-mod_gl_utils_unload_fonts (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_unload_fonts (mod_gl_utils_context_t * utils_context)
 {
   unload_font (utils_context->font_data.menu);
   unload_font (utils_context->font_data.system);
 
-  memset (&utils_context->font_data, 0, sizeof (MOD_GL_UTILS_FONT_DATA));
+  memset (&utils_context->font_data, 0, sizeof (mod_gl_utils_font_data_t));
 }
 
 /*
  * Putting all the load/unload functions together
  */
 int
-mod_gl_utils_load_data (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_load_data (mod_gl_utils_context_t * utils_context)
 {
-  return
+  int ret = 0;
+  lw6gui_look_t *look = NULL;
+
+  ret =
     ((utils_context->texture_data.to_delete = lw6sys_list_new (NULL)) != NULL)
     && _mod_gl_utils_load_consts (utils_context)
     && mod_gl_utils_load_fonts (utils_context);
+
+  look = lw6gui_look_new (NULL);
+  if (look)
+    {
+      ret = mod_gl_utils_texture_1x1_update (utils_context, look) && ret;
+      lw6gui_look_free (look);
+    }
+
+  return ret;
 }
 
 int
 mod_gl_load_data (void *context)
 {
-  return mod_gl_utils_load_data ((MOD_GL_UTILS_CONTEXT *) context);
+  return mod_gl_utils_load_data ((mod_gl_utils_context_t *) context);
 }
 
 void
-mod_gl_utils_unload_data (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_unload_data (mod_gl_utils_context_t * utils_context)
 {
   mod_gl_utils_clear_menucache (utils_context);
 
@@ -255,14 +245,17 @@ mod_gl_utils_unload_data (MOD_GL_UTILS_CONTEXT * utils_context)
   LW6SYS_FREE (utils_context->texture_data.to_delete);
 
   memset (&utils_context->texture_data, 0,
-	  sizeof (MOD_GL_UTILS_TEXTURE_DATA));
+	  sizeof (mod_gl_utils_texture_data_t));
+
+  mod_gl_utils_unload_fonts (utils_context);
+
+  mod_gl_utils_texture_1x1_clear (utils_context);
 
   _mod_gl_utils_unload_consts (utils_context);
-  mod_gl_utils_unload_fonts (utils_context);
 }
 
 void
 mod_gl_unload_data (void *context)
 {
-  mod_gl_utils_unload_data ((MOD_GL_UTILS_CONTEXT *) context);
+  mod_gl_utils_unload_data ((mod_gl_utils_context_t *) context);
 }
