@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,7 +33,7 @@ get_text_wh (TTF_Font * font, char *text, int *width, int *height)
 {
   if (TTF_SizeUTF8 (font, text, width, height) == -1)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("unable to calculate font width and height for text \"%s\""),
 		  text);
@@ -64,7 +65,7 @@ get_text_height (TTF_Font * font, char *text)
  * Returns the size of the string if it was drawn
  */
 int
-mod_gl_utils_get_system_text_width (MOD_GL_UTILS_CONTEXT * context,
+mod_gl_utils_get_system_text_width (mod_gl_utils_context_t * context,
 				    char *text)
 {
   return get_text_width (context->font_data.system, text);
@@ -74,7 +75,7 @@ mod_gl_utils_get_system_text_width (MOD_GL_UTILS_CONTEXT * context,
  * Returns the size of the string if it was drawn
  */
 int
-mod_gl_utils_get_system_text_height (MOD_GL_UTILS_CONTEXT * context,
+mod_gl_utils_get_system_text_height (mod_gl_utils_context_t * context,
 				     char *text)
 {
   return get_text_height (context->font_data.system, text);
@@ -84,7 +85,7 @@ mod_gl_utils_get_system_text_height (MOD_GL_UTILS_CONTEXT * context,
  * Helper internal func
  */
 static void
-draw_text (MOD_GL_UTILS_CONTEXT * context,
+draw_text (mod_gl_utils_context_t * context,
 	   TTF_Font * font, SDL_Color color, char *text, int x, int y)
 {
   SDL_Surface *text_surface;
@@ -133,38 +134,34 @@ draw_text (MOD_GL_UTILS_CONTEXT * context,
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
-		      _("TTF_RenderUTF8_Blended failed"));
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("TTF_RenderUTF8_Blended failed"));
 	}
       LW6SYS_FREE (utf8);
     }
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
-		  _("unable to draw text \"%s\""), text);
+      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to draw text \"%s\""), text);
     }
 }
 
 static void
-system_colors (SDL_Color * fg, SDL_Color * shade,
-	       MOD_GL_UTILS_CONTEXT * context)
+system_colors (SDL_Color * fg, SDL_Color * shade, lw6gui_look_t * look)
 {
-  (*fg) = mod_gl_utils_color_sys2sdl (&(context->const_data.system_font_fg));
-  (*shade) =
-    mod_gl_utils_color_sys2sdl (&(context->const_data.system_font_shade));
+  (*fg) = mod_gl_utils_color_8_to_sdl (look->style.system_color.fg);
+  (*shade) = mod_gl_utils_color_8_to_sdl (look->style.system_color.bg);
 }
 
 /*
  * Draws a font on the screen, at a given position
  */
 void
-mod_gl_utils_draw_system_text (MOD_GL_UTILS_CONTEXT * context, char *text,
-			       int x, int y)
+mod_gl_utils_draw_system_text (mod_gl_utils_context_t * context,
+			       lw6gui_look_t * look, char *text, int x, int y)
 {
   SDL_Color fg, shade;
 
-  system_colors (&fg, &shade, context);
+  system_colors (&fg, &shade, look);
   mod_gl_utils_set_render_mode_2d_blend (context);
 
 
@@ -176,7 +173,8 @@ mod_gl_utils_draw_system_text (MOD_GL_UTILS_CONTEXT * context, char *text,
 }
 
 void
-mod_gl_utils_draw_system_text_top_left (MOD_GL_UTILS_CONTEXT * context,
+mod_gl_utils_draw_system_text_top_left (mod_gl_utils_context_t * context,
+					lw6gui_look_t * look,
 					char **text_list)
 {
   int y;
@@ -184,7 +182,7 @@ mod_gl_utils_draw_system_text_top_left (MOD_GL_UTILS_CONTEXT * context,
   int h;
   SDL_Color fg, shade;
 
-  system_colors (&fg, &shade, context);
+  system_colors (&fg, &shade, look);
   mod_gl_utils_set_render_mode_2d_blend (context);
 
   y = 0;
@@ -203,7 +201,8 @@ mod_gl_utils_draw_system_text_top_left (MOD_GL_UTILS_CONTEXT * context,
 }
 
 void
-mod_gl_utils_draw_system_text_top_right (MOD_GL_UTILS_CONTEXT * context,
+mod_gl_utils_draw_system_text_top_right (mod_gl_utils_context_t * context,
+					 lw6gui_look_t * look,
 					 char **text_list)
 {
   int x;
@@ -212,7 +211,7 @@ mod_gl_utils_draw_system_text_top_right (MOD_GL_UTILS_CONTEXT * context,
   int h;
   SDL_Color fg, shade;
 
-  system_colors (&fg, &shade, context);
+  system_colors (&fg, &shade, look);
 
   mod_gl_utils_set_render_mode_2d_blend (context);
 
@@ -235,7 +234,8 @@ mod_gl_utils_draw_system_text_top_right (MOD_GL_UTILS_CONTEXT * context,
 }
 
 void
-mod_gl_utils_draw_system_text_bottom_left (MOD_GL_UTILS_CONTEXT * context,
+mod_gl_utils_draw_system_text_bottom_left (mod_gl_utils_context_t * context,
+					   lw6gui_look_t * look,
 					   char **text_list)
 {
   int y;
@@ -246,7 +246,7 @@ mod_gl_utils_draw_system_text_bottom_left (MOD_GL_UTILS_CONTEXT * context,
   char **list_end;
   SDL_Color fg, shade;
 
-  system_colors (&fg, &shade, context);
+  system_colors (&fg, &shade, look);
 
   mod_gl_utils_set_render_mode_2d_blend (context);
 
@@ -274,7 +274,8 @@ mod_gl_utils_draw_system_text_bottom_left (MOD_GL_UTILS_CONTEXT * context,
 }
 
 void
-mod_gl_utils_draw_system_text_bottom_right (MOD_GL_UTILS_CONTEXT * context,
+mod_gl_utils_draw_system_text_bottom_right (mod_gl_utils_context_t * context,
+					    lw6gui_look_t * look,
 					    char **text_list)
 {
   int x;
@@ -286,7 +287,7 @@ mod_gl_utils_draw_system_text_bottom_right (MOD_GL_UTILS_CONTEXT * context,
   char **list_end;
   SDL_Color fg, shade;
 
-  system_colors (&fg, &shade, context);
+  system_colors (&fg, &shade, look);
 
   mod_gl_utils_set_render_mode_2d_blend (context);
 
