@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,14 +31,14 @@
  * fighters here" is done.
  */
 static void
-update_game_surface (MOD_GL_UTILS_CONTEXT * utils_context,
+update_game_surface (mod_gl_utils_context_t * utils_context,
 		     SDL_Surface * surface,
-		     LW6KER_GAME_STATE * game_state,
-		     LW6GFX_GAME_LOOK * game_look, int layer_id,
+		     lw6ker_game_state_t * game_state,
+		     lw6gui_look_t * look, int layer_id,
 		     int x0, int y0, int w, int h)
 {
   int x, y, x1, y1, fighter_id;
-  LW6KER_FIGHTER *fighter;
+  lw6ker_fighter_t *fighter;
 
   x1 = x0 + w;
   y1 = y0 + h;
@@ -46,11 +47,11 @@ update_game_surface (MOD_GL_UTILS_CONTEXT * utils_context,
       for (y = y0; y < y1; ++y)
 	{
 	  fighter_id =
-	    lw6ker_map_state_get_fighter_id (&(game_state->map), layer_id, x,
-					     y);
+	    lw6ker_map_state_get_fighter_id (&(game_state->map_state),
+					     layer_id, x, y);
 	  if (fighter_id >= 0)
 	    {
-	      fighter = &(game_state->map.armies.fighters[fighter_id]);
+	      fighter = &(game_state->map_state.armies.fighters[fighter_id]);
 	      mod_gl_utils_putpixel (surface, x - x0, y - y0,
 				     mod_gl_utils_get_shaded_color_for_fighter
 				     (utils_context, fighter->team_id,
@@ -65,18 +66,18 @@ update_game_surface (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_utils_update_game_texture (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_utils_update_game_texture (mod_gl_utils_context_t * utils_context,
 				  SDL_Surface * surface,
 				  GLuint texture,
-				  LW6KER_GAME_STATE * game_state,
-				  LW6MAP_PARAM * map_param,
-				  LW6GFX_GAME_LOOK * game_look, int layer_id)
+				  lw6ker_game_state_t * game_state,
+				  lw6map_param_t * map_param,
+				  lw6gui_look_t * look, int layer_id)
 {
   mod_gl_utils_update_team_color_map (&(utils_context->team_color_map),
 				      &(map_param->style));
-  update_game_surface (utils_context, surface, game_state, game_look,
-		       layer_id, 0, 0, game_state->map.shape.w,
-		       game_state->map.shape.h);
+  update_game_surface (utils_context, surface, game_state, look,
+		       layer_id, 0, 0, game_state->map_state.shape.w,
+		       game_state->map_state.shape.h);
   /*
    * Using this instead of creating a new texture from a surface using
    * glTexImage2D (surface2texture) is important, for performance.
@@ -88,15 +89,15 @@ mod_gl_utils_update_game_texture (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_utils_update_game_texture_array (MOD_GL_UTILS_CONTEXT * utils_context,
-					MOD_GL_UTILS_SURFACE_ARRAY *
+mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
+					utils_context,
+					mod_gl_utils_surface_array_t *
 					surface_array,
-					MOD_GL_UTILS_TEXTURE_ARRAY *
+					mod_gl_utils_texture_array_t *
 					texture_array,
-					LW6KER_GAME_STATE * game_state,
-					LW6MAP_PARAM * map_param,
-					LW6GFX_GAME_LOOK * game_look,
-					int layer_id)
+					lw6ker_game_state_t * game_state,
+					lw6map_param_t * map_param,
+					lw6gui_look_t * look, int layer_id)
 {
   int n_x, n_y;
 
@@ -120,7 +121,7 @@ mod_gl_utils_update_game_texture_array (MOD_GL_UTILS_CONTEXT * utils_context,
 	      update_game_surface (utils_context,
 				   mod_gl_utils_get_surface_array_surface
 				   (surface_array, n_x, n_y), game_state,
-				   game_look, layer_id,
+				   look, layer_id,
 				   surface_array->layout.x0[n_x],
 				   surface_array->layout.y0[n_y],
 				   surface_array->layout.w[n_x],
