@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,12 +34,12 @@
  * Very slow, we don't care, for debugging only.
  */
 SDL_Surface *
-mod_gl_utils_create_gradient_surface (MOD_GL_UTILS_CONTEXT * utils_context,
-				      LW6KER_MAP_STATE * map_state,
+mod_gl_utils_create_gradient_surface (mod_gl_utils_context_t * utils_context,
+				      lw6ker_map_state_t * map_state,
 				      int team_id)
 {
   SDL_Surface *gradient_surface;
-  LW6SYS_COLOR_F color;
+  lw6sys_color_f_t color;
 
   gradient_surface =
     mod_gl_utils_create_surface (utils_context,
@@ -48,8 +49,8 @@ mod_gl_utils_create_gradient_surface (MOD_GL_UTILS_CONTEXT * utils_context,
     {
       int i;
       float grey;
-      LW6KER_ZONE_STRUCT *zone;
-      LW6KER_TEAM *team;
+      lw6ker_zone_struct_t *zone;
+      lw6ker_team_t *team;
       int pot_min = 0;
       int pot_max = 0;
 
