@@ -1,23 +1,23 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include <string.h>
@@ -32,18 +32,15 @@ Contact author        : ufoot@ufoot.org
  * Pointer must be freed.
  */
 static char *
-create_button_key (char *text, int select)
+create_button_key (lw6gui_look_t * look, lw6gui_menuitem_t * menuitem)
 {
   char *key;
-  int length;
+  int c1, c2;
 
-  length = strlen (text) + 1 + 33;	// ':' + maxlength("%d")
-  key = (char *) LW6SYS_MALLOC ((length + 1) * sizeof (char));
-  if (key != NULL)
-    {
-      snprintf (key, length + 1, "%d:%s", select, text);
-      key[length] = '\0';
-    }
+  c1 = lw6sys_checksum ((unsigned char *) look, sizeof (lw6gui_look_t));
+  c2 =
+    lw6sys_checksum ((unsigned char *) menuitem, sizeof (lw6gui_menuitem_t));
+  key = lw6sys_new_sprintf ("%d %d", c1, c2);
 
   return key;
 }
@@ -52,11 +49,12 @@ create_button_key (char *text, int select)
  * Store a button bitmap in the menucache. Returns != 0 if successfull.
  */
 int
-mod_gl_utils_store_button_in_menucache (MOD_GL_UTILS_CONTEXT * context,
-					char *text, int select,
+mod_gl_utils_store_button_in_menucache (mod_gl_utils_context_t * context,
+					lw6gui_look_t * look,
+					lw6gui_menuitem_t * menuitem,
 					SDL_Surface * surface)
 {
-  MOD_GL_UTILS_MENUCACHE_ARRAY *menucache_array;
+  mod_gl_utils_menucache_array_t *menucache_array;
   int ret = 0;
   int i;
   char *key;
@@ -80,7 +78,7 @@ mod_gl_utils_store_button_in_menucache (MOD_GL_UTILS_CONTEXT * context,
       menucache_array->item_array[i].surface = NULL;
     }
 
-  key = create_button_key (text, select);
+  key = create_button_key (look, menuitem);
   if (key != NULL)
     {
       ret = 1;
@@ -95,17 +93,18 @@ mod_gl_utils_store_button_in_menucache (MOD_GL_UTILS_CONTEXT * context,
  * Gets a button bitmap from the menucache. Returns non NULL if successfull.
  */
 SDL_Surface *
-mod_gl_utils_get_button_from_menucache (MOD_GL_UTILS_CONTEXT * context,
-					char *text, int select)
+mod_gl_utils_get_button_from_menucache (mod_gl_utils_context_t * context,
+					lw6gui_look_t * look,
+					lw6gui_menuitem_t * menuitem)
 {
-  MOD_GL_UTILS_MENUCACHE_ARRAY *menucache_array;
+  mod_gl_utils_menucache_array_t *menucache_array;
   SDL_Surface *surface = NULL;
   int i;
   char *key;
 
   menucache_array = &(context->menucache_array);
 
-  key = create_button_key (text, select);
+  key = create_button_key (look, menuitem);
 
   if (key != NULL)
     {
@@ -131,9 +130,9 @@ mod_gl_utils_get_button_from_menucache (MOD_GL_UTILS_CONTEXT * context,
  * Clear the cache (usefull when quiting the program).
  */
 void
-mod_gl_utils_clear_menucache (MOD_GL_UTILS_CONTEXT * context)
+mod_gl_utils_clear_menucache (mod_gl_utils_context_t * context)
 {
-  MOD_GL_UTILS_MENUCACHE_ARRAY *menucache_array;
+  mod_gl_utils_menucache_array_t *menucache_array;
   int i;
   char *key;
   SDL_Surface *surface;
@@ -152,5 +151,5 @@ mod_gl_utils_clear_menucache (MOD_GL_UTILS_CONTEXT * context)
 	}
     }
 
-  memset (menucache_array, 0, sizeof (MOD_GL_UTILS_MENUCACHE_ARRAY));
+  memset (menucache_array, 0, sizeof (mod_gl_utils_menucache_array_t));
 }
