@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,9 +22,7 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-
 #include <GL/glu.h>
 #include <SDL/SDL_image.h>
 
@@ -36,8 +35,8 @@
  * Initialize display.
  */
 int
-mod_gl_utils_set_video_mode (MOD_GL_UTILS_CONTEXT * utils_context, int width,
-			     int height, int fullscreen,
+mod_gl_utils_set_video_mode (mod_gl_utils_context_t * utils_context,
+			     int width, int height, int fullscreen,
 			     void (*resize_callback) (int width, int height,
 						      int fullscreen))
 {
@@ -56,7 +55,7 @@ mod_gl_utils_set_video_mode (MOD_GL_UTILS_CONTEXT * utils_context, int width,
   if (!info)
     {
       /* This should probably never happen. */
-      lw6sys_log (LW6SYS_LOG_ERROR, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_ERROR,
 		  _("SDL GetVideoInfo failed: \"%s\""), SDL_GetError ());
       fflush (stderr);
       return 0;
@@ -98,7 +97,7 @@ mod_gl_utils_set_video_mode (MOD_GL_UTILS_CONTEXT * utils_context, int width,
        * including DISPLAY not being set, the specified
        * resolution not being available, etc.
        */
-      lw6sys_log (LW6SYS_LOG_ERROR, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_ERROR,
 		  _("SDL SetVideoMode %dx%d failed: \"%s\""), width,
 		  height, SDL_GetError ());
       fflush (stderr);
@@ -107,7 +106,7 @@ mod_gl_utils_set_video_mode (MOD_GL_UTILS_CONTEXT * utils_context, int width,
   else
     {
       glViewport (0, 0, width, height);	// required by some drivers
-      lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("SDL SetVideoMode %dx%d"),
+      lw6sys_log (LW6SYS_LOG_INFO, _("SDL SetVideoMode %dx%d"),
 		  width, height);
       utils_context->screen.width = width;
       utils_context->screen.height = height;
@@ -118,31 +117,32 @@ mod_gl_utils_set_video_mode (MOD_GL_UTILS_CONTEXT * utils_context, int width,
 		     &(utils_context->caps.max_texture_size));
       if (!utils_context->caps.max_texture_size)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _("unable to get MAX_TEXTURE_SIZE"));
 	  utils_context->caps.max_texture_size = 512;
 	}
     }
 
-  SDL_WM_SetCaption (PACKAGE_STRING, PACKAGE_TARNAME);
+  SDL_WM_SetCaption (lw6sys_build_get_package_string (),
+		     lw6sys_build_get_package_tarname ());
 
-  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("%d BPP"),
+  lw6sys_log (LW6SYS_LOG_INFO, _("%d BPP"),
 	      SDL_GetVideoSurface ()->format->BitsPerPixel);
-  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("OpenGL vendor \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _("OpenGL vendor \"%s\""),
 	      glGetString (GL_VENDOR));
-  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("OpenGL renderer \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _("OpenGL renderer \"%s\""),
 	      glGetString (GL_RENDERER));
-  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("OpenGL version \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _("OpenGL version \"%s\""),
 	      glGetString (GL_VERSION));
 
-  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl",
+  lw6sys_log (LW6SYS_LOG_INFO,
 	      _("OpenGL MAX_TEXTURE_SIZE = %d"),
 	      utils_context->caps.max_texture_size);
 
   if (utils_context->caps.max_texture_size <
       MOD_GL_UTILS_REQUIRED_TEXTURE_SIZE)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("OpenGL driver only handles %dx%d textures when %dx%d textures are needed"),
 		  utils_context->caps.max_texture_size,
@@ -151,6 +151,11 @@ mod_gl_utils_set_video_mode (MOD_GL_UTILS_CONTEXT * utils_context, int width,
 		  MOD_GL_UTILS_REQUIRED_TEXTURE_SIZE);
     }
 
+  /*
+   * Call this function to be sure we're truely in some known mode
+   */
+  mod_gl_utils_set_render_mode_2d (utils_context);
+
   return 1;
 }
 
@@ -159,7 +164,7 @@ mod_gl_utils_set_video_mode (MOD_GL_UTILS_CONTEXT * utils_context, int width,
  * Called whenever window resize is asked for.
  */
 int
-mod_gl_utils_resize_video_mode (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_utils_resize_video_mode (mod_gl_utils_context_t * utils_context,
 				int width, int height)
 {
   int ret = 0;
@@ -176,7 +181,7 @@ mod_gl_utils_resize_video_mode (MOD_GL_UTILS_CONTEXT * utils_context,
       if (SDL_SetVideoMode (width, height, utils_context->screen.bpp, flags)
 	  == 0)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _("unable to resize screen %dx%d"), width, height);
 	}
       else
@@ -193,7 +198,7 @@ mod_gl_utils_resize_video_mode (MOD_GL_UTILS_CONTEXT * utils_context,
 					      fullscreen);
 	    }
 
-	  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl",
+	  lw6sys_log (LW6SYS_LOG_INFO,
 		      _("resizing screen %dx%d"), width, height);
 
 	  ret = 1;
@@ -209,3 +214,18 @@ mod_gl_utils_resize_video_mode (MOD_GL_UTILS_CONTEXT * utils_context,
 
   return ret;
 }
+
+int
+mod_gl_utils_get_video_mode (mod_gl_utils_context_t * utils_context,
+			     int *width, int *height, int *fullscreen)
+{
+  int ret = 0;
+
+  (*width) = utils_context->screen.width;
+  (*height) = utils_context->screen.height;
+  (*fullscreen) = utils_context->screen.fullscreen;
+
+  ret = 1;
+
+  return ret;
+}
