@@ -1,23 +1,23 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include <stdio.h>
@@ -30,9 +30,9 @@ Contact author        : ufoot@ufoot.org
 #include "gl-utils-internal.h"
 
 int
-mod_gl_utils_rect_array_init (MOD_GL_UTILS_CONTEXT *
+mod_gl_utils_rect_array_init (mod_gl_utils_context_t *
 			      utils_context,
-			      MOD_GL_UTILS_RECT_ARRAY * rect_array, int w,
+			      mod_gl_utils_rect_array_t * rect_array, int w,
 			      int h, int tile_size)
 {
   int ret = 0;
@@ -78,7 +78,7 @@ mod_gl_utils_rect_array_init (MOD_GL_UTILS_CONTEXT *
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("rect_array dimensions are incorrect, w=%d, h=%d, tile_size=%d, last_w=%d, last_h=%d"),
 		      w, h, tile_size, rect_array->w[n_w - 1],
@@ -94,9 +94,9 @@ mod_gl_utils_rect_array_init (MOD_GL_UTILS_CONTEXT *
 }
 
 void
-mod_gl_utils_rect_array_clear (MOD_GL_UTILS_CONTEXT *
+mod_gl_utils_rect_array_clear (mod_gl_utils_context_t *
 			       utils_context,
-			       MOD_GL_UTILS_RECT_ARRAY * rect_array)
+			       mod_gl_utils_rect_array_t * rect_array)
 {
   if (rect_array->x0)
     {
@@ -114,5 +114,5 @@ mod_gl_utils_rect_array_clear (MOD_GL_UTILS_CONTEXT *
     {
       LW6SYS_FREE (rect_array->h);
     }
-  memset (rect_array, 0, sizeof (MOD_GL_UTILS_RECT_ARRAY));
+  memset (rect_array, 0, sizeof (mod_gl_utils_rect_array_t));
 }
