@@ -1,27 +1,26 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include <stdio.h>
-
 #include <GL/glu.h>
 
 #include "config.h"
@@ -43,7 +42,8 @@ basic_cleanup ()
  * Prepares OpenGL buffer for a new draw.
  */
 void
-mod_gl_utils_prepare_buffer (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_prepare_buffer (mod_gl_utils_context_t * utils_context,
+			     lw6gui_look_t * look)
 {
   glViewport (0, 0, utils_context->screen.width, utils_context->screen.height);	// required by some drivers
   glClearColor (0.0f, 0.0f, 0.0f, 0.0f);
@@ -51,16 +51,17 @@ mod_gl_utils_prepare_buffer (MOD_GL_UTILS_CONTEXT * utils_context)
 }
 
 void
-mod_gl_prepare_buffer (void *utils_context)
+mod_gl_prepare_buffer (void *utils_context, lw6gui_look_t * look)
 {
-  mod_gl_utils_prepare_buffer ((MOD_GL_UTILS_CONTEXT *) utils_context);
+  mod_gl_utils_prepare_buffer ((mod_gl_utils_context_t *) utils_context,
+			       look);
 }
 
 /*
  * Liquid War 6 uses a double buffer, this function swaps them.
  */
 void
-mod_gl_utils_swap_buffers (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_swap_buffers (mod_gl_utils_context_t * utils_context)
 {
   glFinish ();
   SDL_GL_SwapBuffers ();
@@ -71,11 +72,11 @@ mod_gl_utils_swap_buffers (MOD_GL_UTILS_CONTEXT * utils_context)
 void
 mod_gl_swap_buffers (void *utils_context)
 {
-  mod_gl_utils_swap_buffers ((MOD_GL_UTILS_CONTEXT *) utils_context);
+  mod_gl_utils_swap_buffers ((mod_gl_utils_context_t *) utils_context);
 }
 
 void
-mod_gl_utils_set_render_mode_2d (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_set_render_mode_2d (mod_gl_utils_context_t * utils_context)
 {
   basic_cleanup ();
   if (utils_context->render_mode != MOD_GL_UTILS_RENDER_2D)
@@ -98,7 +99,7 @@ mod_gl_utils_set_render_mode_2d (MOD_GL_UTILS_CONTEXT * utils_context)
 }
 
 void
-mod_gl_utils_set_render_mode_2d_blend (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_set_render_mode_2d_blend (mod_gl_utils_context_t * utils_context)
 {
   basic_cleanup ();
   if (utils_context->render_mode != MOD_GL_UTILS_RENDER_2D_BLEND)
@@ -122,7 +123,7 @@ mod_gl_utils_set_render_mode_2d_blend (MOD_GL_UTILS_CONTEXT * utils_context)
 }
 
 void
-mod_gl_utils_set_render_mode_3d_map (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_set_render_mode_3d_map (mod_gl_utils_context_t * utils_context)
 {
   basic_cleanup ();
   if (utils_context->render_mode != MOD_GL_UTILS_RENDER_3D_MAP)
@@ -145,7 +146,7 @@ mod_gl_utils_set_render_mode_3d_map (MOD_GL_UTILS_CONTEXT * utils_context)
 }
 
 void
-mod_gl_utils_set_render_mode_3d_menu (MOD_GL_UTILS_CONTEXT * utils_context)
+mod_gl_utils_set_render_mode_3d_menu (mod_gl_utils_context_t * utils_context)
 {
   basic_cleanup ();
   if (utils_context->render_mode != MOD_GL_UTILS_RENDER_3D_MENU)
@@ -168,7 +169,7 @@ mod_gl_utils_set_render_mode_3d_menu (MOD_GL_UTILS_CONTEXT * utils_context)
 }
 
 void
-mod_gl_utils_set_render_mode_3d_pick (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_utils_set_render_mode_3d_pick (mod_gl_utils_context_t * utils_context,
 				      int x, int y)
 {
   GLint viewport[4];
@@ -195,3 +196,26 @@ mod_gl_utils_set_render_mode_3d_pick (MOD_GL_UTILS_CONTEXT * utils_context,
       utils_context->render_mode = MOD_GL_UTILS_RENDER_3D_PICK;
     }
 }
+
+void
+mod_gl_utils_set_render_mode_3d_warp (mod_gl_utils_context_t * utils_context)
+{
+  basic_cleanup ();
+  if (utils_context->render_mode != MOD_GL_UTILS_RENDER_3D_WARP)
+    {
+      glMatrixMode (GL_PROJECTION);
+      glLoadIdentity ();
+
+      gluPerspective (utils_context->const_data.persp_fovy,
+		      ((float) utils_context->screen.width) /
+		      ((float) utils_context->screen.height),
+		      utils_context->const_data.persp_znear,
+		      utils_context->const_data.persp_zfar);
+      glDisable (GL_DEPTH_TEST);
+      glDisable (GL_DEPTH);
+      glDisable (GL_BLEND);
+      glDisable (GL_LIGHTING);
+
+      utils_context->render_mode = MOD_GL_UTILS_RENDER_3D_WARP;
+    }
+}
