@@ -1,28 +1,27 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include <stdio.h>
 #include <string.h>
-
 #include <GL/glu.h>
 
 #include "config.h"
@@ -31,9 +30,9 @@ Contact author        : ufoot@ufoot.org
 #include "gl-utils-internal.h"
 
 int
-mod_gl_utils_surface_array_init (MOD_GL_UTILS_CONTEXT *
+mod_gl_utils_surface_array_init (mod_gl_utils_context_t *
 				 utils_context,
-				 MOD_GL_UTILS_SURFACE_ARRAY * surface_array,
+				 mod_gl_utils_surface_array_t * surface_array,
 				 int w, int h, int tile_size)
 {
   int ret = 0;
@@ -69,7 +68,7 @@ mod_gl_utils_surface_array_init (MOD_GL_UTILS_CONTEXT *
 		  else
 		    {
 		      ret = 0;
-		      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+		      lw6sys_log (LW6SYS_LOG_WARNING,
 				  _
 				  ("surface %d,%d of surface array couldn't be created, array is broken"),
 				  n_x, n_y);
@@ -92,9 +91,9 @@ mod_gl_utils_surface_array_init (MOD_GL_UTILS_CONTEXT *
 }
 
 int
-mod_gl_utils_surface_array_init_from_surface (MOD_GL_UTILS_CONTEXT *
+mod_gl_utils_surface_array_init_from_surface (mod_gl_utils_context_t *
 					      utils_context,
-					      MOD_GL_UTILS_SURFACE_ARRAY *
+					      mod_gl_utils_surface_array_t *
 					      surface_array,
 					      SDL_Surface * surface,
 					      int tile_size)
@@ -145,16 +144,17 @@ mod_gl_utils_surface_array_init_from_surface (MOD_GL_UTILS_CONTEXT *
 }
 
 int
-mod_gl_utils_surface_array_init_from_map (MOD_GL_UTILS_CONTEXT *
+mod_gl_utils_surface_array_init_from_map (mod_gl_utils_context_t *
 					  utils_context,
-					  MOD_GL_UTILS_SURFACE_ARRAY *
+					  mod_gl_utils_surface_array_t *
 					  surface_array,
-					  LW6MAP_MAP * map, int tile_size)
+					  lw6map_level_t * level,
+					  int tile_size)
 {
   int ret = 0;
   SDL_Surface *surface;
 
-  surface = mod_gl_utils_map2surface (utils_context, map);
+  surface = mod_gl_utils_map2surface (utils_context, level);
   if (surface)
     {
       ret = mod_gl_utils_surface_array_init_from_surface (utils_context,
@@ -167,8 +167,9 @@ mod_gl_utils_surface_array_init_from_map (MOD_GL_UTILS_CONTEXT *
 }
 
 void
-mod_gl_utils_surface_array_clear (MOD_GL_UTILS_CONTEXT * utils_context,
-				  MOD_GL_UTILS_SURFACE_ARRAY * surface_array)
+mod_gl_utils_surface_array_clear (mod_gl_utils_context_t * utils_context,
+				  mod_gl_utils_surface_array_t *
+				  surface_array)
 {
   int i;
   if (surface_array->surfaces != NULL)
