@@ -1,28 +1,27 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include <stdio.h>
 #include <string.h>
-
 #include <GL/glu.h>
 
 #include "config.h"
@@ -76,7 +75,7 @@ mod_gl_utils_texture_scale (int size)
  * Transforms an SDL bitmap into a proper GL texture.
  */
 static GLuint
-surface2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context,
+surface2texture_xywh (mod_gl_utils_context_t * gfx_context,
 		      SDL_Surface * surface, int x, int y, int w, int h)
 {
   GLuint texture = 0;
@@ -90,7 +89,7 @@ surface2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context,
   if (w > gfx_context->caps.max_texture_size ||
       h > gfx_context->caps.max_texture_size)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("texture is too big (%dx%d) for OpenGL driver (accepts %dx%d)"),
 		  w, h, gfx_context->caps.max_texture_size,
@@ -149,7 +148,7 @@ surface2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to generate texture from surface"));
     }
 
@@ -162,8 +161,8 @@ surface2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context,
  * Transforms an SDL bitmap into a proper GL texture.
  */
 static GLuint
-surface2texture_wh (MOD_GL_UTILS_CONTEXT * gfx_context, SDL_Surface * surface,
-		    int w, int h)
+surface2texture_wh (mod_gl_utils_context_t * gfx_context,
+		    SDL_Surface * surface, int w, int h)
 {
   return surface2texture_xywh (gfx_context, surface, 0, 0, w, h);
 }
@@ -172,7 +171,7 @@ surface2texture_wh (MOD_GL_UTILS_CONTEXT * gfx_context, SDL_Surface * surface,
  * Transforms an SDL bitmap into a proper GL texture.
  */
 static GLuint
-surface2texture (MOD_GL_UTILS_CONTEXT * gfx_context, SDL_Surface * surface)
+surface2texture (mod_gl_utils_context_t * gfx_context, SDL_Surface * surface)
 {
   int w, h;
 
@@ -187,7 +186,7 @@ surface2texture (MOD_GL_UTILS_CONTEXT * gfx_context, SDL_Surface * surface)
  * Converts a surface to a texture. Public wrapper function.
  */
 GLuint
-mod_gl_utils_surface2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context,
+mod_gl_utils_surface2texture_xywh (mod_gl_utils_context_t * gfx_context,
 				   SDL_Surface * surface, int x, int y, int w,
 				   int h)
 {
@@ -202,7 +201,7 @@ mod_gl_utils_surface2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context,
  * Converts a surface to a texture. Public wrapper function.
  */
 GLuint
-mod_gl_utils_surface2texture_wh (MOD_GL_UTILS_CONTEXT * gfx_context,
+mod_gl_utils_surface2texture_wh (mod_gl_utils_context_t * gfx_context,
 				 SDL_Surface * surface, int w, int h)
 {
   GLuint texture;
@@ -216,7 +215,7 @@ mod_gl_utils_surface2texture_wh (MOD_GL_UTILS_CONTEXT * gfx_context,
  * Converts a surface to a texture. Public wrapper function.
  */
 GLuint
-mod_gl_utils_surface2texture (MOD_GL_UTILS_CONTEXT * gfx_context,
+mod_gl_utils_surface2texture (mod_gl_utils_context_t * gfx_context,
 			      SDL_Surface * surface)
 {
   GLuint texture;
@@ -230,8 +229,8 @@ mod_gl_utils_surface2texture (MOD_GL_UTILS_CONTEXT * gfx_context,
  * Transforms an SDL bitmap into a proper GL texture.
  */
 static GLuint
-map2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context, LW6MAP_MAP * map, int x,
-		  int y, int w, int h)
+map2texture_xywh (mod_gl_utils_context_t * gfx_context,
+		  lw6map_level_t * level, int x, int y, int w, int h)
 {
   GLuint texture = 0;
   SDL_Surface *image;
@@ -239,7 +238,7 @@ map2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context, LW6MAP_MAP * map, int x,
   if (w > gfx_context->caps.max_texture_size ||
       h > gfx_context->caps.max_texture_size)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("map is too big (%dx%d) to be texturized by OpenGL driver"),
 		  w, h);
@@ -248,7 +247,7 @@ map2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context, LW6MAP_MAP * map, int x,
   w = mod_gl_utils_power_of_two_ge (w);
   h = mod_gl_utils_power_of_two_ge (h);
 
-  image = mod_gl_utils_map2surface_xywh (gfx_context, map, x, y, w, h);
+  image = mod_gl_utils_map2surface_xywh (gfx_context, level, x, y, w, h);
 
   if (image)
     {
@@ -271,7 +270,7 @@ map2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context, LW6MAP_MAP * map, int x,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to generate texture from map"));
     }
 
@@ -279,53 +278,54 @@ map2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context, LW6MAP_MAP * map, int x,
 }
 
 static GLuint
-map2texture_wh (MOD_GL_UTILS_CONTEXT * gfx_context, LW6MAP_MAP * map, int w,
-		int h)
+map2texture_wh (mod_gl_utils_context_t * gfx_context, lw6map_level_t * level,
+		int w, int h)
 {
-  return map2texture_xywh (gfx_context, map, 0, 0, w, h);
+  return map2texture_xywh (gfx_context, level, 0, 0, w, h);
 }
 
 static GLuint
-map2texture (MOD_GL_UTILS_CONTEXT * gfx_context, LW6MAP_MAP * map)
+map2texture (mod_gl_utils_context_t * gfx_context, lw6map_level_t * level)
 {
   int w, h;
 
   /* Use the map width and height expanded to powers of 2 */
-  w = mod_gl_utils_power_of_two_ge (map->texture.shape.w);
-  h = mod_gl_utils_power_of_two_ge (map->texture.shape.h);
+  w = mod_gl_utils_power_of_two_ge (level->texture.shape.w);
+  h = mod_gl_utils_power_of_two_ge (level->texture.shape.h);
 
-  return map2texture_wh (gfx_context, map, w, h);
+  return map2texture_wh (gfx_context, level, w, h);
 }
 
 GLuint
-mod_gl_utils_map2texture_xywh (MOD_GL_UTILS_CONTEXT * gfx_context,
-			       LW6MAP_MAP * map, int x, int y, int w, int h)
+mod_gl_utils_map2texture_xywh (mod_gl_utils_context_t * gfx_context,
+			       lw6map_level_t * level, int x, int y, int w,
+			       int h)
 {
   GLuint texture;
 
-  texture = map2texture_xywh (gfx_context, map, x, y, w, h);
+  texture = map2texture_xywh (gfx_context, level, x, y, w, h);
 
   return (int) texture;
 }
 
 GLuint
-mod_gl_utils_map2texture_wh (MOD_GL_UTILS_CONTEXT * gfx_context,
-			     LW6MAP_MAP * map, int w, int h)
+mod_gl_utils_map2texture_wh (mod_gl_utils_context_t * gfx_context,
+			     lw6map_level_t * level, int w, int h)
 {
   GLuint texture;
 
-  texture = map2texture_wh (gfx_context, map, w, h);
+  texture = map2texture_wh (gfx_context, level, w, h);
 
   return (int) texture;
 }
 
 GLuint
-mod_gl_utils_map2texture (MOD_GL_UTILS_CONTEXT * gfx_context,
-			  LW6MAP_MAP * map)
+mod_gl_utils_map2texture (mod_gl_utils_context_t * gfx_context,
+			  lw6map_level_t * level)
 {
   GLuint texture;
 
-  texture = map2texture (gfx_context, map);
+  texture = map2texture (gfx_context, level);
 
   return (int) texture;
 }
@@ -340,7 +340,7 @@ mod_gl_utils_map2texture (MOD_GL_UTILS_CONTEXT * gfx_context,
  * use mod_gl_utils_schedule_delete_texture instead.
  */
 void
-mod_gl_utils_delete_texture (MOD_GL_UTILS_CONTEXT * gfx_context,
+mod_gl_utils_delete_texture (mod_gl_utils_context_t * gfx_context,
 			     GLuint texture)
 {
   if (glIsTexture ((GLuint) texture))
@@ -350,7 +350,7 @@ mod_gl_utils_delete_texture (MOD_GL_UTILS_CONTEXT * gfx_context,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  "trying to delete texture, but it isn't a texture");
     }
 }
@@ -359,7 +359,7 @@ mod_gl_utils_delete_texture (MOD_GL_UTILS_CONTEXT * gfx_context,
  * Schedules a texture to be deleted by mod_gl_utils_flush_delete_texture
  */
 void
-mod_gl_utils_schedule_delete_texture (MOD_GL_UTILS_CONTEXT * gfx_context,
+mod_gl_utils_schedule_delete_texture (mod_gl_utils_context_t * gfx_context,
 				      GLuint texture)
 {
   GLuint *texture_ptr = NULL;
@@ -368,7 +368,7 @@ mod_gl_utils_schedule_delete_texture (MOD_GL_UTILS_CONTEXT * gfx_context,
   if (texture_ptr)
     {
       *texture_ptr = texture;
-      lw6sys_list_push (&(gfx_context->texture_data.to_delete),
+      lw6sys_lifo_push (&(gfx_context->texture_data.to_delete),
 			(void *) texture_ptr);
     }
 }
@@ -377,14 +377,14 @@ mod_gl_utils_schedule_delete_texture (MOD_GL_UTILS_CONTEXT * gfx_context,
  * Deletes all textures scheduled for delete.
  */
 void
-mod_gl_utils_delete_scheduled_textures (MOD_GL_UTILS_CONTEXT * gfx_context)
+mod_gl_utils_delete_scheduled_textures (mod_gl_utils_context_t * gfx_context)
 {
   GLuint *texture_ptr = NULL;
 
   while (!lw6sys_list_is_empty (gfx_context->texture_data.to_delete))
     {
       texture_ptr =
-	(GLuint *) lw6sys_list_pop (&(gfx_context->texture_data.to_delete));
+	(GLuint *) lw6sys_lifo_pop (&(gfx_context->texture_data.to_delete));
       if (texture_ptr != NULL)
 	{
 	  mod_gl_utils_delete_texture (gfx_context, *texture_ptr);
@@ -394,7 +394,7 @@ mod_gl_utils_delete_scheduled_textures (MOD_GL_UTILS_CONTEXT * gfx_context)
 }
 
 void
-mod_gl_utils_texture_update (MOD_GL_UTILS_CONTEXT *
+mod_gl_utils_texture_update (mod_gl_utils_context_t *
 			     utils_context,
 			     GLuint texture, SDL_Surface * surface)
 {
