@@ -1,28 +1,27 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include <stdio.h>
 #include <string.h>
-
 #include <GL/glu.h>
 
 #include "config.h"
@@ -31,9 +30,9 @@ Contact author        : ufoot@ufoot.org
 #include "gl-utils-internal.h"
 
 int
-mod_gl_utils_texture_array_init (MOD_GL_UTILS_CONTEXT *
+mod_gl_utils_texture_array_init (mod_gl_utils_context_t *
 				 utils_context,
-				 MOD_GL_UTILS_TEXTURE_ARRAY * texture_array,
+				 mod_gl_utils_texture_array_t * texture_array,
 				 int w, int h, int tile_size)
 {
   int ret = 0;
@@ -73,7 +72,7 @@ mod_gl_utils_texture_array_init (MOD_GL_UTILS_CONTEXT *
 		      else
 			{
 			  ret = 0;
-			  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+			  lw6sys_log (LW6SYS_LOG_WARNING,
 				      _
 				      ("texture %d,%d of texture array couldn't be created, array is broken"),
 				      n_x, n_y);
@@ -83,7 +82,7 @@ mod_gl_utils_texture_array_init (MOD_GL_UTILS_CONTEXT *
 		  else
 		    {
 		      ret = 0;
-		      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+		      lw6sys_log (LW6SYS_LOG_WARNING,
 				  _
 				  ("surface %d,%d of texture array couldn't be created, array is broken"),
 				  n_x, n_y);
@@ -105,10 +104,12 @@ mod_gl_utils_texture_array_init (MOD_GL_UTILS_CONTEXT *
 }
 
 void
-mod_gl_utils_texture_array_update (MOD_GL_UTILS_CONTEXT *
+mod_gl_utils_texture_array_update (mod_gl_utils_context_t *
 				   utils_context,
-				   MOD_GL_UTILS_TEXTURE_ARRAY * texture_array,
-				   MOD_GL_UTILS_SURFACE_ARRAY * surface_array)
+				   mod_gl_utils_texture_array_t *
+				   texture_array,
+				   mod_gl_utils_surface_array_t *
+				   surface_array)
 {
   int n_x, n_y;
 
@@ -129,7 +130,7 @@ mod_gl_utils_texture_array_update (MOD_GL_UTILS_CONTEXT *
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("surface array size (%d,%d) and texture array size (%d,%d) do not match, can't update"),
 		  surface_array->layout.n_w, surface_array->layout.n_h,
@@ -138,8 +139,9 @@ mod_gl_utils_texture_array_update (MOD_GL_UTILS_CONTEXT *
 }
 
 void
-mod_gl_utils_texture_array_clear (MOD_GL_UTILS_CONTEXT * utils_context,
-				  MOD_GL_UTILS_TEXTURE_ARRAY * texture_array)
+mod_gl_utils_texture_array_clear (mod_gl_utils_context_t * utils_context,
+				  mod_gl_utils_texture_array_t *
+				  texture_array)
 {
   int i;
 
@@ -164,8 +166,9 @@ mod_gl_utils_texture_array_clear (MOD_GL_UTILS_CONTEXT * utils_context,
  * usable 'till next redraw.
  */
 void
-sdl_utils_schedule_delete_texture_array (MOD_GL_UTILS_CONTEXT * utils_context,
-					 MOD_GL_UTILS_TEXTURE_ARRAY *
+sdl_utils_schedule_delete_texture_array (mod_gl_utils_context_t *
+					 utils_context,
+					 mod_gl_utils_texture_array_t *
 					 texture_array)
 {
   int i;
