@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,13 +31,13 @@
  * Finds a texture in the cache.
  */
 static GLuint
-find_in_cache (MOD_GL_UTILS_CONTEXT * context, int w, int h,
+find_in_cache (mod_gl_utils_context_t * context, int w, int h,
 	       char *str_key, int int_key)
 {
   GLuint texture = 0;
   int i;
-  MOD_GL_UTILS_TEXTURECACHE_ARRAY *texturecache_array;
-  MOD_GL_UTILS_TEXTURECACHE_ITEM *texturecache_item;
+  mod_gl_utils_texturecache_array_t *texturecache_array;
+  mod_gl_utils_texturecache_item_t *texturecache_item;
 
   texturecache_array = &(context->texturecache_array);
 
@@ -63,13 +63,12 @@ find_in_cache (MOD_GL_UTILS_CONTEXT * context, int w, int h,
  * Stores a texture in the cache. If the texture isn't defined, does nothing.
  */
 static void
-store_in_cache (MOD_GL_UTILS_CONTEXT * context, int w, int h,
+store_in_cache (mod_gl_utils_context_t * context, int w, int h,
 		char *str_key, int int_key, GLuint texture)
 {
   int i;
-  MOD_GL_UTILS_TEXTURECACHE_ARRAY *texturecache_array;
-  MOD_GL_UTILS_TEXTURECACHE_ITEM *texturecache_item;
-  int str_key_length = 0;
+  mod_gl_utils_texturecache_array_t *texturecache_array;
+  mod_gl_utils_texturecache_item_t *texturecache_item;
   char *str_key_copy = NULL;
 
   texturecache_array = &(context->texturecache_array);
@@ -86,16 +85,13 @@ store_in_cache (MOD_GL_UTILS_CONTEXT * context, int w, int h,
 	      texturecache_item->str_key == NULL &&
 	      texturecache_item->texture == 0)
 	    {
-	      str_key_length = strlen (str_key);
-	      str_key_copy = LW6SYS_MALLOC (str_key_length + 1);
+	      str_key_copy = lw6sys_str_copy (str_key);
 	      if (str_key_copy != NULL)
 		{
 		  texturecache_item->used = 1;
 		  texturecache_item->surface_w = w;
 		  texturecache_item->surface_h = h;
 		  texturecache_item->int_key = int_key;
-		  strncpy (str_key_copy, str_key, str_key_length + 1);
-		  str_key_copy[str_key_length] = '\0';
 		  texturecache_item->str_key = str_key_copy;
 		  texturecache_item->texture = texture;
 		  break;
@@ -113,9 +109,9 @@ store_in_cache (MOD_GL_UTILS_CONTEXT * context, int w, int h,
  * Converts a surface to a texture, but first searches it in the cache.
  */
 GLuint
-mod_gl_utils_surface2texture_xywh_using_cache (MOD_GL_UTILS_CONTEXT * context,
-					       SDL_Surface * surface, int x,
-					       int y, int w, int h,
+mod_gl_utils_surface2texture_xywh_using_cache (mod_gl_utils_context_t *
+					       context, SDL_Surface * surface,
+					       int x, int y, int w, int h,
 					       char *str_key, int int_key)
 {
   GLuint texture = 0;
@@ -135,7 +131,7 @@ mod_gl_utils_surface2texture_xywh_using_cache (MOD_GL_UTILS_CONTEXT * context,
 }
 
 GLuint
-mod_gl_utils_surface2texture_wh_using_cache (MOD_GL_UTILS_CONTEXT * context,
+mod_gl_utils_surface2texture_wh_using_cache (mod_gl_utils_context_t * context,
 					     SDL_Surface * surface, int w,
 					     int h, char *str_key,
 					     int int_key)
@@ -156,7 +152,7 @@ mod_gl_utils_surface2texture_wh_using_cache (MOD_GL_UTILS_CONTEXT * context,
 }
 
 GLuint
-mod_gl_utils_surface2texture_using_cache (MOD_GL_UTILS_CONTEXT * context,
+mod_gl_utils_surface2texture_using_cache (mod_gl_utils_context_t * context,
 					  SDL_Surface * surface,
 					  char *str_key, int int_key)
 {
@@ -179,22 +175,22 @@ mod_gl_utils_surface2texture_using_cache (MOD_GL_UTILS_CONTEXT * context,
  * Converts a map to a texture, but first searches it in the cache.
  */
 GLuint
-mod_gl_utils_map2texture_xywh_using_cache (MOD_GL_UTILS_CONTEXT * context,
-					   LW6MAP_MAP * map, int x, int y,
-					   int w, int h, char *str_key,
+mod_gl_utils_map2texture_xywh_using_cache (mod_gl_utils_context_t * context,
+					   lw6map_level_t * level, int x,
+					   int y, int w, int h, char *str_key,
 					   int int_key)
 {
   GLuint texture = 0;
 
   texture =
-    find_in_cache (context, map->texture.shape.w, map->texture.shape.h,
+    find_in_cache (context, level->texture.shape.w, level->texture.shape.h,
 		   str_key, int_key);
 
   if (!texture)
     {
-      texture = mod_gl_utils_map2texture_xywh (context, map, x, y, w, h);
+      texture = mod_gl_utils_map2texture_xywh (context, level, x, y, w, h);
 
-      store_in_cache (context, map->texture.shape.w, map->texture.shape.h,
+      store_in_cache (context, level->texture.shape.w, level->texture.shape.h,
 		      str_key, int_key, texture);
     }
 
@@ -202,21 +198,21 @@ mod_gl_utils_map2texture_xywh_using_cache (MOD_GL_UTILS_CONTEXT * context,
 }
 
 GLuint
-mod_gl_utils_map2texture_wh_using_cache (MOD_GL_UTILS_CONTEXT * context,
-					 LW6MAP_MAP * map, int w, int h,
+mod_gl_utils_map2texture_wh_using_cache (mod_gl_utils_context_t * context,
+					 lw6map_level_t * level, int w, int h,
 					 char *str_key, int int_key)
 {
   GLuint texture = 0;
 
   texture =
-    find_in_cache (context, map->texture.shape.w, map->texture.shape.h,
+    find_in_cache (context, level->texture.shape.w, level->texture.shape.h,
 		   str_key, int_key);
 
   if (!texture)
     {
-      texture = mod_gl_utils_map2texture_wh (context, map, w, h);
+      texture = mod_gl_utils_map2texture_wh (context, level, w, h);
 
-      store_in_cache (context, map->texture.shape.w, map->texture.shape.h,
+      store_in_cache (context, level->texture.shape.w, level->texture.shape.h,
 		      str_key, int_key, texture);
     }
 
@@ -224,21 +220,21 @@ mod_gl_utils_map2texture_wh_using_cache (MOD_GL_UTILS_CONTEXT * context,
 }
 
 GLuint
-mod_gl_utils_map2texture_using_cache (MOD_GL_UTILS_CONTEXT * context,
-				      LW6MAP_MAP * map, char *str_key,
+mod_gl_utils_map2texture_using_cache (mod_gl_utils_context_t * context,
+				      lw6map_level_t * level, char *str_key,
 				      int int_key)
 {
   GLuint texture = 0;
 
   texture =
-    find_in_cache (context, map->texture.shape.w, map->texture.shape.h,
+    find_in_cache (context, level->texture.shape.w, level->texture.shape.h,
 		   str_key, int_key);
 
   if (!texture)
     {
-      texture = mod_gl_utils_map2texture (context, map);
+      texture = mod_gl_utils_map2texture (context, level);
 
-      store_in_cache (context, map->texture.shape.w, map->texture.shape.h,
+      store_in_cache (context, level->texture.shape.w, level->texture.shape.h,
 		      str_key, int_key, texture);
     }
 
@@ -249,11 +245,11 @@ mod_gl_utils_map2texture_using_cache (MOD_GL_UTILS_CONTEXT * context,
  * Call this after each display, in case we need to clean up the cache.
  */
 extern void
-mod_gl_utils_optimize_texturecache (MOD_GL_UTILS_CONTEXT * context)
+mod_gl_utils_optimize_texturecache (mod_gl_utils_context_t * context)
 {
   int i;
-  MOD_GL_UTILS_TEXTURECACHE_ARRAY *texturecache_array;
-  MOD_GL_UTILS_TEXTURECACHE_ITEM *texturecache_item;
+  mod_gl_utils_texturecache_array_t *texturecache_array;
+  mod_gl_utils_texturecache_item_t *texturecache_item;
 
   texturecache_array = &(context->texturecache_array);
 
@@ -284,11 +280,11 @@ mod_gl_utils_optimize_texturecache (MOD_GL_UTILS_CONTEXT * context)
  * Call this when quitting the game.
  */
 extern void
-mod_gl_utils_clear_texturecache (MOD_GL_UTILS_CONTEXT * context)
+mod_gl_utils_clear_texturecache (mod_gl_utils_context_t * context)
 {
   int i;
-  MOD_GL_UTILS_TEXTURECACHE_ARRAY *texturecache_array;
-  MOD_GL_UTILS_TEXTURECACHE_ITEM *texturecache_item;
+  mod_gl_utils_texturecache_array_t *texturecache_array;
+  mod_gl_utils_texturecache_item_t *texturecache_item;
 
   texturecache_array = &(context->texturecache_array);
 
@@ -312,5 +308,5 @@ mod_gl_utils_clear_texturecache (MOD_GL_UTILS_CONTEXT * context)
 	}
     }
 
-  memset (texturecache_array, 0, sizeof (MOD_GL_UTILS_TEXTURECACHE_ARRAY));
+  memset (texturecache_array, 0, sizeof (mod_gl_utils_texturecache_array_t));
 }
