@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,7 +26,7 @@
 #include "gl-utils-internal.h"
 
 void
-mod_gl_utils_viewport_calc_view_area (MOD_GL_UTILS_CONTEXT *
+mod_gl_utils_viewport_calc_view_area (mod_gl_utils_context_t *
 				      utils_context, int *view_x,
 				      int *view_y, int *view_w, int *view_h)
 {
@@ -40,11 +41,11 @@ mod_gl_utils_viewport_calc_view_area (MOD_GL_UTILS_CONTEXT *
 }
 
 void
-mod_gl_utils_viewport_calc_map_area (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_utils_viewport_calc_map_area (mod_gl_utils_context_t * utils_context,
 				     float *map_x1, float *map_y1,
 				     float *map_x2, float *map_y2,
 				     int shape_w, int shape_h,
-				     LW6MAP_PARAM * map_param)
+				     lw6map_param_t * map_param)
 {
   int view_x, view_y, view_w, view_h;
   float map_w, map_h;
