@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,11 +32,11 @@
  * Very slow, we don't care, for debugging only.
  */
 SDL_Surface *
-mod_gl_utils_create_zones_surface (MOD_GL_UTILS_CONTEXT * utils_context,
-				   LW6KER_MAP_STRUCT * map_struct)
+mod_gl_utils_create_zones_surface (mod_gl_utils_context_t * utils_context,
+				   lw6ker_map_struct_t * map_struct)
 {
   SDL_Surface *zones_surface;
-  LW6SYS_COLOR_F color;
+  lw6sys_color_f_t color;
 
   zones_surface =
     mod_gl_utils_create_surface (utils_context, map_struct->shape.w,
@@ -44,7 +45,7 @@ mod_gl_utils_create_zones_surface (MOD_GL_UTILS_CONTEXT * utils_context,
     {
       int i;
       float grey;
-      LW6KER_ZONE_STRUCT *zone;
+      lw6ker_zone_struct_t *zone;
       int log_base;
 
       log_base = map_struct->max_zone_size;
