@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,9 +22,7 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-
 #include <GL/glu.h>
 #include <SDL/SDL_image.h>
 
@@ -33,14 +32,14 @@
 #include "gl-flat.h"
 #include "gl-flat-internal.h"
 
-#define CONST_FILE "gfx/gl/view/flat/const.xml"
+#define CONST_FILE "view/flat/gl-flat-const.xml"
 
 static void
 read_callback (void *callback_data, char *element, char *key, char *value)
 {
-  _MOD_GL_VIEW_FLAT_CONST_DATA *const_data;
+  _mod_gl_view_flat_const_data_t *const_data;
 
-  const_data = (_MOD_GL_VIEW_FLAT_CONST_DATA *) callback_data;
+  const_data = (_mod_gl_view_flat_const_data_t *) callback_data;
 
   if (!strcmp (element, "int"))
     {
@@ -58,18 +57,17 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 }
 
 static int
-load_consts (MOD_GL_UTILS_CONTEXT * utils_context,
-	     _MOD_GL_VIEW_FLAT_CONTEXT * flat_context)
+load_consts (mod_gl_utils_context_t * utils_context,
+	     _mod_gl_view_flat_context_t * flat_context)
 {
   int ret = 0;
   char *const_file = NULL;
 
-  const_file = lw6sys_find_data_file (CONST_FILE);
+  const_file = lw6sys_path_concat (utils_context->path.data_dir, CONST_FILE);
 
   if (const_file)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("reading \"%s\""),
-		  const_file);
+      lw6sys_log (LW6SYS_LOG_INFO, _("reading \"%s\""), const_file);
 
       ret =
 	lw6cfg_read_key_value_xml_file (const_file, read_callback,
@@ -82,11 +80,11 @@ load_consts (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 static void
-unload_consts (MOD_GL_UTILS_CONTEXT * utils_context,
-	       _MOD_GL_VIEW_FLAT_CONTEXT * flat_context)
+unload_consts (mod_gl_utils_context_t * utils_context,
+	       _mod_gl_view_flat_context_t * flat_context)
 {
   memset (&flat_context->const_data, 0,
-	  sizeof (_MOD_GL_VIEW_FLAT_CONST_DATA));
+	  sizeof (_mod_gl_view_flat_const_data_t));
 }
 
 
@@ -94,32 +92,33 @@ unload_consts (MOD_GL_UTILS_CONTEXT * utils_context,
  * Putting all the load/unload functions together
  */
 int
-_mod_gl_view_flat_load_data (MOD_GL_UTILS_CONTEXT * utils_context,
-			     _MOD_GL_VIEW_FLAT_CONTEXT * flat_context)
+_mod_gl_view_flat_load_data (mod_gl_utils_context_t * utils_context,
+			     _mod_gl_view_flat_context_t * flat_context)
 {
   return load_consts (utils_context, flat_context);
 }
 
 int
-mod_gl_view_load_data (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_view_load_data (mod_gl_utils_context_t * utils_context,
 		       void *flat_context)
 {
   return _mod_gl_view_flat_load_data (utils_context,
-				      (_MOD_GL_VIEW_FLAT_CONTEXT *)
+				      (_mod_gl_view_flat_context_t *)
 				      flat_context);
 }
 
 void
-_mod_gl_view_flat_unload_data (MOD_GL_UTILS_CONTEXT * utils_context,
-			       _MOD_GL_VIEW_FLAT_CONTEXT * flat_context)
+_mod_gl_view_flat_unload_data (mod_gl_utils_context_t * utils_context,
+			       _mod_gl_view_flat_context_t * flat_context)
 {
   unload_consts (utils_context, flat_context);
 }
 
 void
-mod_gl_view_unload_data (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_view_unload_data (mod_gl_utils_context_t * utils_context,
 			 void *flat_context)
 {
   _mod_gl_view_flat_unload_data (utils_context,
-				 (_MOD_GL_VIEW_FLAT_CONTEXT *) flat_context);
+				 (_mod_gl_view_flat_context_t *)
+				 flat_context);
 }
