@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,8 +28,8 @@
 #include "gl-flat-internal.h"
 
 static void
-set_map_options (MOD_GL_UTILS_CONTEXT * utils_context,
-		 _MOD_GL_VIEW_FLAT_CONTEXT * flat_context)
+set_map_options (mod_gl_utils_context_t * utils_context,
+		 _mod_gl_view_flat_context_t * flat_context)
 {
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
@@ -38,8 +38,8 @@ set_map_options (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 static void
-display_texture_ex (MOD_GL_UTILS_CONTEXT * utils_context,
-		    _MOD_GL_VIEW_FLAT_CONTEXT * flat_context,
+display_texture_ex (mod_gl_utils_context_t * utils_context,
+		    _mod_gl_view_flat_context_t * flat_context,
 		    GLuint texture, float x1, float y1, float x2, float y2,
 		    float scale_w, float scale_h)
 {
@@ -65,10 +65,10 @@ display_texture_ex (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 static void
-display_texture (MOD_GL_UTILS_CONTEXT * utils_context,
-		 _MOD_GL_VIEW_FLAT_CONTEXT * flat_context,
+display_texture (mod_gl_utils_context_t * utils_context,
+		 _mod_gl_view_flat_context_t * flat_context,
 		 int texture_w, int texture_h, int shape_w, int shape_h,
-		 GLuint texture, LW6MAP_PARAM * map_param)
+		 GLuint texture, lw6map_param_t * map_param)
 {
   float x1, y1, x2, y2, scale_w, scale_h;
 
@@ -84,14 +84,14 @@ display_texture (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 static void
-display_texture_array (MOD_GL_UTILS_CONTEXT * utils_context,
-		       _MOD_GL_VIEW_FLAT_CONTEXT * flat_context,
+display_texture_array (mod_gl_utils_context_t * utils_context,
+		       _mod_gl_view_flat_context_t * flat_context,
 		       int texture_array_w,
 		       int texture_array_h,
 		       int shape_w,
 		       int shape_h,
-		       MOD_GL_UTILS_TEXTURE_ARRAY * texture_array,
-		       LW6MAP_PARAM * param)
+		       mod_gl_utils_texture_array_t * texture_array,
+		       lw6map_param_t * param)
 {
   float x1, y1, x2, y2, w, h, coef_x, coef_y;
   float scale_w, scale_h;
@@ -175,56 +175,60 @@ display_texture_array (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 static void
-display_map_preview (MOD_GL_UTILS_CONTEXT * utils_context,
-		     _MOD_GL_VIEW_FLAT_CONTEXT * flat_context,
-		     LW6MAP_MAP * map)
+display_map_preview (mod_gl_utils_context_t * utils_context,
+		     _mod_gl_view_flat_context_t * flat_context,
+		     lw6gui_look_t * look, lw6map_level_t * level)
 {
   display_texture_array (utils_context, flat_context,
-			 flat_context->game_context.map.map->texture.shape.w,
-			 flat_context->game_context.map.map->
-			 texture.shape.h,
-			 flat_context->game_context.map.map->
-			 texture.shape.w,
-			 flat_context->game_context.map.map->
-			 texture.shape.h,
+			 flat_context->game_context.map.level->texture.shape.
+			 w,
+			 flat_context->game_context.map.level->texture.shape.
+			 h,
+			 flat_context->game_context.map.level->texture.shape.
+			 w,
+			 flat_context->game_context.map.level->texture.shape.
+			 h,
 			 &(flat_context->game_context.map.map_texture_array),
-			 &(map->param));
+			 &(level->param));
 }
 
 void
-_mod_gl_view_flat_display_preview (MOD_GL_UTILS_CONTEXT * utils_context,
-				   _MOD_GL_VIEW_FLAT_CONTEXT *
-				   flat_context, LW6MAP_MAP * map)
+_mod_gl_view_flat_display_preview (mod_gl_utils_context_t * utils_context,
+				   _mod_gl_view_flat_context_t *
+				   flat_context, lw6gui_look_t * look,
+				   lw6map_level_t * level)
 {
-  if (utils_context && flat_context && map && map->texture.data)
+  if (utils_context && flat_context && level && level->texture.data)
     {
       _mod_gl_view_flat_game_context_update_map (utils_context,
 						 flat_context,
 						 &(flat_context->
-						   game_context.map), map);
+						   game_context.map), level);
 
       mod_gl_utils_set_render_mode_2d_blend (utils_context);
 
       glColor3f (1.0, 1.0, 1.0);
       glEnable (GL_TEXTURE_2D);	// for texture
 
-      display_map_preview (utils_context, flat_context, map);
+      display_map_preview (utils_context, flat_context, look, level);
     }
 }
 
 void
-mod_gl_view_flat_display_preview (MOD_GL_UTILS_CONTEXT * utils_context,
-				  void *flat_context, LW6MAP_MAP * map)
+mod_gl_view_flat_display_preview (mod_gl_utils_context_t * utils_context,
+				  void *flat_context, lw6gui_look_t * look,
+				  lw6map_level_t * level)
 {
   _mod_gl_view_flat_display_preview (utils_context,
-				     (_MOD_GL_VIEW_FLAT_CONTEXT *)
-				     flat_context, map);
+				     (_mod_gl_view_flat_context_t *)
+				     flat_context, look, level);
 }
 
 static void
-display_map_zones (MOD_GL_UTILS_CONTEXT * utils_context,
-		   _MOD_GL_VIEW_FLAT_CONTEXT * flat_context,
-		   LW6MAP_MAP * map, LW6KER_MAP_STRUCT * map_struct)
+display_map_zones (mod_gl_utils_context_t * utils_context,
+		   _mod_gl_view_flat_context_t * flat_context,
+		   lw6gui_look_t * look, lw6map_level_t * level,
+		   lw6ker_map_struct_t * map_struct)
 {
   GLuint texture = 0;
   SDL_Surface *surface = NULL;
@@ -237,8 +241,8 @@ display_map_zones (MOD_GL_UTILS_CONTEXT * utils_context,
       if (texture)
 	{
 	  display_texture (utils_context, flat_context, map_struct->shape.w,
-			   map_struct->shape.h, map->texture.shape.w,
-			   map->texture.shape.h, texture, &(map->param));
+			   map_struct->shape.h, level->texture.shape.w,
+			   level->texture.shape.h, texture, &(level->param));
 
 	  mod_gl_utils_schedule_delete_texture (utils_context, texture);
 	}
@@ -248,12 +252,13 @@ display_map_zones (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-_mod_gl_view_flat_display_zones (MOD_GL_UTILS_CONTEXT * utils_context,
-				 _MOD_GL_VIEW_FLAT_CONTEXT *
-				 flat_context, LW6MAP_MAP * map,
-				 LW6KER_MAP_STRUCT * map_struct)
+_mod_gl_view_flat_display_zones (mod_gl_utils_context_t * utils_context,
+				 _mod_gl_view_flat_context_t *
+				 flat_context, lw6gui_look_t * look,
+				 lw6map_level_t * level,
+				 lw6ker_map_struct_t * map_struct)
 {
-  if (utils_context && flat_context && map && map_struct)
+  if (utils_context && flat_context && level && map_struct)
     {
       //_mod_gl_set_render_mode_2d (context);
       mod_gl_utils_set_render_mode_2d_blend (utils_context);
@@ -261,25 +266,28 @@ _mod_gl_view_flat_display_zones (MOD_GL_UTILS_CONTEXT * utils_context,
       glColor3f (1.0, 1.0, 1.0);
       glEnable (GL_TEXTURE_2D);	// for texture
 
-      display_map_zones (utils_context, flat_context, map, map_struct);
+      display_map_zones (utils_context, flat_context, look, level,
+			 map_struct);
     }
 }
 
 void
-mod_gl_view_flat_display_zones (MOD_GL_UTILS_CONTEXT * utils_context,
-				void *flat_context, LW6MAP_MAP * map,
-				LW6KER_MAP_STRUCT * map_struct)
+mod_gl_view_flat_display_zones (mod_gl_utils_context_t * utils_context,
+				void *flat_context, lw6gui_look_t * look,
+				lw6map_level_t * level,
+				lw6ker_map_struct_t * map_struct)
 {
   _mod_gl_view_flat_display_zones (utils_context,
-				   (_MOD_GL_VIEW_FLAT_CONTEXT *)
-				   flat_context, map, map_struct);
+				   (_mod_gl_view_flat_context_t *)
+				   flat_context, look, level, map_struct);
 }
 
 static void
-display_map_gradient (MOD_GL_UTILS_CONTEXT * utils_context,
-		      _MOD_GL_VIEW_FLAT_CONTEXT * flat_context,
-		      LW6MAP_MAP * map,
-		      LW6KER_MAP_STATE * map_state, int team_id)
+display_map_gradient (mod_gl_utils_context_t * utils_context,
+		      _mod_gl_view_flat_context_t * flat_context,
+		      lw6gui_look_t * look,
+		      lw6map_level_t * level,
+		      lw6ker_map_state_t * map_state, int team_id)
 {
   GLuint texture = 0;
   SDL_Surface *surface = NULL;
@@ -293,8 +301,8 @@ display_map_gradient (MOD_GL_UTILS_CONTEXT * utils_context,
       if (texture)
 	{
 	  display_texture (utils_context, flat_context, map_state->shape.w,
-			   map_state->shape.h, map->texture.shape.w,
-			   map->texture.shape.h, texture, &(map->param));
+			   map_state->shape.h, level->texture.shape.w,
+			   level->texture.shape.h, texture, &(level->param));
 
 	  mod_gl_utils_schedule_delete_texture (utils_context, texture);
 	}
@@ -304,11 +312,12 @@ display_map_gradient (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-_mod_gl_view_flat_display_gradient (MOD_GL_UTILS_CONTEXT * utils_context,
-				    _MOD_GL_VIEW_FLAT_CONTEXT *
-				    flat_context,
-				    LW6MAP_MAP * map,
-				    LW6KER_MAP_STATE * map_state, int team_id)
+_mod_gl_view_flat_display_gradient (mod_gl_utils_context_t * utils_context,
+				    _mod_gl_view_flat_context_t *
+				    flat_context, lw6gui_look_t * look,
+				    lw6map_level_t * level,
+				    lw6ker_map_state_t * map_state,
+				    int team_id)
 {
   if (utils_context && flat_context && map_state)
     {
@@ -317,20 +326,23 @@ _mod_gl_view_flat_display_gradient (MOD_GL_UTILS_CONTEXT * utils_context,
       glColor3f (1.0, 1.0, 1.0);
       glEnable (GL_TEXTURE_2D);	// for texture
 
-      display_map_gradient (utils_context, flat_context, map, map_state,
-			    team_id);
+      display_map_gradient (utils_context, flat_context, look, level,
+			    map_state, team_id);
     }
 }
 
 void
-mod_gl_view_flat_display_gradient (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_view_flat_display_gradient (mod_gl_utils_context_t * utils_context,
 				   void *flat_context,
-				   LW6MAP_MAP * map,
-				   LW6KER_MAP_STATE * map_state, int team_id)
+				   lw6gui_look_t * look,
+				   lw6map_level_t * level,
+				   lw6ker_map_state_t * map_state,
+				   int team_id)
 {
   _mod_gl_view_flat_display_gradient (utils_context,
-				      (_MOD_GL_VIEW_FLAT_CONTEXT *)
-				      flat_context, map, map_state, team_id);
+				      (_mod_gl_view_flat_context_t *)
+				      flat_context, look, level, map_state,
+				      team_id);
 }
 
 /*
@@ -340,14 +352,15 @@ mod_gl_view_flat_display_gradient (MOD_GL_UTILS_CONTEXT * utils_context,
  * game_context_init first.
  */
 static void
-display_armies (MOD_GL_UTILS_CONTEXT * utils_context,
-		_MOD_GL_VIEW_FLAT_CONTEXT *
-		flat_context, LW6MAP_PARAM * map_param,
-		LW6GFX_GAME_LOOK * game_look)
+display_armies (mod_gl_utils_context_t * utils_context,
+		_mod_gl_view_flat_context_t *
+		flat_context, lw6gui_look_t * look,
+		lw6map_param_t * map_param)
 {
   int i;
 
-  for (i = 0; i < flat_context->game_context.armies.game_state->map.nb_layers;
+  for (i = 0;
+       i < flat_context->game_context.armies.game_state->map_state.nb_layers;
        ++i)
     {
       mod_gl_utils_update_game_texture_array (utils_context,
@@ -358,15 +371,15 @@ display_armies (MOD_GL_UTILS_CONTEXT * utils_context,
 						armies_texture_arrays[i]),
 					      flat_context->game_context.
 					      armies.game_state, map_param,
-					      game_look, i);
+					      look, i);
       display_texture_array (utils_context, flat_context,
 			     flat_context->game_context.armies.game_state->
-			     map.shape.w,
+			     map_state.shape.w,
 			     flat_context->game_context.armies.game_state->
-			     map.shape.h,
-			     flat_context->game_context.map.map->texture.
+			     map_state.shape.h,
+			     flat_context->game_context.map.level->texture.
 			     shape.w,
-			     flat_context->game_context.map.map->texture.
+			     flat_context->game_context.map.level->texture.
 			     shape.h,
 			     &(flat_context->game_context.armies.
 			       armies_texture_arrays[i]), map_param);
@@ -380,47 +393,49 @@ display_armies (MOD_GL_UTILS_CONTEXT * utils_context,
  * game_context_init first.
  */
 static void
-display_game (MOD_GL_UTILS_CONTEXT * utils_context,
-	      _MOD_GL_VIEW_FLAT_CONTEXT *
-	      flat_context, LW6MAP_MAP * map, LW6GFX_GAME_LOOK * game_look)
+display_game (mod_gl_utils_context_t * utils_context,
+	      _mod_gl_view_flat_context_t *
+	      flat_context, lw6gui_look_t * look, lw6map_level_t * level)
 {
-  display_map_preview (utils_context, flat_context, map);
-  display_armies (utils_context, flat_context, &(map->param), game_look);
+  display_map_preview (utils_context, flat_context, look, level);
+  display_armies (utils_context, flat_context, look, &(level->param));
 }
 
 void
-_mod_gl_view_flat_display_game (MOD_GL_UTILS_CONTEXT * utils_context,
-				_MOD_GL_VIEW_FLAT_CONTEXT *
+_mod_gl_view_flat_display_game (mod_gl_utils_context_t * utils_context,
+				_mod_gl_view_flat_context_t *
 				flat_context,
-				LW6MAP_MAP * map,
-				LW6KER_GAME_STATE * game_state,
-				LW6GFX_GAME_LOOK * game_look)
+				lw6gui_look_t * look,
+				lw6ker_game_state_t * game_state)
 {
-  if (utils_context && flat_context && map && game_state)
+  if (utils_context && flat_context && game_state)
     {
+      lw6map_level_t *level;
+
+      level = game_state->game_struct->level;
+
       _mod_gl_view_flat_game_context_update (utils_context,
 					     flat_context,
 					     &flat_context->
-					     game_context, map, game_state,
-					     game_look);
+					     game_context, look, level,
+					     game_state);
 
       mod_gl_utils_set_render_mode_2d_blend (utils_context);
 
       glColor3f (1.0, 1.0, 1.0);
       glEnable (GL_TEXTURE_2D);	// for texture
 
-      display_game (utils_context, flat_context, map, game_look);
+      display_game (utils_context, flat_context, look, level);
     }
 }
 
 void
-mod_gl_view_flat_display_game (MOD_GL_UTILS_CONTEXT * utils_context,
+mod_gl_view_flat_display_game (mod_gl_utils_context_t * utils_context,
 			       void *flat_context,
-			       LW6MAP_MAP * map,
-			       LW6KER_GAME_STATE * game_state,
-			       LW6GFX_GAME_LOOK * game_look)
+			       lw6gui_look_t * look,
+			       lw6ker_game_state_t * game_state)
 {
   _mod_gl_view_flat_display_game (utils_context,
-				  (_MOD_GL_VIEW_FLAT_CONTEXT *)
-				  flat_context, map, game_state, game_look);
+				  (_mod_gl_view_flat_context_t *)
+				  flat_context, look, game_state);
 }
