@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 */
 
 #include <string.h>
-
 #include <GL/glu.h>
 
 #include "config.h"
@@ -30,48 +29,49 @@
 #include "gl-flat-internal.h"
 
 int
-_mod_gl_view_flat_game_context_init (MOD_GL_UTILS_CONTEXT *
+_mod_gl_view_flat_game_context_init (mod_gl_utils_context_t *
 				     utils_context,
-				     _MOD_GL_VIEW_FLAT_CONTEXT *
+				     _mod_gl_view_flat_context_t *
 				     flat_context,
-				     _MOD_GL_VIEW_FLAT_GAME_CONTEXT *
+				     _mod_gl_view_flat_game_context_t *
 				     game_context,
-				     LW6MAP_MAP * map,
-				     LW6KER_GAME_STATE * game_state,
-				     LW6GFX_GAME_LOOK * game_look)
+				     lw6gui_look_t * look,
+				     lw6map_level_t * level,
+				     lw6ker_game_state_t * game_state)
 {
   int ret = 0;
 
   ret =
     _mod_gl_view_flat_game_context_init_map (utils_context, flat_context,
-					     &(game_context->map), map)
+					     &(game_context->map), level)
     && _mod_gl_view_flat_game_context_init_armies (utils_context,
 						   flat_context,
 						   &(game_context->armies),
-						   game_state, game_look);
+						   look, game_state);
 
   return ret;
 }
 
 int
-_mod_gl_view_flat_game_context_init_map (MOD_GL_UTILS_CONTEXT *
+_mod_gl_view_flat_game_context_init_map (mod_gl_utils_context_t *
 					 utils_context,
-					 _MOD_GL_VIEW_FLAT_CONTEXT *
+					 _mod_gl_view_flat_context_t *
 					 flat_context,
-					 _MOD_GL_VIEW_FLAT_GAME_CONTEXT_MAP *
-					 game_context_map, LW6MAP_MAP * map)
+					 _mod_gl_view_flat_game_context_map_t
+					 * game_context_map,
+					 lw6map_level_t * level)
 {
   int ret = 0;
 
   ret = 1;
 
-  MOD_GL_UTILS_SURFACE_ARRAY surface_array;
+  mod_gl_utils_surface_array_t surface_array;
 
-  memset (&surface_array, 0, sizeof (MOD_GL_UTILS_SURFACE_ARRAY));
+  memset (&surface_array, 0, sizeof (mod_gl_utils_surface_array_t));
 
   ret = ret && mod_gl_utils_surface_array_init_from_map (utils_context,
 							 &surface_array,
-							 map,
+							 level,
 							 flat_context->
 							 const_data.
 							 tile_size_map);
@@ -80,8 +80,8 @@ _mod_gl_view_flat_game_context_init_map (MOD_GL_UTILS_CONTEXT *
       ret = mod_gl_utils_texture_array_init (utils_context,
 					     &(game_context_map->
 					       map_texture_array),
-					     map->texture.shape.w,
-					     map->texture.shape.h,
+					     level->texture.shape.w,
+					     level->texture.shape.h,
 					     flat_context->const_data.
 					     tile_size_map);
       if (ret)
@@ -94,13 +94,13 @@ _mod_gl_view_flat_game_context_init_map (MOD_GL_UTILS_CONTEXT *
       mod_gl_utils_surface_array_clear (utils_context, &surface_array);
     }
 
-  game_context_map->map = map;
-  game_context_map->map_id = map->id;
+  game_context_map->level = level;
+  game_context_map->level_id = level->id;
 
   if (!ret)
     {
 
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to init game_context (map) for flat backend"));
     }
 
@@ -108,14 +108,14 @@ _mod_gl_view_flat_game_context_init_map (MOD_GL_UTILS_CONTEXT *
 }
 
 int
-_mod_gl_view_flat_game_context_init_armies (MOD_GL_UTILS_CONTEXT *
+_mod_gl_view_flat_game_context_init_armies (mod_gl_utils_context_t *
 					    utils_context,
-					    _MOD_GL_VIEW_FLAT_CONTEXT *
+					    _mod_gl_view_flat_context_t *
 					    flat_context,
-					    _MOD_GL_VIEW_FLAT_GAME_CONTEXT_ARMIES
+					    _mod_gl_view_flat_game_context_armies_t
 					    * game_context_armies,
-					    LW6KER_GAME_STATE * game_state,
-					    LW6GFX_GAME_LOOK * game_look)
+					    lw6gui_look_t * look,
+					    lw6ker_game_state_t * game_state)
 {
   int ret = 0;
   int i;
@@ -126,19 +126,19 @@ _mod_gl_view_flat_game_context_init_armies (MOD_GL_UTILS_CONTEXT *
     && mod_gl_utils_surface_array_init (utils_context,
 					&(game_context_armies->
 					  armies_surface_array),
-					game_state->map.shape.w,
-					game_state->map.shape.h,
+					game_state->map_state.shape.w,
+					game_state->map_state.shape.h,
 					flat_context->const_data.
 					tile_size_armies);
 
-  for (i = 0; i < game_state->map.nb_layers; ++i)
+  for (i = 0; i < game_state->map_state.nb_layers; ++i)
     {
       ret = ret
 	&& mod_gl_utils_texture_array_init (utils_context,
 					    &(game_context_armies->
 					      armies_texture_arrays[i]),
-					    game_state->map.shape.w,
-					    game_state->map.shape.h,
+					    game_state->map_state.shape.w,
+					    game_state->map_state.shape.h,
 					    flat_context->const_data.
 					    tile_size_armies);
     }
@@ -148,7 +148,7 @@ _mod_gl_view_flat_game_context_init_armies (MOD_GL_UTILS_CONTEXT *
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to init game_context (armies) for flat backend"));
     }
 
@@ -156,11 +156,11 @@ _mod_gl_view_flat_game_context_init_armies (MOD_GL_UTILS_CONTEXT *
 }
 
 void
-_mod_gl_view_flat_game_context_clear (MOD_GL_UTILS_CONTEXT *
+_mod_gl_view_flat_game_context_clear (mod_gl_utils_context_t *
 				      utils_context,
-				      _MOD_GL_VIEW_FLAT_CONTEXT *
+				      _mod_gl_view_flat_context_t *
 				      flat_context,
-				      _MOD_GL_VIEW_FLAT_GAME_CONTEXT *
+				      _mod_gl_view_flat_game_context_t *
 				      game_context)
 {
   _mod_gl_view_flat_game_context_clear_map (utils_context, flat_context,
@@ -170,24 +170,24 @@ _mod_gl_view_flat_game_context_clear (MOD_GL_UTILS_CONTEXT *
 }
 
 void
-_mod_gl_view_flat_game_context_clear_map (MOD_GL_UTILS_CONTEXT *
+_mod_gl_view_flat_game_context_clear_map (mod_gl_utils_context_t *
 					  utils_context,
-					  _MOD_GL_VIEW_FLAT_CONTEXT *
+					  _mod_gl_view_flat_context_t *
 					  flat_context,
-					  _MOD_GL_VIEW_FLAT_GAME_CONTEXT_MAP *
-					  game_context_map)
+					  _mod_gl_view_flat_game_context_map_t
+					  * game_context_map)
 {
   mod_gl_utils_texture_array_clear (utils_context,
 				    &(game_context_map->map_texture_array));
-  memset (game_context_map, 0, sizeof (_MOD_GL_VIEW_FLAT_GAME_CONTEXT_MAP));
+  memset (game_context_map, 0, sizeof (_mod_gl_view_flat_game_context_map_t));
 }
 
 void
-_mod_gl_view_flat_game_context_clear_armies (MOD_GL_UTILS_CONTEXT *
+_mod_gl_view_flat_game_context_clear_armies (mod_gl_utils_context_t *
 					     utils_context,
-					     _MOD_GL_VIEW_FLAT_CONTEXT *
+					     _mod_gl_view_flat_context_t *
 					     flat_context,
-					     _MOD_GL_VIEW_FLAT_GAME_CONTEXT_ARMIES
+					     _mod_gl_view_flat_game_context_armies_t
 					     * game_context_armies)
 {
   int i;
@@ -203,45 +203,46 @@ _mod_gl_view_flat_game_context_clear_armies (MOD_GL_UTILS_CONTEXT *
     }
 
   memset (game_context_armies, 0,
-	  sizeof (_MOD_GL_VIEW_FLAT_GAME_CONTEXT_ARMIES));
+	  sizeof (_mod_gl_view_flat_game_context_armies_t));
 }
 
 int
-_mod_gl_view_flat_game_context_update (MOD_GL_UTILS_CONTEXT *
+_mod_gl_view_flat_game_context_update (mod_gl_utils_context_t *
 				       utils_context,
-				       _MOD_GL_VIEW_FLAT_CONTEXT *
+				       _mod_gl_view_flat_context_t *
 				       flat_context,
-				       _MOD_GL_VIEW_FLAT_GAME_CONTEXT *
+				       _mod_gl_view_flat_game_context_t *
 				       game_context,
-				       LW6MAP_MAP * map,
-				       LW6KER_GAME_STATE * game_state,
-				       LW6GFX_GAME_LOOK * game_look)
+				       lw6gui_look_t * look,
+				       lw6map_level_t * level,
+				       lw6ker_game_state_t * game_state)
 {
   int ret = 0;
 
   ret =
     _mod_gl_view_flat_game_context_update_map (utils_context, flat_context,
-					       &(game_context->map), map)
+					       &(game_context->map), level)
     && _mod_gl_view_flat_game_context_update_armies (utils_context,
 						     flat_context,
 						     &(game_context->armies),
-						     game_state, game_look);
+						     look, game_state);
 
   return ret;
 }
 
 int
-_mod_gl_view_flat_game_context_update_map (MOD_GL_UTILS_CONTEXT *
+_mod_gl_view_flat_game_context_update_map (mod_gl_utils_context_t *
 					   utils_context,
-					   _MOD_GL_VIEW_FLAT_CONTEXT *
+					   _mod_gl_view_flat_context_t *
 					   flat_context,
-					   _MOD_GL_VIEW_FLAT_GAME_CONTEXT_MAP
+					   _mod_gl_view_flat_game_context_map_t
 					   * game_context_map,
-					   LW6MAP_MAP * map)
+					   lw6map_level_t * level)
 {
   int ret = 0;
 
-  if (game_context_map->map_id == map->id && game_context_map->map == map)
+  if (game_context_map->level_id == level->id
+      && game_context_map->level == level)
     {
       ret = 1;			// nothing to do, up to date
     }
@@ -252,21 +253,22 @@ _mod_gl_view_flat_game_context_update_map (MOD_GL_UTILS_CONTEXT *
 						game_context_map);
       ret =
 	_mod_gl_view_flat_game_context_init_map (utils_context, flat_context,
-						 game_context_map, map);
+						 game_context_map, level);
     }
 
   return ret;
 }
 
 int
-_mod_gl_view_flat_game_context_update_armies (MOD_GL_UTILS_CONTEXT *
+_mod_gl_view_flat_game_context_update_armies (mod_gl_utils_context_t *
 					      utils_context,
-					      _MOD_GL_VIEW_FLAT_CONTEXT *
+					      _mod_gl_view_flat_context_t *
 					      flat_context,
-					      _MOD_GL_VIEW_FLAT_GAME_CONTEXT_ARMIES
+					      _mod_gl_view_flat_game_context_armies_t
 					      * game_context_armies,
-					      LW6KER_GAME_STATE * game_state,
-					      LW6GFX_GAME_LOOK * game_look)
+					      lw6gui_look_t * look,
+					      lw6ker_game_state_t *
+					      game_state)
 {
   int ret = 0;
 
@@ -284,7 +286,7 @@ _mod_gl_view_flat_game_context_update_armies (MOD_GL_UTILS_CONTEXT *
 	_mod_gl_view_flat_game_context_init_armies (utils_context,
 						    flat_context,
 						    game_context_armies,
-						    game_state, game_look);
+						    look, game_state);
     }
 
   return ret;
