@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,22 +30,24 @@
 #define MIN_SIDE 1.0f
 
 void
-_mod_gl_view_flat_pick_map_coord (MOD_GL_UTILS_CONTEXT * utils_context,
-				  _MOD_GL_VIEW_FLAT_CONTEXT *
+_mod_gl_view_flat_pick_map_coord (mod_gl_utils_context_t * utils_context,
+				  _mod_gl_view_flat_context_t *
 				  flat_context,
+				  lw6gui_look_t * look,
 				  int *map_x,
 				  int *map_y,
-				  LW6MAP_MAP * map,
-				  LW6KER_GAME_STATE * game_state,
+				  lw6ker_game_state_t * game_state,
 				  int screen_x, int screen_y)
 {
   float screen_x1, screen_y1, screen_x2, screen_y2;
   float screen_w, screen_h;
+  lw6map_level_t *level = game_state->game_struct->level;
 
   mod_gl_utils_viewport_calc_map_area (utils_context, &screen_x1, &screen_y1,
 				       &screen_x2, &screen_y2,
-				       map->texture.shape.w,
-				       map->texture.shape.h, &(map->param));
+				       level->texture.shape.w,
+				       level->texture.shape.h,
+				       &(level->param));
 
   screen_w = screen_x2 - screen_x1;
   screen_h = screen_y2 - screen_y1;
@@ -69,24 +71,24 @@ _mod_gl_view_flat_pick_map_coord (MOD_GL_UTILS_CONTEXT * utils_context,
   else
     {
       (*map_x) =
-	((float) map->depth.shape.w) * (screen_x - screen_x1) / screen_w;
+	((float) level->depth.shape.w) * (screen_x - screen_x1) / screen_w;
       (*map_y) =
-	((float) map->depth.shape.h) * (screen_y - screen_y1) / screen_h;
+	((float) level->depth.shape.h) * (screen_y - screen_y1) / screen_h;
     }
 }
 
 void
-mod_gl_view_flat_pick_map_coord (MOD_GL_UTILS_CONTEXT *
+mod_gl_view_flat_pick_map_coord (mod_gl_utils_context_t *
 				 utils_context,
 				 void *flat_context,
+				 lw6gui_look_t * look,
 				 int *map_x,
 				 int *map_y,
-				 LW6MAP_MAP * map,
-				 LW6KER_GAME_STATE * game_state,
+				 lw6ker_game_state_t * game_state,
 				 int screen_x, int screen_y)
 {
   _mod_gl_view_flat_pick_map_coord (utils_context,
-				    (_MOD_GL_VIEW_FLAT_CONTEXT *)
-				    flat_context, map_x, map_y, map,
+				    (_mod_gl_view_flat_context_t *)
+				    flat_context, look, map_x, map_y,
 				    game_state, screen_x, screen_y);
 }
