@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,13 +26,13 @@
 static void
 warning (char *func_name)
 {
-  lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+  lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("view backend function \"%s\" is not defined"));
 }
 
 int
-mod_gl_view_init (MOD_GL_UTILS_CONTEXT * utils_context,
-		  MOD_GL_VIEW_BACKEND * backend)
+mod_gl_view_init (mod_gl_utils_context_t * utils_context,
+		  mod_gl_view_backend_t * backend)
 {
   if (backend->init)
     {
@@ -47,8 +47,8 @@ mod_gl_view_init (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_view_quit (MOD_GL_UTILS_CONTEXT * utils_context,
-		  MOD_GL_VIEW_BACKEND * backend)
+mod_gl_view_quit (mod_gl_utils_context_t * utils_context,
+		  mod_gl_view_backend_t * backend)
 {
   if (backend->quit)
     {
@@ -61,12 +61,14 @@ mod_gl_view_quit (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_view_display_preview (MOD_GL_UTILS_CONTEXT * utils_context,
-			     MOD_GL_VIEW_BACKEND * backend, LW6MAP_MAP * map)
+mod_gl_view_display_preview (mod_gl_utils_context_t * utils_context,
+			     mod_gl_view_backend_t * backend,
+			     lw6gui_look_t * look, lw6map_level_t * level)
 {
   if (backend->display_preview)
     {
-      backend->display_preview (utils_context, backend->view_context, map);
+      backend->display_preview (utils_context, backend->view_context, look,
+				level);
     }
   else
     {
@@ -75,14 +77,16 @@ mod_gl_view_display_preview (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_view_display_zones (MOD_GL_UTILS_CONTEXT * utils_context,
-			   MOD_GL_VIEW_BACKEND * backend,
-			   LW6MAP_MAP * map, LW6KER_MAP_STRUCT * map_struct)
+mod_gl_view_display_zones (mod_gl_utils_context_t * utils_context,
+			   mod_gl_view_backend_t * backend,
+			   lw6gui_look_t * look,
+			   lw6map_level_t * level,
+			   lw6ker_map_struct_t * map_struct)
 {
   if (backend->display_zones)
     {
-      backend->display_zones (utils_context, backend->view_context, map,
-			      map_struct);
+      backend->display_zones (utils_context, backend->view_context, look,
+			      level, map_struct);
     }
   else
     {
@@ -91,15 +95,16 @@ mod_gl_view_display_zones (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_view_display_gradient (MOD_GL_UTILS_CONTEXT * utils_context,
-			      MOD_GL_VIEW_BACKEND * backend,
-			      LW6MAP_MAP * map,
-			      LW6KER_MAP_STATE * map_state, int team_id)
+mod_gl_view_display_gradient (mod_gl_utils_context_t * utils_context,
+			      mod_gl_view_backend_t * backend,
+			      lw6gui_look_t * look,
+			      lw6map_level_t * level,
+			      lw6ker_map_state_t * map_state, int team_id)
 {
   if (backend->display_gradient)
     {
-      backend->display_gradient (utils_context, backend->view_context, map,
-				 map_state, team_id);
+      backend->display_gradient (utils_context, backend->view_context, look,
+				 level, map_state, team_id);
     }
   else
     {
@@ -108,16 +113,15 @@ mod_gl_view_display_gradient (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_view_display_game (MOD_GL_UTILS_CONTEXT * utils_context,
-			  MOD_GL_VIEW_BACKEND * backend,
-			  LW6MAP_MAP * map,
-			  LW6KER_GAME_STATE * game_state,
-			  LW6GFX_GAME_LOOK * game_look)
+mod_gl_view_display_game (mod_gl_utils_context_t * utils_context,
+			  mod_gl_view_backend_t * backend,
+			  lw6gui_look_t * look,
+			  lw6ker_game_state_t * game_state)
 {
   if (backend->display_game)
     {
-      backend->display_game (utils_context, backend->view_context,
-			     map, game_state, game_look);
+      backend->display_game (utils_context, backend->view_context, look,
+			     game_state);
     }
   else
     {
@@ -126,17 +130,16 @@ mod_gl_view_display_game (MOD_GL_UTILS_CONTEXT * utils_context,
 }
 
 void
-mod_gl_view_pick_map_coord (MOD_GL_UTILS_CONTEXT * utils_context,
-			    MOD_GL_VIEW_BACKEND * backend, int *map_x,
-			    int *map_y, LW6MAP_MAP * map,
-			    LW6KER_GAME_STATE * game_state, int screen_x,
+mod_gl_view_pick_map_coord (mod_gl_utils_context_t * utils_context,
+			    mod_gl_view_backend_t * backend,
+			    lw6gui_look_t * look, int *map_x, int *map_y,
+			    lw6ker_game_state_t * game_state, int screen_x,
 			    int screen_y)
 {
   if (backend->pick_map_coord)
     {
-      backend->pick_map_coord (utils_context, backend->view_context,
-			       map_x, map_y, map, game_state, screen_x,
-			       screen_y);
+      backend->pick_map_coord (utils_context, backend->view_context, look,
+			       map_x, map_y, game_state, screen_x, screen_y);
     }
   else
     {
