@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,12 +28,13 @@
 
 #include "gl-flat/gl-flat.h"
 
-MOD_GL_VIEW_BACKEND *
-mod_gl_view_create_backend (MOD_GL_UTILS_CONTEXT * utils_context, char *name)
+mod_gl_view_backend_t *
+mod_gl_view_create_backend (mod_gl_utils_context_t * utils_context,
+			    char *name)
 {
-  MOD_GL_VIEW_BACKEND *(*init_func) (MOD_GL_UTILS_CONTEXT * utils_context) =
-    NULL;
-  MOD_GL_VIEW_BACKEND *backend = NULL;
+  mod_gl_view_backend_t *(*init_func) (mod_gl_utils_context_t *
+				       utils_context) = NULL;
+  mod_gl_view_backend_t *backend = NULL;
 
   if (strcmp (name, "flat") == 0)
     {
@@ -40,7 +42,7 @@ mod_gl_view_create_backend (MOD_GL_UTILS_CONTEXT * utils_context, char *name)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("view backend \"%s\" does not exists"), name);
     }
 
@@ -57,8 +59,8 @@ mod_gl_view_create_backend (MOD_GL_UTILS_CONTEXT * utils_context, char *name)
 }
 
 void
-mod_gl_view_destroy_backend (MOD_GL_UTILS_CONTEXT * utils_context,
-			     MOD_GL_VIEW_BACKEND * backend)
+mod_gl_view_destroy_backend (mod_gl_utils_context_t * utils_context,
+			     mod_gl_view_backend_t * backend)
 {
   if (backend)
     {
