@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,7 +22,6 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 #include <time.h>
 #include <string.h>
@@ -30,8 +30,23 @@
 #include "../gfx.h"
 #include "mod-gl-internal.h"
 
+int
+_mod_gl_set_backends (_mod_gl_context_t * gfx_context, lw6gui_look_t * look)
+{
+  int ret = 1;
+
+  ret =
+    _mod_gl_set_background_backend (gfx_context, look->style.background_style)
+    && ret;
+  ret = _mod_gl_set_hud_backend (gfx_context, look->style.hud_style) && ret;
+  ret = _mod_gl_set_menu_backend (gfx_context, look->style.menu_style) && ret;
+  ret = _mod_gl_set_view_backend (gfx_context, look->style.view_style) && ret;
+
+  return ret;
+}
+
 static void
-clear_background_backend (_MOD_GL_CONTEXT * gfx_context)
+clear_background_backend (_mod_gl_context_t * gfx_context)
 {
   if (gfx_context->background_backend)
     {
@@ -47,7 +62,7 @@ clear_background_backend (_MOD_GL_CONTEXT * gfx_context)
 }
 
 static void
-clear_hud_backend (_MOD_GL_CONTEXT * gfx_context)
+clear_hud_backend (_mod_gl_context_t * gfx_context)
 {
   if (gfx_context->hud_backend)
     {
@@ -63,7 +78,7 @@ clear_hud_backend (_MOD_GL_CONTEXT * gfx_context)
 }
 
 static void
-clear_menu_backend (_MOD_GL_CONTEXT * gfx_context)
+clear_menu_backend (_mod_gl_context_t * gfx_context)
 {
   if (gfx_context->menu_backend)
     {
@@ -79,7 +94,7 @@ clear_menu_backend (_MOD_GL_CONTEXT * gfx_context)
 }
 
 static void
-clear_view_backend (_MOD_GL_CONTEXT * gfx_context)
+clear_view_backend (_mod_gl_context_t * gfx_context)
 {
   if (gfx_context->view_backend)
     {
@@ -95,7 +110,7 @@ clear_view_backend (_MOD_GL_CONTEXT * gfx_context)
 }
 
 int
-_mod_gl_set_background_backend (_MOD_GL_CONTEXT * gfx_context,
+_mod_gl_set_background_backend (_mod_gl_context_t * gfx_context,
 				char *background_style)
 {
   int ret = 0;
@@ -126,7 +141,7 @@ _mod_gl_set_background_backend (_MOD_GL_CONTEXT * gfx_context,
 }
 
 int
-_mod_gl_set_hud_backend (_MOD_GL_CONTEXT * gfx_context, char *hud_style)
+_mod_gl_set_hud_backend (_mod_gl_context_t * gfx_context, char *hud_style)
 {
   int ret = 0;
 
@@ -154,7 +169,7 @@ _mod_gl_set_hud_backend (_MOD_GL_CONTEXT * gfx_context, char *hud_style)
 }
 
 int
-_mod_gl_set_menu_backend (_MOD_GL_CONTEXT * gfx_context, char *menu_style)
+_mod_gl_set_menu_backend (_mod_gl_context_t * gfx_context, char *menu_style)
 {
   int ret = 0;
 
@@ -183,7 +198,7 @@ _mod_gl_set_menu_backend (_MOD_GL_CONTEXT * gfx_context, char *menu_style)
 }
 
 int
-_mod_gl_set_view_backend (_MOD_GL_CONTEXT * gfx_context, char *view_style)
+_mod_gl_set_view_backend (_mod_gl_context_t * gfx_context, char *view_style)
 {
   int ret = 0;
 
@@ -214,92 +229,134 @@ _mod_gl_set_view_backend (_MOD_GL_CONTEXT * gfx_context, char *view_style)
 /*
  * Low-level SDL initialisation.
  */
-_MOD_GL_CONTEXT *
-_mod_gl_init (int width, int height, int fullscreen,
+_mod_gl_context_t *
+_mod_gl_init (int argc, char *argv[], int width, int height, int fullscreen,
 	      void (*resize_callback) (int width, int height, int fullscreen),
 	      int ticks)
 {
-  _MOD_GL_CONTEXT *gfx_context = NULL;
+  _mod_gl_context_t *gfx_context = NULL;
   int background_ok = 0;
   int hud_ok = 0;
   int menu_ok = 0;
   int view_ok = 0;
   int sdl_ok = 1;
+  int ttf_ok = 1;
+  lw6map_style_t map_style;
 
-  gfx_context = (_MOD_GL_CONTEXT *) LW6SYS_MALLOC (sizeof (_MOD_GL_CONTEXT));
-  if (!gfx_context)
+  gfx_context =
+    (_mod_gl_context_t *) LW6SYS_CALLOC (sizeof (_mod_gl_context_t));
+  if (gfx_context)
     {
-      /*
-       * No use to continue if this basic malloc fails...
-       */
-      exit (1);
-    }
-  memset (gfx_context, 0, sizeof (_MOD_GL_CONTEXT));
-
-
-  if (lw6sys_sdl_register ())
-    {
-      sdl_ok = !SDL_Init (0);
-    }
-
-  sdl_ok = sdl_ok && (SDL_WasInit (SDL_INIT_TIMER)
-		      || !SDL_InitSubSystem (SDL_INIT_TIMER));
-  //sdl_ok = sdl_ok && (SDL_WasInit(SDL_INIT_JOYSTICK) || !SDL_InitSubSystem(SDL_INIT_JOYSTICK));
-  sdl_ok = sdl_ok && (SDL_WasInit (SDL_INIT_VIDEO)
-		      || !SDL_InitSubSystem (SDL_INIT_VIDEO));
-
-  if (sdl_ok)
-    {
-      lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("SDL Init"));
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_ERROR, "gfx-mod-gl", _("SDL init error: \"%s\""),
-		  SDL_GetError ());
-      exit (1);
-    }
-
-  SDL_EnableUNICODE (1);
-
-  if (TTF_Init () == -1)
-    {
-      lw6sys_log (LW6SYS_LOG_ERROR, "gfx-mod-gl",
-		  _("SDL_ttf init error: \"%s\""), TTF_GetError ());
-      exit (1);
-    }
-
-  srandom (time (NULL));
-
-  if (mod_gl_utils_set_video_mode
-      (&(gfx_context->utils_context), width, height, fullscreen,
-       resize_callback))
-    {
-      if (mod_gl_utils_load_data (&(gfx_context->utils_context)))
+      if (mod_gl_utils_path_init (&(gfx_context->utils_context), argc, argv))
 	{
-	  background_ok = _mod_gl_set_background_backend (gfx_context, NULL);
-	  hud_ok = _mod_gl_set_hud_backend (gfx_context, NULL);
-	  menu_ok = _mod_gl_set_menu_backend (gfx_context, NULL);
-	  view_ok = _mod_gl_set_view_backend (gfx_context, NULL);
+
+	  if (lw6sys_sdl_register ())
+	    {
+	      sdl_ok = !SDL_Init (0);
+	    }
+
+	  sdl_ok = sdl_ok && (SDL_WasInit (SDL_INIT_TIMER)
+			      || !SDL_InitSubSystem (SDL_INIT_TIMER));
+	  sdl_ok = sdl_ok && (SDL_WasInit (SDL_INIT_VIDEO)
+			      || !SDL_InitSubSystem (SDL_INIT_VIDEO));
+
+	  if (sdl_ok)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("SDL Init"));
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_ERROR, _("SDL init error: \"%s\""),
+			  SDL_GetError ());
+	    }
+
+	  SDL_EnableUNICODE (1);
+
+	  ttf_ok = (TTF_Init () != -1);
+	  if (ttf_ok)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("SDL_ttf Init"));
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_ERROR,
+			  _("SDL_ttf init error: \"%s\""), TTF_GetError ());
+	    }
+
+	  srandom (time (NULL));
+
+	  if (sdl_ok && ttf_ok)
+	    {
+	      if (mod_gl_utils_set_video_mode
+		  (&(gfx_context->utils_context), width, height, fullscreen,
+		   resize_callback))
+		{
+		  if (mod_gl_utils_load_data (&(gfx_context->utils_context)))
+		    {
+		      memset (&map_style, 0, sizeof (lw6map_style_t));
+		      lw6map_style_defaults (&map_style);
+		      background_ok =
+			_mod_gl_set_background_backend (gfx_context,
+							map_style.
+							background_style);
+		      hud_ok =
+			_mod_gl_set_hud_backend (gfx_context,
+						 map_style.hud_style);
+		      menu_ok =
+			_mod_gl_set_menu_backend (gfx_context,
+						  map_style.menu_style);
+		      view_ok =
+			_mod_gl_set_view_backend (gfx_context,
+						  map_style.view_style);
+		      mod_gl_utils_update_team_color_map (&
+							  (gfx_context->
+							   utils_context.
+							   team_color_map),
+							  &map_style);
+		      lw6map_style_clear (&map_style);
+		    }
+		  else
+		    {
+		      lw6sys_log (LW6SYS_LOG_ERROR, _("unable to load data"));
+		    }
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_ERROR,
+			      _("unable to set video mode"));
+		}
+	    }
+
+	  if (gfx_context)
+	    {
+	      gfx_context->utils_context.joysticks_state.supported =
+		!SDL_InitSubSystem (SDL_INIT_JOYSTICK);
+	      if (gfx_context->utils_context.joysticks_state.supported)
+		{
+		  mod_gl_utils_joystick_init (&
+					      (gfx_context->utils_context.
+					       joysticks_state));
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_NOTICE, _("no joystick support"));
+		}
+	    }
+
+	  if (gfx_context && !(background_ok && hud_ok && menu_ok && view_ok))
+	    {
+	      _mod_gl_quit (gfx_context);
+	      gfx_context = NULL;
+	    }
+
+	  mod_gl_utils_timer_init (&(gfx_context->utils_context), ticks);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_ERROR, "gfx-mod-gl",
-		      _("unable to load data"));
+	  LW6SYS_FREE (gfx_context);
+	  gfx_context = NULL;
 	}
     }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_ERROR, "gfx-mod-gl",
-		  _("unable to set video mode"));
-    }
-
-  if (gfx_context && !(background_ok && hud_ok && menu_ok && view_ok))
-    {
-      _mod_gl_quit (gfx_context);
-      gfx_context = NULL;
-    }
-
-  mod_gl_utils_timer_init (&(gfx_context->utils_context), ticks);
 
   return gfx_context;
 }
@@ -308,7 +365,7 @@ _mod_gl_init (int width, int height, int fullscreen,
  * Ends-up all SDL stuff.
  */
 void
-_mod_gl_quit (_MOD_GL_CONTEXT * gfx_context)
+_mod_gl_quit (_mod_gl_context_t * gfx_context)
 {
   float quit_sleep;
 
@@ -318,6 +375,13 @@ _mod_gl_quit (_MOD_GL_CONTEXT * gfx_context)
    */
   quit_sleep = gfx_context->utils_context.const_data.quit_sleep;
 
+  if (gfx_context->utils_context.joysticks_state.supported)
+    {
+      mod_gl_utils_joystick_quit (&
+				  (gfx_context->utils_context.
+				   joysticks_state));
+    }
+
   clear_background_backend (gfx_context);
   clear_hud_backend (gfx_context);
   clear_menu_backend (gfx_context);
@@ -325,16 +389,18 @@ _mod_gl_quit (_MOD_GL_CONTEXT * gfx_context)
 
   mod_gl_utils_unload_data (&(gfx_context->utils_context));
 
+  mod_gl_utils_path_quit (&(gfx_context->utils_context));
+
   glFinish ();
+  lw6sys_log (LW6SYS_LOG_INFO, _("SDL_ttf Quit"));
   TTF_Quit ();
 
   SDL_QuitSubSystem (SDL_INIT_VIDEO);
-  //SDL_QuitSubSystem(SDL_INIT_JOYSTICK);
   SDL_QuitSubSystem (SDL_INIT_TIMER);
 
   if (lw6sys_sdl_unregister ())
     {
-      lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("SDL Quit"));
+      lw6sys_log (LW6SYS_LOG_INFO, _("SDL Quit"));
       SDL_Quit ();
     }
 
@@ -350,7 +416,7 @@ _mod_gl_quit (_MOD_GL_CONTEXT * gfx_context)
   if (gfx_context->utils_context.surface_counter.new_counter !=
       gfx_context->utils_context.surface_counter.delete_counter)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("possible memory leak, %d calls to SDL_CreateSurface, IMG_Load or TTF_RenderUTF8, and %d calls to SDL_FreeSurface"),
 		  gfx_context->utils_context.surface_counter.
@@ -361,7 +427,7 @@ _mod_gl_quit (_MOD_GL_CONTEXT * gfx_context)
   if (gfx_context->utils_context.texture_counter.new_counter !=
       gfx_context->utils_context.texture_counter.delete_counter)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("possible memory leak, %d calls to glGenTexture and %d calls to glDeleteTextures"),
 		  gfx_context->utils_context.texture_counter.
