@@ -1,23 +1,23 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include <string.h>
@@ -26,11 +26,12 @@ Contact author        : ufoot@ufoot.org
 #include "ker.h"
 #include "ker-internal.h"
 
-LW6SYS_BOOL
-_lw6ker_armies_init (LW6KER_ARMIES * armies, LW6KER_MAP_STRUCT * map_struct,
-		     LW6OPT_STATIC * options)
+int
+_lw6ker_armies_init (lw6ker_armies_t * armies,
+		     lw6ker_map_struct_t * map_struct,
+		     lw6map_options_t * options)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   // todo
   ret = 1;
@@ -40,8 +41,8 @@ _lw6ker_armies_init (LW6KER_ARMIES * armies, LW6KER_MAP_STRUCT * map_struct,
 		    options->total_armies_surface);
   armies->active_fighters = 0;
   armies->fighters =
-    (LW6KER_FIGHTER *) LW6SYS_CALLOC (armies->max_fighters *
-				      sizeof (LW6KER_FIGHTER));
+    (lw6ker_fighter_t *) LW6SYS_CALLOC (armies->max_fighters *
+					sizeof (lw6ker_fighter_t));
 
   if (armies->fighters)
     {
@@ -49,14 +50,14 @@ _lw6ker_armies_init (LW6KER_ARMIES * armies, LW6KER_MAP_STRUCT * map_struct,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker", _("unable to allocate armies"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to allocate armies"));
     }
 
   return ret;
 }
 
 void
-_lw6ker_armies_clear (LW6KER_ARMIES * armies)
+_lw6ker_armies_clear (lw6ker_armies_t * armies)
 {
   if (armies->fighters)
     {
@@ -68,10 +69,10 @@ _lw6ker_armies_clear (LW6KER_ARMIES * armies)
   armies->active_fighters = 0;
 }
 
-LW6SYS_BOOL
-_lw6ker_armies_copy (LW6KER_ARMIES * dst, LW6KER_ARMIES * src)
+int
+_lw6ker_armies_copy (lw6ker_armies_t * dst, lw6ker_armies_t * src)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   if (dst && src && dst->map_struct && src->map_struct
       && dst->map_struct == src->map_struct)
@@ -80,17 +81,17 @@ _lw6ker_armies_copy (LW6KER_ARMIES * dst, LW6KER_ARMIES * src)
 
       dst->max_fighters = src->max_fighters;
       dst->active_fighters = src->active_fighters;
-      for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	{
 	  dst->fighters_per_team[i] = src->fighters_per_team[i];
 	}
       memcpy (dst->fighters, src->fighters,
-	      src->max_fighters * sizeof (LW6KER_FIGHTER));
+	      src->max_fighters * sizeof (lw6ker_fighter_t));
       ret = 1;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("armies_copy only works if dst and src point to the same map_struct"));
     }
@@ -99,14 +100,14 @@ _lw6ker_armies_copy (LW6KER_ARMIES * dst, LW6KER_ARMIES * src)
 }
 
 void
-_lw6ker_armies_update_checksum (LW6KER_ARMIES * armies,
-				LW6SYS_UINT32 * checksum)
+_lw6ker_armies_update_checksum (lw6ker_armies_t * armies,
+				u_int32_t * checksum)
 {
   int i;
 
   lw6sys_checksum_update_int32 (checksum, armies->max_fighters);
   lw6sys_checksum_update_int32 (checksum, armies->active_fighters);
-  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
       lw6sys_checksum_update_int32 (checksum, armies->fighters_per_team[i]);
     }
@@ -116,10 +117,10 @@ _lw6ker_armies_update_checksum (LW6KER_ARMIES * armies,
     }
 }
 
-LW6SYS_INT32
-lw6ker_armies_add_fighter (LW6KER_ARMIES * armies, LW6KER_FIGHTER fighter)
+int32_t
+lw6ker_armies_add_fighter (lw6ker_armies_t * armies, lw6ker_fighter_t fighter)
 {
-  LW6SYS_INT32 new_id = -1;
+  int32_t new_id = -1;
 
   if (armies->active_fighters < armies->max_fighters)
     {
@@ -130,7 +131,7 @@ lw6ker_armies_add_fighter (LW6KER_ARMIES * armies, LW6KER_FIGHTER fighter)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("unable to add fighter, there are already %d fighters"),
 		  armies->active_fighters);
@@ -144,14 +145,14 @@ lw6ker_armies_add_fighter (LW6KER_ARMIES * armies, LW6KER_FIGHTER fighter)
  * with a smaller index. The trick is to swap fighters before deletion,
  * then delete.
  */
-LW6SYS_BOOL
-lw6ker_armies_remove_fighter (LW6KER_ARMIES * armies)
+int
+lw6ker_armies_remove_fighter (lw6ker_armies_t * armies)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   if (armies->active_fighters > 0)
     {
-      LW6SYS_INT32 last_fighter_id;
+      int32_t last_fighter_id;
 
       last_fighter_id = armies->active_fighters - 1;
       armies->fighters_per_team[armies->fighters[last_fighter_id].team_id]--;
@@ -161,14 +162,14 @@ lw6ker_armies_remove_fighter (LW6KER_ARMIES * armies)
        * the time to vacuum stuff.
        */
       memset (&(armies->fighters[last_fighter_id]), 0,
-	      sizeof (LW6KER_FIGHTER));
+	      sizeof (lw6ker_fighter_t));
       armies->active_fighters--;
 
       ret = 1;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to remove fighter, none to remove"));
     }
 
