@@ -1,23 +1,23 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include <string.h>
@@ -26,11 +26,11 @@ Contact author        : ufoot@ufoot.org
 #include "ker.h"
 #include "ker-internal.h"
 
-LW6SYS_BOOL
-_lw6ker_bot_init (LW6KER_BOT * bot, LW6KER_CURSOR * cursor,
-		  LW6SYS_INT32 rounds)
+int
+_lw6ker_bot_init (lw6ker_bot_t * bot, lw6ker_cursor_t * cursor,
+		  int32_t rounds)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   _lw6ker_bot_clear (bot);
 
@@ -44,13 +44,13 @@ _lw6ker_bot_init (LW6KER_BOT * bot, LW6KER_CURSOR * cursor,
 }
 
 void
-_lw6ker_bot_clear (LW6KER_BOT * bot)
+_lw6ker_bot_clear (lw6ker_bot_t * bot)
 {
-  memset (bot, 0, sizeof (LW6KER_BOT));
+  memset (bot, 0, sizeof (lw6ker_bot_t));
 }
 
 void
-_lw6ker_bot_update_checksum (LW6KER_BOT * bot, LW6SYS_UINT32 * checksum)
+_lw6ker_bot_update_checksum (lw6ker_bot_t * bot, u_int32_t * checksum)
 {
   lw6sys_checksum_update_int32 (checksum, bot->active);
   lw6sys_checksum_update_xy (checksum, &(bot->pos));
@@ -63,7 +63,7 @@ _lw6ker_bot_update_checksum (LW6KER_BOT * bot, LW6SYS_UINT32 * checksum)
 }
 
 static void
-find_new_pos (LW6SYS_XY * pos, LW6KER_GAME_STATE * game_state)
+find_new_pos (lw6sys_xy_t * pos, lw6ker_game_state_t * game_state)
 {
   /*
    * Todo: code something a little better than this, for this is
@@ -71,10 +71,10 @@ find_new_pos (LW6SYS_XY * pos, LW6KER_GAME_STATE * game_state)
    */
   pos->x =
     lw6sys_checksum_int32 (game_state->moves) %
-    (lw6sys_max (1, game_state->map.shape.w - 2));
+    (lw6sys_max (1, game_state->map_state.shape.w - 2));
   pos->y =
     lw6sys_checksum_int32 (game_state->rounds) %
-    (lw6sys_max (1, game_state->map.shape.h - 2));
+    (lw6sys_max (1, game_state->map_state.shape.h - 2));
 }
 
 /*
@@ -83,10 +83,10 @@ find_new_pos (LW6SYS_XY * pos, LW6KER_GAME_STATE * game_state)
  * but very basic here.
  */
 void
-_lw6ker_bot_update_pos (LW6KER_BOT * bot, LW6KER_GAME_STATE * game_state)
+_lw6ker_bot_update_pos (lw6ker_bot_t * bot, lw6ker_game_state_t * game_state)
 {
-  LW6SYS_INT32 weight_from;
-  LW6SYS_INT32 weight_to;
+  int32_t weight_from;
+  int32_t weight_to;
 
   if (bot->active)
     {
