@@ -1,23 +1,23 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include <string.h>
@@ -36,18 +36,18 @@ Contact author        : ufoot@ufoot.org
  */
 static int seq_id = 0;
 
-LW6KER_GAME_STATE *
-lw6ker_game_state_new (LW6KER_GAME_STRUCT * game_struct)
+lw6ker_game_state_t *
+lw6ker_game_state_new (lw6ker_game_struct_t * game_struct)
 {
-  LW6KER_GAME_STATE *ret = NULL;
+  lw6ker_game_state_t *ret = NULL;
 
-  ret = (LW6KER_GAME_STATE *) LW6SYS_CALLOC (sizeof (LW6KER_GAME_STATE));
+  ret = (lw6ker_game_state_t *) LW6SYS_CALLOC (sizeof (lw6ker_game_state_t));
   if (ret)
     {
       ret->id = ++seq_id;
       ret->game_struct = game_struct;
-      lw6opt_dynamic_init (&(ret->options), ret->game_struct->options);
-      _lw6ker_map_state_init (&(ret->map), &(ret->game_struct->map),
+      _lw6ker_map_state_init (&(ret->map_state),
+			      &(ret->game_struct->map_struct),
 			      &(ret->game_struct->options));
     }
 
@@ -55,7 +55,7 @@ lw6ker_game_state_new (LW6KER_GAME_STRUCT * game_struct)
 }
 
 void
-lw6ker_game_state_free (LW6KER_GAME_STATE * game_state)
+lw6ker_game_state_free (lw6ker_game_state_t * game_state)
 {
   /*
    * IMPORTANT NOTE: it's important *not* to reference game_struct
@@ -70,13 +70,13 @@ lw6ker_game_state_free (LW6KER_GAME_STATE * game_state)
    * and once it decides to purge objects (we have no more refs on
    * them that is) it can purge them in any order...
    */
-  _lw6ker_map_state_clear (&(game_state->map));
+  _lw6ker_map_state_clear (&(game_state->map_state));
 
   LW6SYS_FREE (game_state);
 }
 
 int
-lw6ker_game_state_memory_footprint (LW6KER_GAME_STATE * game_state)
+lw6ker_game_state_memory_footprint (lw6ker_game_state_t * game_state)
 {
   int ret = 0;
 
@@ -86,7 +86,7 @@ lw6ker_game_state_memory_footprint (LW6KER_GAME_STATE * game_state)
 }
 
 char *
-lw6ker_game_state_repr (LW6KER_GAME_STATE * game_state)
+lw6ker_game_state_repr (lw6ker_game_state_t * game_state)
 {
   char *ret = NULL;
 
@@ -94,8 +94,8 @@ lw6ker_game_state_repr (LW6KER_GAME_STATE * game_state)
     {
       ret =
 	lw6sys_new_sprintf ("%d (%dx%d)", game_state->id,
-			    game_state->game_struct->map.shape.w,
-			    game_state->game_struct->map.shape.h);
+			    game_state->game_struct->map_struct.shape.w,
+			    game_state->game_struct->map_struct.shape.h);
     }
   else
     {
@@ -114,10 +114,10 @@ lw6ker_game_state_repr (LW6KER_GAME_STATE * game_state)
  * slow) but that we're sure of, something 100% bullet proof we can
  * rely on.
  */
-LW6SYS_BOOL
-lw6ker_game_state_copy (LW6KER_GAME_STATE * dst, LW6KER_GAME_STATE * src)
+int
+lw6ker_game_state_copy (lw6ker_game_state_t * dst, lw6ker_game_state_t * src)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
   int i, j;
 
   /*
@@ -140,14 +140,13 @@ lw6ker_game_state_copy (LW6KER_GAME_STATE * dst, LW6KER_GAME_STATE * src)
 	}
       else
 	{
-	  ret = _lw6ker_map_state_copy (&dst->map, &src->map);
-	  lw6opt_dynamic_copy (&dst->options, &src->options);
+	  ret = _lw6ker_map_state_copy (&dst->map_state, &src->map_state);
 	  dst->moves = src->moves;
 	  dst->spreads = src->spreads;
 	  dst->rounds = src->rounds;
-	  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+	  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	    {
-	      for (j = 0; j < LW6OPT_MAX_CURSORS_PER_TEAM; ++j)
+	      for (j = 0; j < LW6MAP_MAX_CURSORS_PER_TEAM; ++j)
 		{
 		  dst->bots[i][j] = src->bots[i][j];
 		}
@@ -156,7 +155,7 @@ lw6ker_game_state_copy (LW6KER_GAME_STATE * dst, LW6KER_GAME_STATE * src)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("game_state_copy only works if dst and src point to the same game_struct"));
     }
@@ -165,88 +164,89 @@ lw6ker_game_state_copy (LW6KER_GAME_STATE * dst, LW6KER_GAME_STATE * src)
 }
 
 void
-_lw6ker_game_state_update_checksum (LW6KER_GAME_STATE *
-				    game_state, LW6SYS_UINT32 * checksum)
+_lw6ker_game_state_update_checksum (lw6ker_game_state_t *
+				    game_state, u_int32_t * checksum)
 {
   int i, j;
 
   _lw6ker_game_struct_update_checksum (game_state->game_struct, checksum);
-  _lw6ker_map_state_update_checksum (&(game_state->map), checksum);
-  lw6opt_dynamic_update_checksum (&(game_state->options), checksum);
+  _lw6ker_map_state_update_checksum (&(game_state->map_state), checksum);
   lw6sys_checksum_update_int32 (checksum, game_state->moves);
   lw6sys_checksum_update_int32 (checksum, game_state->spreads);
   lw6sys_checksum_update_int32 (checksum, game_state->rounds);
-  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
-      for (j = 0; j < LW6OPT_MAX_CURSORS_PER_TEAM; ++j)
+      for (j = 0; j < LW6MAP_MAX_CURSORS_PER_TEAM; ++j)
 	{
 	  _lw6ker_bot_update_checksum (&(game_state->bots[i][j]), checksum);
 	}
     }
 }
 
-LW6SYS_UINT32
-lw6ker_game_state_checksum (LW6KER_GAME_STATE * game_state)
+u_int32_t
+lw6ker_game_state_checksum (lw6ker_game_state_t * game_state)
 {
-  LW6SYS_UINT32 ret = 0;
+  u_int32_t ret = 0;
 
   _lw6ker_game_state_update_checksum (game_state, &ret);
 
   return ret;
 }
 
-LW6SYS_BOOL
-lw6ker_game_state_add_team (LW6KER_GAME_STATE * game_state,
-			    LW6SYS_INT32 team_id, LW6SYS_INT32 nb_cursors)
+int
+lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
+			    int32_t team_id, int32_t nb_cursors)
 {
-  LW6SYS_BOOL ret = 0;
-  LW6SYS_INT32 i;
+  int ret = 0;
+  int32_t i;
   /*
    * Some values as INT64 to force casts to long long and
    * avoid integer capacity overflow.
    */
-  LW6SYS_INT64 total_fighters;
-  LW6SYS_INT64 total_fighters_to_remove;
+  int64_t total_fighters;
+  int64_t total_fighters_to_remove;
 
-  if (!game_state->map.teams[team_id].active)
+  if (!game_state->map_state.teams[team_id].active)
     {
-      LW6SYS_INT32 nb_fighters;
-      LW6SYS_XY desired_center;
+      int32_t nb_fighters;
+      lw6sys_xy_t desired_center;
 
-      lw6ker_map_state_start_xy (&(game_state->map), &desired_center,
+      lw6ker_map_state_start_xy (&(game_state->map_state), &desired_center,
 				 team_id);
 
       nb_fighters =
-	lw6ker_per1000 (game_state->map.map_struct->room_for_armies,
+	lw6ker_per1000 (game_state->map_state.map_struct->room_for_armies,
 			game_state->game_struct->options.single_army_surface);
-      if (nb_fighters + game_state->map.armies.active_fighters >
-	  game_state->map.armies.max_fighters)
+      if (nb_fighters + game_state->map_state.armies.active_fighters >
+	  game_state->map_state.armies.max_fighters)
 	{
 	  /*
 	   * OK there will be too many fighters, now the rule is:
 	   * a new team gets 1/n of total allowed fighters.
 	   */
 	  nb_fighters =
-	    game_state->map.armies.max_fighters /
-	    (lw6ker_map_state_get_nb_active_teams (&(game_state->map)) + 1);
+	    game_state->map_state.armies.max_fighters /
+	    (lw6ker_map_state_get_nb_active_teams (&(game_state->map_state)) +
+	     1);
 	}
       /*
        * Remove fighters if needed
        */
-      if (nb_fighters + game_state->map.armies.active_fighters >
-	  game_state->map.armies.max_fighters)
+      if (nb_fighters + game_state->map_state.armies.active_fighters >
+	  game_state->map_state.armies.max_fighters)
 	{
-	  total_fighters = game_state->map.armies.active_fighters;
-	  total_fighters_to_remove = nb_fighters - (game_state->map.armies.
-						    max_fighters -
-						    total_fighters);
-	  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+	  total_fighters = game_state->map_state.armies.active_fighters;
+	  total_fighters_to_remove =
+	    nb_fighters - (game_state->map_state.armies.max_fighters -
+			   total_fighters);
+	  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	    {
-	      lw6ker_map_state_remove_team_fighters (&(game_state->map),
+	      lw6ker_map_state_remove_team_fighters (&(game_state->map_state),
 						     i,
 						     (total_fighters_to_remove
 						      *
-						      game_state->map.armies.
+						      game_state->map_state.
+						      armies.
 						      fighters_per_team[i]) /
 						     total_fighters);
 	    }
@@ -254,15 +254,15 @@ lw6ker_game_state_add_team (LW6KER_GAME_STATE * game_state,
 	   * Note that this value has probably changed since we last
 	   * calculated it...
 	   */
-	  total_fighters = game_state->map.armies.active_fighters;
-	  total_fighters_to_remove = nb_fighters - (game_state->map.armies.
-						    max_fighters -
-						    total_fighters);
-	  lw6ker_map_state_remove_fighters (&(game_state->map),
+	  total_fighters = game_state->map_state.armies.active_fighters;
+	  total_fighters_to_remove =
+	    nb_fighters - (game_state->map_state.armies.max_fighters -
+			   total_fighters);
+	  lw6ker_map_state_remove_fighters (&(game_state->map_state),
 					    total_fighters_to_remove);
 	}
 
-      lw6ker_map_state_populate_team (&game_state->map, team_id,
+      lw6ker_map_state_populate_team (&game_state->map_state, team_id,
 				      nb_fighters, desired_center,
 				      nb_cursors,
 				      game_state->game_struct->options);
@@ -271,18 +271,18 @@ lw6ker_game_state_add_team (LW6KER_GAME_STATE * game_state,
   else
     {
       int free_team_id =
-	lw6ker_map_state_get_free_team_id (&(game_state->map));
+	lw6ker_map_state_get_free_team_id (&(game_state->map_state));
 
       if (free_team_id >= 0)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("can't add team (team_id=%d), it's already active, however team %d is free"),
 		      team_id, free_team_id);
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("can't add team (team_id=%d) no free teams left, game is full"),
 		      team_id);
@@ -292,29 +292,29 @@ lw6ker_game_state_add_team (LW6KER_GAME_STATE * game_state,
   return ret;
 }
 
-LW6SYS_BOOL
-lw6ker_game_state_remove_team (LW6KER_GAME_STATE * game_state,
-			       LW6SYS_INT32 team_id)
+int
+lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
+			       int32_t team_id)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
-  if (game_state->map.teams[team_id].active)
+  if (game_state->map_state.teams[team_id].active)
     {
-      LW6SYS_INT32 nb_active_teams;
+      int32_t nb_active_teams;
       /*
        * Some values as INT64 to force casts to long long and
        * avoid integer capacity overflow.
        */
-      LW6SYS_INT64 nb_active_fighters;
-      LW6SYS_INT64 new_average_fighters_per_team;
-      LW6SYS_INT64 new_active_fighters;
-      LW6SYS_INT64 single_average_fighters_per_team;
-      LW6SYS_INT64 total_fighters_to_distribute;
-      LW6SYS_INT32 i;
+      int64_t nb_active_fighters;
+      int64_t new_average_fighters_per_team;
+      int64_t new_active_fighters;
+      int64_t single_average_fighters_per_team;
+      int64_t total_fighters_to_distribute;
+      int32_t i;
 
       nb_active_teams =
-	lw6ker_map_state_get_nb_active_teams (&(game_state->map));
-      nb_active_fighters = game_state->map.armies.active_fighters;
+	lw6ker_map_state_get_nb_active_teams (&(game_state->map_state));
+      nb_active_fighters = game_state->map_state.armies.active_fighters;
 
       if (nb_active_teams <= 1)
 	{
@@ -322,7 +322,7 @@ lw6ker_game_state_remove_team (LW6KER_GAME_STATE * game_state,
 	   * Weird situation, not sure it should happen, except when in
 	   * a spectator mode -> not one single fighter left!
 	   */
-	  lw6ker_map_state_remove_fighters (&(game_state->map),
+	  lw6ker_map_state_remove_fighters (&(game_state->map_state),
 					    nb_active_fighters);
 	}
       else
@@ -330,13 +330,13 @@ lw6ker_game_state_remove_team (LW6KER_GAME_STATE * game_state,
 	  new_average_fighters_per_team =
 	    nb_active_fighters / (nb_active_teams - 1);
 	  single_average_fighters_per_team =
-	    lw6ker_per1000 (game_state->map.map_struct->room_for_armies,
+	    lw6ker_per1000 (game_state->map_state.map_struct->room_for_armies,
 			    game_state->game_struct->options.
 			    single_army_surface);
 	  if (new_average_fighters_per_team >
 	      single_average_fighters_per_team)
 	    {
-	      lw6ker_map_state_remove_team_fighters (&(game_state->map),
+	      lw6ker_map_state_remove_team_fighters (&(game_state->map_state),
 						     team_id,
 						     nb_active_fighters -
 						     single_average_fighters_per_team
@@ -348,24 +348,24 @@ lw6ker_game_state_remove_team (LW6KER_GAME_STATE * game_state,
 	   * to be, that is there are not enough teams to reach the
 	   * absolute limit for fighters in this map.
 	   */
-	  new_active_fighters = game_state->map.armies.active_fighters;
+	  new_active_fighters = game_state->map_state.armies.active_fighters;
 
 	  /*
 	   * Now, second step, we redistribute the remaining fighters 
 	   * to other teams
 	   */
 	  total_fighters_to_distribute =
-	    game_state->map.armies.fighters_per_team[team_id];
-	  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+	    game_state->map_state.armies.fighters_per_team[team_id];
+	  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	    {
 	      if (i != team_id)
 		{
-		  lw6ker_map_state_redistribute_team (&(game_state->map), i,
-						      team_id,
-						      (game_state->map.
+		  lw6ker_map_state_redistribute_team (&
+						      (game_state->map_state),
+						      i, team_id,
+						      (game_state->map_state.
 						       armies.
-						       fighters_per_team[i]
-						       *
+						       fighters_per_team[i] *
 						       total_fighters_to_distribute)
 						      / new_active_fighters,
 						      game_state->
@@ -377,17 +377,19 @@ lw6ker_game_state_remove_team (LW6KER_GAME_STATE * game_state,
 	   * We might get a few fighters left due to rounding/approximations,
 	   * we get rid of them.
 	   */
-	  while (game_state->map.armies.fighters_per_team[team_id] > 0)
+	  while (game_state->map_state.armies.fighters_per_team[team_id] > 0)
 	    {
 	      for (i = 0;
-		   i < LW6OPT_MAX_NB_TEAMS
-		   && game_state->map.armies.fighters_per_team[team_id] > 0;
-		   ++i)
+		   i < LW6MAP_MAX_NB_TEAMS
+		   && game_state->map_state.armies.
+		   fighters_per_team[team_id] > 0; ++i)
 		{
-		  if (game_state->map.teams[i].active)
+		  if (game_state->map_state.teams[i].active)
 		    {
-		      lw6ker_map_state_redistribute_team (&(game_state->map),
-							  i, team_id, 1,
+		      lw6ker_map_state_redistribute_team (&
+							  (game_state->
+							   map_state), i,
+							  team_id, 1,
 							  game_state->
 							  game_struct->
 							  options);
@@ -395,7 +397,7 @@ lw6ker_game_state_remove_team (LW6KER_GAME_STATE * game_state,
 		}
 	    }
 
-	  lw6ker_map_state_cancel_team (&(game_state->map), team_id);
+	  lw6ker_map_state_cancel_team (&(game_state->map_state), team_id);
 	}
 
       ret = 1;
@@ -405,13 +407,13 @@ lw6ker_game_state_remove_team (LW6KER_GAME_STATE * game_state,
 }
 
 static void
-update_bots (LW6KER_GAME_STATE * game_state)
+update_bots (lw6ker_game_state_t * game_state)
 {
   int i, j;
 
-  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
-      for (j = 0; j < LW6OPT_MAX_CURSORS_PER_TEAM; ++j)
+      for (j = 0; j < LW6MAP_MAX_CURSORS_PER_TEAM; ++j)
 	{
 	  if (game_state->bots[i][j].active)
 	    {
@@ -422,28 +424,28 @@ update_bots (LW6KER_GAME_STATE * game_state)
 }
 
 static void
-update_cursors_with_bots (LW6KER_GAME_STATE * game_state)
+update_cursors_with_bots (lw6ker_game_state_t * game_state)
 {
   int i, j;
 
-  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
-      for (j = 0; j < LW6OPT_MAX_CURSORS_PER_TEAM; ++j)
+      for (j = 0; j < LW6MAP_MAX_CURSORS_PER_TEAM; ++j)
 	{
 	  if (game_state->bots[i][j].active)
 	    {
-	      if (j < game_state->map.teams[i].cursor_array.nb_cursors)
+	      if (j < game_state->map_state.teams[i].cursor_array.nb_cursors)
 		{
-		  game_state->map.teams[i].cursor_array.cursors[j].pos =
+		  game_state->map_state.teams[i].cursor_array.cursors[j].pos =
 		    game_state->bots[i][j].pos;
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+		  lw6sys_log (LW6SYS_LOG_WARNING,
 			      _
 			      ("strange, bot %d/%d is active, however team %d has only %d cursors"),
 			      i, j, i,
-			      game_state->map.teams[i].cursor_array.
+			      game_state->map_state.teams[i].cursor_array.
 			      nb_cursors);
 		}
 	    }
@@ -459,17 +461,17 @@ update_cursors_with_bots (LW6KER_GAME_STATE * game_state)
  * next... round.
  */
 void
-lw6ker_game_state_do_round (LW6KER_GAME_STATE * game_state)
+lw6ker_game_state_do_round (lw6ker_game_state_t * game_state)
 {
   update_bots (game_state);
   update_cursors_with_bots (game_state);
 
-  lw6ker_map_state_spread_gradient (&(game_state->map),
+  lw6ker_map_state_spread_gradient (&(game_state->map_state),
 				    &(game_state->game_struct->options),
 				    game_state->game_struct->options.
 				    spreads_per_round);
 
-  lw6ker_map_state_move_fighters (&(game_state->map),
+  lw6ker_map_state_move_fighters (&(game_state->map_state),
 				  lw6sys_checksum_int32 (game_state->
 							 rounds) %
 				  LW6KER_NB_PARITIES,
@@ -482,76 +484,78 @@ lw6ker_game_state_do_round (LW6KER_GAME_STATE * game_state)
   game_state->rounds++;
 }
 
-LW6SYS_UINT32
-lw6ker_game_state_get_moves (LW6KER_GAME_STATE * game_state)
+u_int32_t
+lw6ker_game_state_get_moves (lw6ker_game_state_t * game_state)
 {
   return (game_state->moves);
 }
 
-LW6SYS_UINT32
-lw6ker_game_state_get_spreads (LW6KER_GAME_STATE * game_state)
+u_int32_t
+lw6ker_game_state_get_spreads (lw6ker_game_state_t * game_state)
 {
   return (game_state->spreads);
 }
 
-LW6SYS_UINT32
-lw6ker_game_state_get_rounds (LW6KER_GAME_STATE * game_state)
+u_int32_t
+lw6ker_game_state_get_rounds (lw6ker_game_state_t * game_state)
 {
   return (game_state->rounds);
 }
 
-LW6SYS_BOOL
-lw6ker_game_state_enable_bot (LW6KER_GAME_STATE * game_state,
-			      LW6SYS_INT32 team_id)
+int
+lw6ker_game_state_enable_bot (lw6ker_game_state_t * game_state,
+			      int32_t team_id)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
   int i;
 
-  if (team_id >= 0 && team_id < LW6OPT_MAX_NB_TEAMS
-      && game_state->map.teams[team_id].active)
+  if (team_id >= 0 && team_id < LW6MAP_MAX_NB_TEAMS
+      && game_state->map_state.teams[team_id].active)
     {
-      for (i = 0; i < game_state->map.teams[team_id].cursor_array.nb_cursors;
+      for (i = 0;
+	   i < game_state->map_state.teams[team_id].cursor_array.nb_cursors;
 	   ++i)
 	{
 	  if (game_state->bots[team_id][i].active)
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	      lw6sys_log (LW6SYS_LOG_WARNING,
 			  _
 			  ("trying to enable bot %d on team %d, but it's already enabled"),
 			  i, team_id);
 	    }
 	  _lw6ker_bot_init (&(game_state->bots[team_id][i]),
-			    &(game_state->map.teams[team_id].cursor_array.
-			      cursors[i]), game_state->rounds);
+			    &(game_state->map_state.teams[team_id].
+			      cursor_array.cursors[i]), game_state->rounds);
 	}
       ret = 1;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to enable bot on team %d"), team_id);
     }
 
   return ret;
 }
 
-LW6SYS_BOOL
-lw6ker_game_state_disable_bot (LW6KER_GAME_STATE * game_state,
-			       LW6SYS_INT32 team_id)
+int
+lw6ker_game_state_disable_bot (lw6ker_game_state_t * game_state,
+			       int32_t team_id)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   int i;
 
-  if (team_id >= 0 && team_id < LW6OPT_MAX_NB_TEAMS
-      && game_state->map.teams[team_id].active)
+  if (team_id >= 0 && team_id < LW6MAP_MAX_NB_TEAMS
+      && game_state->map_state.teams[team_id].active)
     {
-      for (i = 0; i < game_state->map.teams[team_id].cursor_array.nb_cursors;
+      for (i = 0;
+	   i < game_state->map_state.teams[team_id].cursor_array.nb_cursors;
 	   ++i)
 	{
 	  if (!game_state->bots[team_id][i].active)
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	      lw6sys_log (LW6SYS_LOG_WARNING,
 			  _
 			  ("trying to disable bot %d on team %d, but it's not disabled"),
 			  i, team_id);
@@ -567,7 +571,7 @@ lw6ker_game_state_disable_bot (LW6KER_GAME_STATE * game_state,
        * the team is not active, the idea is that bots must be disabled
        * before the team is unactivated, final dot. We don't want ghost bots.
        */
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to disable bot on team %d"), team_id);
     }
 
