@@ -1,26 +1,25 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
 #include <string.h>
 #include <math.h>
 
@@ -28,21 +27,21 @@ Contact author        : ufoot@ufoot.org
 #include "ker.h"
 #include "ker-internal.h"
 
-typedef struct POLARITY_DATA_STRUCT
+typedef struct polarity_data_s
 {
-  LW6SYS_INT32 fighter_x;
-  LW6SYS_INT32 fighter_y;
-  LW6SYS_INT32 map_w;
-  LW6SYS_INT32 map_h;
-} POLARITY_DATA;
+  int32_t fighter_x;
+  int32_t fighter_y;
+  int32_t map_w;
+  int32_t map_h;
+} polarity_data_t;
 
-LW6SYS_BOOL
-_lw6ker_map_state_init (LW6KER_MAP_STATE * map_state,
-			LW6KER_MAP_STRUCT * map_struct,
-			LW6OPT_STATIC * options)
+int
+_lw6ker_map_state_init (lw6ker_map_state_t * map_state,
+			lw6ker_map_struct_t * map_struct,
+			lw6map_options_t * options)
 {
-  LW6SYS_BOOL ret = 0;
-  LW6SYS_INT32 i;
+  int ret = 0;
+  int32_t i;
 
   map_state->map_struct = map_struct;
   map_state->shape = map_struct->shape;
@@ -71,9 +70,9 @@ _lw6ker_map_state_init (LW6KER_MAP_STATE * map_state,
 }
 
 void
-_lw6ker_map_state_clear (LW6KER_MAP_STATE * map_state)
+_lw6ker_map_state_clear (lw6ker_map_state_t * map_state)
 {
-  LW6SYS_INT32 i;
+  int32_t i;
 
   for (i = 0; i < map_state->max_nb_teams; ++i)
     {
@@ -93,10 +92,10 @@ _lw6ker_map_state_clear (LW6KER_MAP_STATE * map_state)
   map_state->map_struct = NULL;
 }
 
-LW6SYS_BOOL
-_lw6ker_map_state_copy (LW6KER_MAP_STATE * dst, LW6KER_MAP_STATE * src)
+int
+_lw6ker_map_state_copy (lw6ker_map_state_t * dst, lw6ker_map_state_t * src)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   if (dst && src && dst->map_struct && src->map_struct
       && dst->map_struct == src->map_struct)
@@ -119,7 +118,7 @@ _lw6ker_map_state_copy (LW6KER_MAP_STATE * dst, LW6KER_MAP_STATE * src)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("map_state_copy only works if dst and src point to the same map_struct"));
     }
@@ -128,8 +127,8 @@ _lw6ker_map_state_copy (LW6KER_MAP_STATE * dst, LW6KER_MAP_STATE * src)
 }
 
 void
-_lw6ker_map_state_update_checksum (LW6KER_MAP_STATE * map_state,
-				   LW6SYS_UINT32 * checksum)
+_lw6ker_map_state_update_checksum (lw6ker_map_state_t * map_state,
+				   u_int32_t * checksum)
 {
   int i;
   /*
@@ -150,13 +149,13 @@ _lw6ker_map_state_update_checksum (LW6KER_MAP_STATE * map_state,
     }
 }
 
-LW6SYS_INT32
-lw6ker_map_state_get_free_team_id (LW6KER_MAP_STATE * map_state)
+int32_t
+lw6ker_map_state_get_free_team_id (lw6ker_map_state_t * map_state)
 {
-  LW6SYS_INT32 i;
-  LW6SYS_INT32 ret = -1;
+  int32_t i;
+  int32_t ret = -1;
 
-  for (i = 0; i < LW6OPT_MAX_NB_TEAMS && ret < 0; ++i)
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS && ret < 0; ++i)
     {
       if (!map_state->teams[i].active)
 	{
@@ -168,17 +167,17 @@ lw6ker_map_state_get_free_team_id (LW6KER_MAP_STATE * map_state)
 }
 
 void
-lw6ker_map_state_start_xy (LW6KER_MAP_STATE * map_state, LW6SYS_XY * start_xy,
-			   LW6SYS_INT32 team_id)
+lw6ker_map_state_start_xy (lw6ker_map_state_t * map_state,
+			   lw6sys_xy_t * start_xy, int32_t team_id)
 {
-  LW6SYS_INT32 angle;
-  LW6SYS_INT32 team_ip, team_fp;
+  int32_t angle;
+  int32_t team_ip, team_fp;
 
   team_ip = (team_id / 2) * 2;	// unoptimized, but well, is "& 0xFFFFFFFE" cleaner? 
   team_fp = team_id % 2;
 
   angle =
-    (LW6KER_TRIGO_PI * team_ip) / LW6OPT_MAX_NB_TEAMS +
+    (LW6KER_TRIGO_PI * team_ip) / LW6MAP_MAX_NB_TEAMS +
     LW6KER_TRIGO_PI * team_fp + (5 * LW6KER_TRIGO_PI) / 4;
   start_xy->x =
     map_state->shape.w / 2 +
@@ -190,13 +189,13 @@ lw6ker_map_state_start_xy (LW6KER_MAP_STATE * map_state, LW6SYS_XY * start_xy,
     LW6KER_TRIGO_RADIUS;
 }
 
-LW6SYS_INT32
-lw6ker_map_state_get_nb_active_teams (LW6KER_MAP_STATE * map_state)
+int32_t
+lw6ker_map_state_get_nb_active_teams (lw6ker_map_state_t * map_state)
 {
-  LW6SYS_INT32 i;
-  LW6SYS_INT32 ret = 0;
+  int32_t i;
+  int32_t ret = 0;
 
-  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
       if (map_state->teams[i].active)
 	{
@@ -207,23 +206,22 @@ lw6ker_map_state_get_nb_active_teams (LW6KER_MAP_STATE * map_state)
   return ret;
 }
 
-LW6SYS_INT32
-lw6ker_map_state_populate_team (LW6KER_MAP_STATE * map_state,
-				LW6SYS_INT32 team_id,
-				LW6SYS_INT32 nb_fighters,
-				LW6SYS_XY desired_center,
-				LW6SYS_INT32 nb_cursors,
-				LW6OPT_STATIC options)
+int32_t
+lw6ker_map_state_populate_team (lw6ker_map_state_t * map_state,
+				int32_t team_id,
+				int32_t nb_fighters,
+				lw6sys_xy_t desired_center,
+				int32_t nb_cursors, lw6map_options_t options)
 {
-  LW6SYS_XY real_center;
-  LW6SYS_INT32 angle, radius;
-  LW6SYS_INT32 max_radius, max_angle;
-  LW6SYS_INT32 x, y;
-  LW6SYS_INT32 depth;
-  LW6SYS_INT32 nb_fighters_added = 0;
-  LW6SYS_INT32 layer;
-  LW6SYS_INT32 new_fighter_id;
-  LW6KER_FIGHTER new_fighter;
+  lw6sys_xy_t real_center;
+  int32_t angle, radius;
+  int32_t max_radius, max_angle;
+  int32_t x, y;
+  int32_t depth;
+  int32_t nb_fighters_added = 0;
+  int32_t layer;
+  int32_t new_fighter_id;
+  lw6ker_fighter_t new_fighter;
 
   _lw6ker_fighter_clear (&new_fighter);
   lw6ker_map_struct_find_free_slot_near (map_state->map_struct, &real_center,
@@ -260,7 +258,7 @@ lw6ker_map_state_populate_team (LW6KER_MAP_STATE * map_state,
 		      new_fighter.layer = layer;
 		      new_fighter.pos.x = x;
 		      new_fighter.pos.y = y;
-		      new_fighter.health = LW6OPT_MAX_FIGHTER_HEALTH;
+		      new_fighter.health = LW6MAP_MAX_FIGHTER_HEALTH;
 		      new_fighter.last_direction = 0;
 		      new_fighter_id =
 			lw6ker_armies_add_fighter (&(map_state->armies),
@@ -284,29 +282,29 @@ lw6ker_map_state_populate_team (LW6KER_MAP_STATE * map_state,
   return nb_fighters_added;
 }
 
-LW6SYS_BOOL
-lw6ker_map_state_redistribute_team (LW6KER_MAP_STATE * map_state,
-				    LW6SYS_INT32 dst_team_id,
-				    LW6SYS_INT32 src_team_id,
-				    LW6SYS_INT32 nb_fighters,
-				    LW6OPT_STATIC options)
+int
+lw6ker_map_state_redistribute_team (lw6ker_map_state_t * map_state,
+				    int32_t dst_team_id,
+				    int32_t src_team_id,
+				    int32_t nb_fighters,
+				    lw6map_options_t options)
 {
-  LW6SYS_BOOL ret = 0;
-  LW6SYS_INT32 i, j;
-  LW6SYS_INT32 nb_fighters_redistributed = 0;
+  int ret = 0;
+  int32_t i, j;
+  int32_t nb_fighters_redistributed = 0;
 
   if (nb_fighters <= map_state->armies.fighters_per_team[src_team_id])
     {
       while (nb_fighters_redistributed < nb_fighters)
 	{
 	  for (i = 0;
-	       i < LW6OPT_MAX_NB_TEAMS
+	       i < LW6MAP_MAX_NB_TEAMS
 	       && nb_fighters_redistributed < nb_fighters; ++i)
 	    {
 	      for (j = i;
 		   j < map_state->armies.active_fighters
 		   && nb_fighters_redistributed < nb_fighters;
-		   j += LW6OPT_MAX_NB_TEAMS)
+		   j += LW6MAP_MAX_NB_TEAMS)
 		{
 		  if (map_state->armies.fighters[j].team_id == src_team_id)
 		    {
@@ -314,7 +312,7 @@ lw6ker_map_state_redistribute_team (LW6KER_MAP_STATE * map_state,
 		      (map_state->armies.fighters_per_team[src_team_id])--;
 		      (map_state->armies.fighters_per_team[dst_team_id])++;
 		      map_state->armies.fighters[j].health =
-			LW6OPT_MAX_FIGHTER_HEALTH;
+			LW6MAP_MAX_FIGHTER_HEALTH;
 		      nb_fighters_redistributed++;
 		    }
 		}
@@ -324,7 +322,7 @@ lw6ker_map_state_redistribute_team (LW6KER_MAP_STATE * map_state,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("can't redistribute %d fighters from team %d which has only %d"),
 		  nb_fighters, src_team_id,
@@ -334,11 +332,10 @@ lw6ker_map_state_redistribute_team (LW6KER_MAP_STATE * map_state,
   return ret;
 }
 
-LW6SYS_BOOL
-lw6ker_map_state_cancel_team (LW6KER_MAP_STATE * map_state,
-			      LW6SYS_INT32 team_id)
+int
+lw6ker_map_state_cancel_team (lw6ker_map_state_t * map_state, int32_t team_id)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   if (map_state->teams[team_id].active)
     {
@@ -348,7 +345,7 @@ lw6ker_map_state_cancel_team (LW6KER_MAP_STATE * map_state,
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("trying to cancel non-zeroed team %d, still has %d fighters"),
 		      team_id, map_state->armies.fighters_per_team[team_id]);
@@ -356,25 +353,25 @@ lw6ker_map_state_cancel_team (LW6KER_MAP_STATE * map_state,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("trying to cancel inactive team %d"), team_id);
     }
 
   return ret;
 }
 
-LW6SYS_BOOL
-lw6ker_map_state_remove_fighter (LW6KER_MAP_STATE * map_state,
-				 LW6SYS_INT32 fighter_id)
+int
+lw6ker_map_state_remove_fighter (lw6ker_map_state_t * map_state,
+				 int32_t fighter_id)
 {
-  LW6SYS_BOOL ret = 0;
-  LW6SYS_INT32 last_fighter_id;
+  int ret = 0;
+  int32_t last_fighter_id;
 
   last_fighter_id = map_state->armies.active_fighters - 1;
   if (fighter_id >= 0 && fighter_id <= last_fighter_id)
     {
-      LW6KER_FIGHTER fighter;
-      LW6KER_FIGHTER last_fighter;
+      lw6ker_fighter_t fighter;
+      lw6ker_fighter_t last_fighter;
 
       fighter = map_state->armies.fighters[fighter_id];
       last_fighter = map_state->armies.fighters[last_fighter_id];
@@ -405,13 +402,13 @@ lw6ker_map_state_remove_fighter (LW6KER_MAP_STATE * map_state,
   return ret;
 }
 
-LW6SYS_BOOL
-lw6ker_map_state_remove_fighters (LW6KER_MAP_STATE * map_state,
-				  LW6SYS_INT32 nb_fighters)
+int
+lw6ker_map_state_remove_fighters (lw6ker_map_state_t * map_state,
+				  int32_t nb_fighters)
 {
-  LW6SYS_INT32 i, j;
-  LW6SYS_BOOL ret = 0;
-  LW6SYS_INT32 nb_fighters_removed = 0;
+  int32_t i, j;
+  int ret = 0;
+  int32_t nb_fighters_removed = 0;
 
   if (nb_fighters <= map_state->armies.active_fighters)
     {
@@ -430,13 +427,13 @@ lw6ker_map_state_remove_fighters (LW6KER_MAP_STATE * map_state,
 	   * of a given team are deleted at once...
 	   */
 	  for (i = 0;
-	       i < LW6OPT_MAX_NB_TEAMS && nb_fighters_removed < nb_fighters;
+	       i < LW6MAP_MAX_NB_TEAMS && nb_fighters_removed < nb_fighters;
 	       ++i)
 	    {
 	      for (j = i;
 		   j < map_state->armies.active_fighters
 		   && nb_fighters_removed < nb_fighters;
-		   j += LW6OPT_MAX_NB_TEAMS)
+		   j += LW6MAP_MAX_NB_TEAMS)
 		{
 		  lw6ker_map_state_remove_fighter (map_state, j);
 		  nb_fighters_removed++;
@@ -447,7 +444,7 @@ lw6ker_map_state_remove_fighters (LW6KER_MAP_STATE * map_state,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("can't remove %d fighters, map only has %d"),
 		  nb_fighters, map_state->armies.active_fighters);
     }
@@ -455,14 +452,13 @@ lw6ker_map_state_remove_fighters (LW6KER_MAP_STATE * map_state,
   return ret;
 }
 
-LW6SYS_BOOL
-lw6ker_map_state_remove_team_fighters (LW6KER_MAP_STATE * map_state,
-				       LW6SYS_INT32 team_id,
-				       LW6SYS_INT32 nb_fighters)
+int
+lw6ker_map_state_remove_team_fighters (lw6ker_map_state_t * map_state,
+				       int32_t team_id, int32_t nb_fighters)
 {
-  LW6SYS_BOOL ret = 0;
-  LW6SYS_INT32 nb_fighters_removed = 0;
-  LW6SYS_INT32 i, j;
+  int ret = 0;
+  int32_t nb_fighters_removed = 0;
+  int32_t i, j;
 
   nb_fighters =
     lw6sys_min (nb_fighters, map_state->armies.fighters_per_team[team_id]);
@@ -470,11 +466,11 @@ lw6ker_map_state_remove_team_fighters (LW6KER_MAP_STATE * map_state,
   while (nb_fighters_removed < nb_fighters)
     {
       for (i = 0;
-	   i < LW6OPT_MAX_NB_TEAMS && nb_fighters_removed < nb_fighters; ++i)
+	   i < LW6MAP_MAX_NB_TEAMS && nb_fighters_removed < nb_fighters; ++i)
 	{
 	  for (j = i;
 	       j < map_state->armies.active_fighters
-	       && nb_fighters_removed < nb_fighters; j += LW6OPT_MAX_NB_TEAMS)
+	       && nb_fighters_removed < nb_fighters; j += LW6MAP_MAX_NB_TEAMS)
 	    {
 	      if (map_state->armies.fighters[j].team_id == team_id)
 		{
@@ -490,12 +486,11 @@ lw6ker_map_state_remove_team_fighters (LW6KER_MAP_STATE * map_state,
   return ret;
 }
 
-LW6KER_FIGHTER *
-lw6ker_map_state_get_fighter_safe (LW6KER_MAP_STATE * map_state,
-				   LW6SYS_INT32 layer, LW6SYS_INT32 x,
-				   LW6SYS_INT32 y)
+lw6ker_fighter_t *
+lw6ker_map_state_get_fighter_safe (lw6ker_map_state_t * map_state,
+				   int32_t layer, int32_t x, int32_t y)
 {
-  LW6KER_FIGHTER *ret = NULL;
+  lw6ker_fighter_t *ret = NULL;
   int fighter_id;
 
   if (layer >= 0 && layer < map_state->nb_layers && x >= 0
@@ -513,19 +508,19 @@ lw6ker_map_state_get_fighter_safe (LW6KER_MAP_STATE * map_state,
 };
 
 void
-lw6ker_map_state_print_debug (LW6KER_MAP_STATE * map_state)
+lw6ker_map_state_print_debug (lw6ker_map_state_t * map_state)
 {
-  LW6SYS_INT32 i;
+  int32_t i;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, "ker", _("active_fighters = %d"),
+  lw6sys_log (LW6SYS_LOG_DEBUG, _("active_fighters = %d"),
 	      map_state->armies.active_fighters);
-  lw6sys_log (LW6SYS_LOG_DEBUG, "ker", _("max_fighters = %d"),
+  lw6sys_log (LW6SYS_LOG_DEBUG, _("max_fighters = %d"),
 	      map_state->armies.max_fighters);
   if (map_state->armies.active_fighters > 0)
     {
-      for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
 	{
-	  lw6sys_log (LW6SYS_LOG_DEBUG, "ker",
+	  lw6sys_log (LW6SYS_LOG_DEBUG,
 		      _("team %d has %d fighters (%2.1f%%)"), i,
 		      map_state->armies.fighters_per_team[i],
 		      ((float) map_state->armies.fighters_per_team[i]) /
@@ -534,33 +529,33 @@ lw6ker_map_state_print_debug (LW6KER_MAP_STATE * map_state)
     }
 }
 
-LW6SYS_BOOL
-lw6ker_map_state_sanity_check (LW6KER_MAP_STATE * map_state)
+int
+lw6ker_map_state_sanity_check (lw6ker_map_state_t * map_state)
 {
-  LW6SYS_BOOL ret = 1;
-  LW6SYS_INT32 i;
-  LW6SYS_INT32 real_fighters_per_team[LW6OPT_MAX_NB_TEAMS];
-  LW6SYS_INT32 fighter_id;
-  LW6KER_FIGHTER fighter;
+  int ret = 1;
+  int32_t i;
+  int32_t real_fighters_per_team[LW6MAP_MAX_NB_TEAMS];
+  int32_t fighter_id;
+  lw6ker_fighter_t fighter;
 
   if (map_state->armies.active_fighters > map_state->armies.max_fighters)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("active_fighters (%d) > max_fighters (%d)"),
 		  map_state->armies.active_fighters,
 		  map_state->armies.max_fighters);
       ret = 0;
     }
-  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
       real_fighters_per_team[i] = 0;
     }
   for (i = 0; i < map_state->armies.active_fighters; ++i)
     {
       fighter = map_state->armies.fighters[i];
-      if (fighter.team_id >= LW6OPT_MAX_NB_TEAMS)	// <0 check useless, unsigned
+      if (fighter.team_id >= LW6MAP_MAX_NB_TEAMS)	// <0 check useless, unsigned
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("fighter.team_id out of range (%d) for fighter %d"),
 		      fighter.team_id, i);
@@ -572,7 +567,7 @@ lw6ker_map_state_sanity_check (LW6KER_MAP_STATE * map_state)
 					 fighter.pos.x, fighter.pos.y);
       if (i != fighter_id)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("fighter %d in armies array pretends to be at layer=%d,x=%d,y=%d, but in fact there is fighter %d there from slots point of view"),
 		      i, fighter.layer, fighter.pos.x, fighter.pos.y,
@@ -580,12 +575,12 @@ lw6ker_map_state_sanity_check (LW6KER_MAP_STATE * map_state)
 	  ret = 0;
 	}
     }
-  for (i = 0; i < LW6OPT_MAX_NB_TEAMS; ++i)
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
     {
       if (map_state->armies.fighters_per_team[i] > 0
 	  && !map_state->teams[i].active)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("team %d pretends to have %d fighters but is inactive"),
 		      i, map_state->armies.fighters_per_team[i]);
@@ -593,7 +588,7 @@ lw6ker_map_state_sanity_check (LW6KER_MAP_STATE * map_state)
 	}
       if (map_state->armies.fighters_per_team[i] != real_fighters_per_team[i])
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("team %d pretends to have %d fighters but counting them one founds %d"),
 		      i, map_state->armies.fighters_per_team[i],
@@ -609,9 +604,9 @@ lw6ker_map_state_sanity_check (LW6KER_MAP_STATE * map_state)
  * Applies the cursors before spreading the gradient.
  */
 void
-lw6ker_map_state_spread_gradient (LW6KER_MAP_STATE * map_state,
-				  LW6OPT_STATIC * options,
-				  LW6SYS_INT32 nb_spreads)
+lw6ker_map_state_spread_gradient (lw6ker_map_state_t * map_state,
+				  lw6map_options_t * options,
+				  int32_t nb_spreads)
 {
   int i, j;
 
@@ -646,26 +641,24 @@ lw6ker_map_state_spread_gradient (LW6KER_MAP_STATE * map_state,
     }
 }
 
-LW6SYS_BOOL
-_lw6ker_map_state_is_slot_free (LW6KER_MAP_STATE * map_state,
-				LW6SYS_INT32 layer, LW6SYS_INT32 x,
-				LW6SYS_INT32 y)
+int
+_lw6ker_map_state_is_slot_free (lw6ker_map_state_t * map_state,
+				int32_t layer, int32_t x, int32_t y)
 {
   return (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y) >= 0 &&
 	  lw6ker_map_state_get_fighter_id (map_state, layer, x, y) < 0);
 }
 
-LW6SYS_BOOL
-_lw6ker_map_state_is_enemy_there (LW6KER_MAP_STATE * map_state,
-				  LW6SYS_INT32 team_id,
-				  LW6SYS_INT32 layer, LW6SYS_INT32 x,
-				  LW6SYS_INT32 y)
+int
+_lw6ker_map_state_is_enemy_there (lw6ker_map_state_t * map_state,
+				  int32_t team_id,
+				  int32_t layer, int32_t x, int32_t y)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   if (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y) >= 0)
     {
-      LW6SYS_INT32 enemy_id;
+      int32_t enemy_id;
 
       enemy_id = lw6ker_map_state_get_fighter_id (map_state, layer, x, y);
       if (enemy_id >= 0)
@@ -677,17 +670,16 @@ _lw6ker_map_state_is_enemy_there (LW6KER_MAP_STATE * map_state,
   return ret;
 }
 
-LW6SYS_BOOL
-_lw6ker_map_state_is_ally_there (LW6KER_MAP_STATE * map_state,
-				 LW6SYS_INT32 team_id,
-				 LW6SYS_INT32 layer, LW6SYS_INT32 x,
-				 LW6SYS_INT32 y)
+int
+_lw6ker_map_state_is_ally_there (lw6ker_map_state_t * map_state,
+				 int32_t team_id,
+				 int32_t layer, int32_t x, int32_t y)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   if (lw6ker_map_struct_get_zone_id (map_state->map_struct, x, y) >= 0)
     {
-      LW6SYS_INT32 ally_id;
+      int32_t ally_id;
 
       ally_id = lw6ker_map_state_get_fighter_id (map_state, layer, x, y);
       if (ally_id >= 0)
@@ -699,11 +691,11 @@ _lw6ker_map_state_is_ally_there (LW6KER_MAP_STATE * map_state,
   return ret;
 }
 
-static LW6SYS_INT32
-find_straight_dir (LW6SYS_XY from, LW6SYS_XY to, LW6SYS_BOOL parity)
+static int32_t
+find_straight_dir (lw6sys_xy_t from, lw6sys_xy_t to, int parity)
 {
-  LW6SYS_INT32 ret;
-  LW6SYS_INT32 straight_dir = 0;
+  int32_t ret;
+  int32_t straight_dir = 0;
 
   if (to.y < from.y)
     {
@@ -730,15 +722,15 @@ find_straight_dir (LW6SYS_XY from, LW6SYS_XY to, LW6SYS_BOOL parity)
 /*
  * Higher potential = closer to the cursor
  */
-static LW6SYS_INT32
-find_best_dir (LW6KER_MAP_STATE * map_state, LW6KER_FIGHTER * fighter,
-	       LW6SYS_BOOL parity)
+static int32_t
+find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
+	       int parity)
 {
-  LW6SYS_INT32 ret = fighter->last_direction;
-  LW6SYS_INT32 zone_id =
+  int32_t ret = fighter->last_direction;
+  int32_t zone_id =
     lw6ker_map_struct_get_zone_id (map_state->map_struct, fighter->pos.x,
 				   fighter->pos.y);
-  LW6KER_ZONE_STATE *zone_states =
+  lw6ker_zone_state_t *zone_states =
     map_state->teams[fighter->team_id].gradient;
 
   if (zone_id >= 0)
@@ -755,12 +747,12 @@ find_best_dir (LW6KER_MAP_STATE * map_state, LW6KER_FIGHTER * fighter,
 	  /*
 	   * Nothing in cache, we calculate it
 	   */
-	  LW6SYS_INT32 i;
-	  LW6KER_ZONE_STRUCT *zone_structs = map_state->map_struct->zones;
-	  LW6SYS_INT32 neighbour_zone_id;
-	  LW6KER_ZONE_STRUCT *fighter_zone_struct;
+	  int32_t i;
+	  lw6ker_zone_struct_t *zone_structs = map_state->map_struct->zones;
+	  int32_t neighbour_zone_id;
+	  lw6ker_zone_struct_t *fighter_zone_struct;
 	  fighter_zone_struct = &(zone_structs[zone_id]);
-	  LW6SYS_INT32 best_potential = zone_states[zone_id].potential;
+	  int32_t best_potential = zone_states[zone_id].potential;
 
 	  ret = -1;
 
@@ -826,7 +818,7 @@ find_best_dir (LW6KER_MAP_STATE * map_state, LW6KER_FIGHTER * fighter,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("fighter with incorrect zone_id=%d (pos=%d,%d)"), zone_id,
 		  (int) fighter->pos.x, (int) fighter->pos.y);
     }
@@ -842,8 +834,8 @@ find_best_dir (LW6KER_MAP_STATE * map_state, LW6KER_FIGHTER * fighter,
  * iy means y is wrapped and inversed
  */
 static void
-polarity_func_nowrap (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-		      POLARITY_DATA * polarity_data, LW6SYS_INT32 move_dir)
+polarity_func_nowrap (int32_t * x, int32_t * y,
+		      polarity_data_t * polarity_data, int32_t move_dir)
 {
   /*
    * Not that in this case there's no border check, in fact we
@@ -856,10 +848,10 @@ polarity_func_nowrap (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
 }
 
 static void
-polarity_func_x (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-		 POLARITY_DATA * polarity_data, LW6SYS_INT32 move_dir)
+polarity_func_x (int32_t * x, int32_t * y,
+		 polarity_data_t * polarity_data, int32_t move_dir)
 {
-  LW6SYS_INT32 tmp_x;
+  int32_t tmp_x;
 
   tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
   (*y) = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
@@ -879,10 +871,10 @@ polarity_func_x (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
 }
 
 static void
-polarity_func_y (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-		 POLARITY_DATA * polarity_data, LW6SYS_INT32 move_dir)
+polarity_func_y (int32_t * x, int32_t * y,
+		 polarity_data_t * polarity_data, int32_t move_dir)
 {
-  LW6SYS_INT32 tmp_y;
+  int32_t tmp_y;
 
   (*x) = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
   tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
@@ -902,10 +894,10 @@ polarity_func_y (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
 }
 
 static void
-polarity_func_ix (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-		  POLARITY_DATA * polarity_data, LW6SYS_INT32 move_dir)
+polarity_func_ix (int32_t * x, int32_t * y,
+		  polarity_data_t * polarity_data, int32_t move_dir)
 {
-  LW6SYS_INT32 tmp_x, tmp_y;
+  int32_t tmp_x, tmp_y;
 
   tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
   tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
@@ -928,10 +920,10 @@ polarity_func_ix (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
 }
 
 static void
-polarity_func_iy (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-		  POLARITY_DATA * polarity_data, LW6SYS_INT32 move_dir)
+polarity_func_iy (int32_t * x, int32_t * y,
+		  polarity_data_t * polarity_data, int32_t move_dir)
 {
-  LW6SYS_INT32 tmp_x, tmp_y;
+  int32_t tmp_x, tmp_y;
 
   tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
   tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
@@ -954,10 +946,10 @@ polarity_func_iy (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
 }
 
 static void
-polarity_func_x_y (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-		   POLARITY_DATA * polarity_data, LW6SYS_INT32 move_dir)
+polarity_func_x_y (int32_t * x, int32_t * y,
+		   polarity_data_t * polarity_data, int32_t move_dir)
 {
-  LW6SYS_INT32 tmp_x, tmp_y;
+  int32_t tmp_x, tmp_y;
 
   tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
   tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
@@ -990,10 +982,10 @@ polarity_func_x_y (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
 }
 
 static void
-polarity_func_ix_y (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-		    POLARITY_DATA * polarity_data, LW6SYS_INT32 move_dir)
+polarity_func_ix_y (int32_t * x, int32_t * y,
+		    polarity_data_t * polarity_data, int32_t move_dir)
 {
-  LW6SYS_INT32 tmp_x, tmp_y;
+  int32_t tmp_x, tmp_y;
 
   tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
   tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
@@ -1025,10 +1017,10 @@ polarity_func_ix_y (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
 }
 
 static void
-polarity_func_x_iy (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-		    POLARITY_DATA * polarity_data, LW6SYS_INT32 move_dir)
+polarity_func_x_iy (int32_t * x, int32_t * y,
+		    polarity_data_t * polarity_data, int32_t move_dir)
 {
-  LW6SYS_INT32 tmp_x, tmp_y;
+  int32_t tmp_x, tmp_y;
 
   tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
   tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
@@ -1060,10 +1052,10 @@ polarity_func_x_iy (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
 }
 
 static void
-polarity_func_ix_iy (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-		     POLARITY_DATA * polarity_data, LW6SYS_INT32 move_dir)
+polarity_func_ix_iy (int32_t * x, int32_t * y,
+		     polarity_data_t * polarity_data, int32_t move_dir)
 {
-  LW6SYS_INT32 tmp_x, tmp_y;
+  int32_t tmp_x, tmp_y;
 
   tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
   tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
@@ -1103,33 +1095,33 @@ polarity_func_ix_iy (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
  * in Liquid War 5.
  */
 void
-lw6ker_map_state_move_fighters (LW6KER_MAP_STATE * map_state,
-				LW6SYS_BOOL parity, LW6OPT_STATIC * options,
-				LW6SYS_INT32 nb_moves)
+lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
+				int parity, lw6map_options_t * options,
+				int32_t nb_moves)
 {
   int i, j, k;
-  LW6KER_ARMIES *armies = &(map_state->armies);
-  LW6SYS_INT32 active_fighters = armies->active_fighters;
-  LW6KER_FIGHTER *fighter = NULL;
-  LW6SYS_INT32 layer, x, y;
-  LW6SYS_INT32 best_dir, test_dir;
-  LW6SYS_INT32 fighter_team_id, fighter_layer, fighter_x, fighter_y;
-  LW6SYS_INT32 loop_init, loop_step;
-  LW6SYS_BOOL done_with_fighter;
-  LW6SYS_INT32 fighter_attack;
-  LW6SYS_INT32 fighter_defense;
-  LW6SYS_INT32 fighter_new_health;
-  LW6SYS_INT32 side_attack_factor;
-  LW6SYS_INT32 side_defense_factor;
-  LW6SYS_INT32 nb_move_tries;
-  LW6SYS_INT32 nb_attack_tries;
-  LW6SYS_INT32 nb_defense_tries;
-  LW6SYS_INT32 fighter_side_attack;
-  LW6SYS_INT32 fighter_side_defense;
-  POLARITY_DATA polarity_data;
-  void (*polarity_func) (LW6SYS_INT32 * x, LW6SYS_INT32 * y,
-			 POLARITY_DATA * polarity_data,
-			 LW6SYS_INT32 move_dir) = NULL;
+  lw6ker_armies_t *armies = &(map_state->armies);
+  int32_t active_fighters = armies->active_fighters;
+  lw6ker_fighter_t *fighter = NULL;
+  int32_t layer, x, y;
+  int32_t best_dir, test_dir;
+  int32_t fighter_team_id, fighter_layer, fighter_x, fighter_y;
+  int32_t loop_init, loop_step;
+  int done_with_fighter;
+  int32_t fighter_attack;
+  int32_t fighter_defense;
+  int32_t fighter_new_health;
+  int32_t side_attack_factor;
+  int32_t side_defense_factor;
+  int32_t nb_move_tries;
+  int32_t nb_attack_tries;
+  int32_t nb_defense_tries;
+  int32_t fighter_side_attack;
+  int32_t fighter_side_defense;
+  polarity_data_t polarity_data;
+  void (*polarity_func) (int32_t * x, int32_t * y,
+			 polarity_data_t * polarity_data,
+			 int32_t move_dir) = NULL;
 
   fighter_attack = options->fighter_attack;
   fighter_defense = options->fighter_defense;
