@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
 #include <string.h>
 #include <math.h>
 
@@ -40,27 +39,27 @@
  * zones, it's usefull to have this in memory.
  * This was called "MESHER" in Liquid War 5.
  */
-typedef struct DRAFT_ZONE_STRUCT
+typedef struct draft_zone_s
 {
-  LW6SYS_XY pos;
-  LW6SYS_INT32 used;
-  LW6SYS_INT32 size;
-  LW6SYS_INT32 link[LW6KER_NB_DIRS];
-  LW6SYS_INT32 corres;
+  lw6sys_xy_t pos;
+  int32_t used;
+  int32_t size;
+  int32_t link[LW6KER_NB_DIRS];
+  int32_t corres;
 }
-DRAFT_ZONE;
+draft_zone_t;
 
-typedef struct DRAFT_ZONES_STRUCT
+typedef struct draft_zones_s
 {
-  LW6SYS_WH shape;
-  LW6SYS_INT32 max_zone_size;
-  DRAFT_ZONE *zones;
+  lw6sys_wh_t shape;
+  int32_t max_zone_size;
+  draft_zone_t *zones;
 }
-DRAFT_ZONES;
+draft_zones_t;
 
 void
-_lw6ker_map_struct_update_checksum (LW6KER_MAP_STRUCT *
-				    map_struct, LW6SYS_UINT32 * checksum)
+_lw6ker_map_struct_update_checksum (lw6ker_map_struct_t *
+				    map_struct, u_int32_t * checksum)
 {
   int i;
 
@@ -81,17 +80,17 @@ _lw6ker_map_struct_update_checksum (LW6KER_MAP_STRUCT *
     }
 }
 
-static LW6SYS_INT32
-relative_index (LW6MAP_MAP * map, LW6SYS_INT32 x, LW6SYS_INT32 y)
+static int32_t
+relative_index (lw6map_level_t * level, int32_t x, int32_t y)
 {
-  LW6SYS_INT32 w, h;
+  int32_t w, h;
 
-  w = map->depth.shape.w;
-  h = map->depth.shape.h;
+  w = level->depth.shape.w;
+  h = level->depth.shape.h;
 
   if (x >= w)
     {
-      switch (map->param.options.x_polarity)
+      switch (level->param.options.x_polarity)
 	{
 	case 1:
 	  x = 0;
@@ -101,7 +100,7 @@ relative_index (LW6MAP_MAP * map, LW6SYS_INT32 x, LW6SYS_INT32 y)
 	  y = h - 1 - y;
 	  break;
 	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _("x too great (%d/%d) for a non wrapped map"), x, w);
 	  break;
 	}
@@ -109,7 +108,7 @@ relative_index (LW6MAP_MAP * map, LW6SYS_INT32 x, LW6SYS_INT32 y)
 
   if (y >= h)
     {
-      switch (map->param.options.y_polarity)
+      switch (level->param.options.y_polarity)
 	{
 	case 1:
 	  y = 0;
@@ -119,7 +118,7 @@ relative_index (LW6MAP_MAP * map, LW6SYS_INT32 x, LW6SYS_INT32 y)
 	  y = 0;
 	  break;
 	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _("y too great (%d/%d) for a non wrapped map"), y, h);
 	  break;
 	}
@@ -127,7 +126,7 @@ relative_index (LW6MAP_MAP * map, LW6SYS_INT32 x, LW6SYS_INT32 y)
 
   if (x < 0)
     {
-      switch (map->param.options.x_polarity)
+      switch (level->param.options.x_polarity)
 	{
 	case 1:
 	  x = w - 1;
@@ -137,7 +136,7 @@ relative_index (LW6MAP_MAP * map, LW6SYS_INT32 x, LW6SYS_INT32 y)
 	  y = h - 1 - y;
 	  break;
 	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _("x too small (%d) for a non wrapped map"), x);
 	  break;
 	}
@@ -145,7 +144,7 @@ relative_index (LW6MAP_MAP * map, LW6SYS_INT32 x, LW6SYS_INT32 y)
 
   if (y < 0)
     {
-      switch (map->param.options.y_polarity)
+      switch (level->param.options.y_polarity)
 	{
 	case 1:
 	  y = h - 1;
@@ -155,7 +154,7 @@ relative_index (LW6MAP_MAP * map, LW6SYS_INT32 x, LW6SYS_INT32 y)
 	  y = h - 1;
 	  break;
 	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _("y too small (%d) for a non wrapped map"), y);
 	  break;
 	}
@@ -165,38 +164,38 @@ relative_index (LW6MAP_MAP * map, LW6SYS_INT32 x, LW6SYS_INT32 y)
 }
 
 /*
- * Creates a new DRAFT_ZONES object. The idea is to create a structure which
+ * Creates a new draft_zones_t object. The idea is to create a structure which
  * is of the same nature as the final MAP_STRUCT "zones", but unoptimized.
  * We create a structure (a "MESH" in Liquid War 5)) where each square
  * has pointers on its neighbours. As there are 12 directions, these is
  * very redundant. This is just a temporary struct which will be
  * optimized afterwards.
  */
-static DRAFT_ZONES *
-draft_zones_new (LW6MAP_MAP * map)
+static draft_zones_t *
+draft_zones_new (lw6map_level_t * level)
 {
-  DRAFT_ZONES *ret;
+  draft_zones_t *ret;
 
-  ret = (DRAFT_ZONES *) LW6SYS_CALLOC (sizeof (DRAFT_ZONES));
+  ret = (draft_zones_t *) LW6SYS_CALLOC (sizeof (draft_zones_t));
   if (ret)
     {
-      LW6SYS_INT32 w, h, size;
+      int32_t w, h, size;
 
-      ret->shape = map->depth.shape;
+      ret->shape = level->depth.shape;
       ret->max_zone_size = 1;
 
       w = ret->shape.w;
       h = ret->shape.h;
       size = w * h;
 
-      if (size >= map->param.options.min_map_surface)
+      if (size >= level->param.options.min_map_surface)
 	{
 	  ret->zones =
-	    (DRAFT_ZONE *) LW6SYS_CALLOC (size * sizeof (DRAFT_ZONE));
+	    (draft_zone_t *) LW6SYS_CALLOC (size * sizeof (draft_zone_t));
 
 	  if (ret->zones)
 	    {
-	      LW6SYS_INT32 i, j, x, y, x1, x2, y1, y2;
+	      int32_t i, j, x, y, x1, x2, y1, y2;
 
 	      for (i = 0; i < size; ++i)
 		{
@@ -216,7 +215,7 @@ draft_zones_new (LW6MAP_MAP * map)
 		      ret->zones[i].pos.x = x;
 		      ret->zones[i].pos.y = y;
 		      ret->zones[i].used =
-			lw6map_depth_get (&(map->depth), x, y) ? 1 : 0;
+			lw6map_depth_get (&(level->depth), x, y) ? 1 : 0;
 		    }
 		}
 
@@ -225,15 +224,15 @@ draft_zones_new (LW6MAP_MAP * map)
 	      y1 = 0;
 	      y2 = h;
 
-	      if (map->param.options.x_polarity != 1
-		  && map->param.options.x_polarity != -1)
+	      if (level->param.options.x_polarity != 1
+		  && level->param.options.x_polarity != -1)
 		{
 		  x1++;
 		  x2--;
 		}
 
-	      if (map->param.options.y_polarity != 1
-		  && map->param.options.y_polarity != -1)
+	      if (level->param.options.y_polarity != 1
+		  && level->param.options.y_polarity != -1)
 		{
 		  y1++;
 		  y2--;
@@ -243,50 +242,50 @@ draft_zones_new (LW6MAP_MAP * map)
 		{
 		  for (x = x1; x < x2; ++x)
 		    {
-		      i = relative_index (map, x, y);
+		      i = relative_index (level, x, y);
 
 		      if (ret->zones[i].used)
 			{
-			  j = relative_index (map, x, y - 1);
+			  j = relative_index (level, x, y - 1);
 			  if (ret->zones[j].used)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_NNW] =
 				ret->zones[i].link[LW6KER_DIR_NNE] = j;
 			    }
-			  j = relative_index (map, x + 1, y - 1);
+			  j = relative_index (level, x + 1, y - 1);
 			  if (ret->zones[j].used)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_NE] = j;
 			    }
-			  j = relative_index (map, x + 1, y);
+			  j = relative_index (level, x + 1, y);
 			  if (ret->zones[j].used)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_ENE] =
 				ret->zones[i].link[LW6KER_DIR_ESE] = j;
 			    }
-			  j = relative_index (map, x + 1, y + 1);
+			  j = relative_index (level, x + 1, y + 1);
 			  if (ret->zones[j].used)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_SE] = j;
 			    }
-			  j = relative_index (map, x, y + 1);
+			  j = relative_index (level, x, y + 1);
 			  if (ret->zones[j].used)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_SSE] =
 				ret->zones[i].link[LW6KER_DIR_SSW] = j;
 			    }
-			  j = relative_index (map, x - 1, y + 1);
+			  j = relative_index (level, x - 1, y + 1);
 			  if (ret->zones[j].used)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_SW] = j;
 			    }
-			  j = relative_index (map, x - 1, y);
+			  j = relative_index (level, x - 1, y);
 			  if (ret->zones[j].used)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_WSW] =
 				ret->zones[i].link[LW6KER_DIR_WNW] = j;
 			    }
-			  j = relative_index (map, x - 1, y - 1);
+			  j = relative_index (level, x - 1, y - 1);
 			  if (ret->zones[j].used)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_NW] = j;
@@ -297,15 +296,15 @@ draft_zones_new (LW6MAP_MAP * map)
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	      lw6sys_log (LW6SYS_LOG_WARNING,
 			  _("unable to allocate %d draft zones"), size);
 	    }
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _("map is too small, size=%d, MIN_MAP_SIZE=%d"),
-		      size, map->param.options.min_map_surface);
+		      size, level->param.options.min_map_surface);
 	}
     }
 
@@ -313,7 +312,7 @@ draft_zones_new (LW6MAP_MAP * map)
 }
 
 static void
-draft_zones_free (DRAFT_ZONES * draft_zones)
+draft_zones_free (draft_zones_t * draft_zones)
 {
   if (draft_zones)
     {
@@ -326,21 +325,21 @@ draft_zones_free (DRAFT_ZONES * draft_zones)
 }
 
 /*
- * Here we scan the whole DRAFT_ZONES data, and whenever we find
+ * Here we scan the whole draft_zones_t data, and whenever we find
  * 4 zones which form a square and respect "some conditions",
  * we group them into a bigger zone. The only thing to be carefull
  * about is to handle correctly all the pointers (links) on
  * other zones, especially those that link back to the squares
  * we suppress.
  */
-static LW6SYS_INT32
-draft_zones_group (DRAFT_ZONES * draft_zones, LW6SYS_INT32 step)
+static int32_t
+draft_zones_group (draft_zones_t * draft_zones, int32_t step)
 {
-  LW6SYS_INT32 found = 0;
-  LW6SYS_INT32 x, y, w, h, size, i, j, k;
-  LW6SYS_INT32 i_ne, i_se, i_sw, i_nw;
-  DRAFT_ZONE *zone_ne, *zone_se, *zone_sw, *zone_nw;
-  LW6SYS_INT32 *test;
+  int32_t found = 0;
+  int32_t x, y, w, h, size, i, j, k;
+  int32_t i_ne, i_se, i_sw, i_nw;
+  draft_zone_t *zone_ne, *zone_se, *zone_sw, *zone_nw;
+  int32_t *test;
 
   w = draft_zones->shape.w;
   h = draft_zones->shape.h;
@@ -451,7 +450,7 @@ draft_zones_group (DRAFT_ZONES * draft_zones, LW6SYS_INT32 step)
 }
 
 /*
- * Transform the temporary DRAFT_ZONES into the proper
+ * Transform the temporary draft_zones_t into the proper
  * final MAP_STRUCT. The major change is to actually
  * delete and remove from memory all the unused ZONES.
  * We "compact" the zones so that instead of using
@@ -461,13 +460,13 @@ draft_zones_group (DRAFT_ZONES * draft_zones, LW6SYS_INT32 step)
  * usage is always a good thing, the more we reduce it,
  * the more we get a chance to have things cached.
  */
-static LW6SYS_BOOL
-draft_zones_to_map_struct (LW6KER_MAP_STRUCT * map_struct,
-			   DRAFT_ZONES * draft_zones)
+static int
+draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
+			   draft_zones_t * draft_zones)
 {
-  LW6SYS_BOOL ret = 0;
-  LW6SYS_INT32 w, h, size, nb_zones;
-  LW6SYS_INT32 i, j, k, temp;
+  int ret = 0;
+  int32_t w, h, size, nb_zones;
+  int32_t i, j, k, temp;
 
   w = draft_zones->shape.w;
   h = draft_zones->shape.h;
@@ -489,8 +488,8 @@ draft_zones_to_map_struct (LW6KER_MAP_STRUCT * map_struct,
   map_struct->max_zone_size = draft_zones->max_zone_size;
 
   map_struct->zones =
-    (LW6KER_ZONE_STRUCT *) LW6SYS_MALLOC (nb_zones *
-					  sizeof (LW6KER_ZONE_STRUCT));
+    (lw6ker_zone_struct_t *) LW6SYS_MALLOC (nb_zones *
+					    sizeof (lw6ker_zone_struct_t));
 
   if (map_struct->zones)
     {
@@ -527,7 +526,7 @@ draft_zones_to_map_struct (LW6KER_MAP_STRUCT * map_struct,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to create zones for map struct"));
     }
 
@@ -538,22 +537,22 @@ draft_zones_to_map_struct (LW6KER_MAP_STRUCT * map_struct,
  * Create the slots, the main interest in doing this is to
  * have a quick way to get the right zone for a given (x,y).
  */
-static LW6SYS_BOOL
-init_slots (LW6KER_MAP_STRUCT * map_struct, LW6MAP_MAP * map)
+static int
+init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   map_struct->slots =
-    (LW6KER_SLOT_STRUCT *) LW6SYS_CALLOC (map_struct->shape.w *
-					  map_struct->shape.h *
-					  sizeof (LW6KER_SLOT_STRUCT));
+    (lw6ker_slot_struct_t *) LW6SYS_CALLOC (map_struct->shape.w *
+					    map_struct->shape.h *
+					    sizeof (lw6ker_slot_struct_t));
 
   if (map_struct)
     {
-      LW6SYS_INT32 i, x, y;
-      LW6SYS_INT32 depth;
+      int32_t i, x, y;
+      int32_t depth;
 
-      LW6KER_ZONE_STRUCT *zone;
+      lw6ker_zone_struct_t *zone;
 
       /*
        * Set up the id lookup table
@@ -588,7 +587,7 @@ init_slots (LW6KER_MAP_STRUCT * map_struct, LW6MAP_MAP * map)
 	{
 	  for (x = 0; x < map_struct->shape.w; ++x)
 	    {
-	      depth = lw6map_depth_get (&(map->depth), x, y);
+	      depth = lw6map_depth_get (&(level->depth), x, y);
 	      lw6ker_map_struct_set_depth (map_struct, x, y, depth);
 	      map_struct->room_for_armies += depth;
 	      if (map_struct->max_depth < depth)
@@ -602,7 +601,7 @@ init_slots (LW6KER_MAP_STRUCT * map_struct, LW6MAP_MAP * map)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to create slots for map struct"));
     }
 
@@ -615,7 +614,7 @@ init_slots (LW6KER_MAP_STRUCT * map_struct, LW6MAP_MAP * map)
  * of wether it's usefull to implement this. Debugging tool.
  */
 float
-_lw6ker_map_struct_get_compression (LW6KER_MAP_STRUCT * map_struct)
+_lw6ker_map_struct_get_compression (lw6ker_map_struct_t * map_struct)
 {
   float ret;
 
@@ -627,26 +626,27 @@ _lw6ker_map_struct_get_compression (LW6KER_MAP_STRUCT * map_struct)
 }
 
 /*
- * This is one key function: it calls the transformation of a LW6MAP_MAP,
+ * This is one key function: it calls the transformation of a lw6map_level_t,
  * that is a plain object which reflects only the content of PNG & XML
  * files, into an in-memory "ready for algorithmic stuff" structure.
  */
-LW6SYS_BOOL
-_lw6ker_map_struct_init (LW6KER_MAP_STRUCT * map_struct, LW6MAP_MAP * map)
+int
+_lw6ker_map_struct_init (lw6ker_map_struct_t * map_struct,
+			 lw6map_level_t * level)
 {
-  LW6SYS_BOOL ret = 0;
-  DRAFT_ZONES *draft_zones;
+  int ret = 0;
+  draft_zones_t *draft_zones;
 
-  memset (map_struct, 0, sizeof (LW6KER_MAP_STRUCT));
+  memset (map_struct, 0, sizeof (lw6ker_map_struct_t));
 
-  draft_zones = draft_zones_new (map);
+  draft_zones = draft_zones_new (level);
   if (draft_zones)
     {
-      LW6SYS_INT32 i = 1;
+      int32_t i = 1;
 
       ret = 1;
 
-      while (i <= map->param.options.max_zone_size / 2
+      while (i <= level->param.options.max_zone_size / 2
 	     && draft_zones_group (draft_zones, i))
 	{
 	  i *= 2;
@@ -656,11 +656,11 @@ _lw6ker_map_struct_init (LW6KER_MAP_STRUCT * map_struct, LW6MAP_MAP * map)
 
       draft_zones_free (draft_zones);
 
-      ret = ret && init_slots (map_struct, map);
+      ret = ret && init_slots (map_struct, level);
 
       if (ret)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, "ker",
+	  lw6sys_log (LW6SYS_LOG_INFO,
 		      _
 		      ("map struct created %dx%d, %d zones, %1.1f%% compression"),
 		      map_struct->shape.w, map_struct->shape.h,
@@ -674,7 +674,7 @@ _lw6ker_map_struct_init (LW6KER_MAP_STRUCT * map_struct, LW6MAP_MAP * map)
 }
 
 void
-_lw6ker_map_struct_clear (LW6KER_MAP_STRUCT * map_struct)
+_lw6ker_map_struct_clear (lw6ker_map_struct_t * map_struct)
 {
   if (map_struct)
     {
@@ -686,15 +686,15 @@ _lw6ker_map_struct_clear (LW6KER_MAP_STRUCT * map_struct)
 	{
 	  LW6SYS_FREE (map_struct->slots);
 	}
-      memset (map_struct, 0, sizeof (LW6KER_MAP_STRUCT));
+      memset (map_struct, 0, sizeof (lw6ker_map_struct_t));
     }
 }
 
 void
-lw6ker_map_struct_find_free_slot_near (LW6KER_MAP_STRUCT * map_struct,
-				       LW6SYS_XY * there, LW6SYS_XY here)
+lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t * map_struct,
+				       lw6sys_xy_t * there, lw6sys_xy_t here)
 {
-  LW6SYS_BOOL found = 0;
+  int found = 0;
 
   there->x = there->y = 0;
 
@@ -705,9 +705,9 @@ lw6ker_map_struct_find_free_slot_near (LW6KER_MAP_STRUCT * map_struct,
     }
   else
     {
-      LW6SYS_INT32 angle, radius;
-      LW6SYS_INT32 max_radius, max_angle;
-      LW6SYS_INT32 x, y;
+      int32_t angle, radius;
+      int32_t max_radius, max_angle;
+      int32_t x, y;
 
       max_radius = map_struct->shape.w + map_struct->shape.h;	// +, not *
       for (radius = 1; radius < max_radius && !found; ++radius)
@@ -739,7 +739,7 @@ lw6ker_map_struct_find_free_slot_near (LW6KER_MAP_STRUCT * map_struct,
 
   if (!found)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to find a free zone near %dx%d"), here.x, here.y);
     }
 }
