@@ -1,23 +1,23 @@
 /*
-Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Liquid War 6 is a unique multiplayer wargame.
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
-Contact author        : ufoot@ufoot.org
+  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
+  Contact author        : ufoot@ufoot.org
 */
 
 #include "config.h"
@@ -28,18 +28,18 @@ Contact author        : ufoot@ufoot.org
  * MOVE_? offset or used when moving fighters,
  * and calculating "what's in that direction?".
  */
-LW6SYS_INT32 _LW6KER_TABLES_MOVE_X_OFFSET[LW6KER_NB_DIRS] =
+int32_t _LW6KER_TABLES_MOVE_X_OFFSET[LW6KER_NB_DIRS] =
   { 0, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1, 0 };
-LW6SYS_INT32 _LW6KER_TABLES_MOVE_Y_OFFSET[LW6KER_NB_DIRS] =
+int32_t _LW6KER_TABLES_MOVE_Y_OFFSET[LW6KER_NB_DIRS] =
   { -1, -1, 0, 0, 1, 1, 1, 1, 0, 0, -1, -1 };
 
 /*
  * Used to try a direction or another one, when something
  * is blocking.
  */
-LW6SYS_INT32
+int32_t
   _LW6KER_TABLES_MOVE_DIR[LW6KER_NB_PARITIES][LW6KER_NB_DIRS]
-  [LW6OPT_MAX_NB_DIR_TRIES] =
+  [LW6MAP_MAX_NB_DIR_TRIES] =
 {
   {				// parity 0
     {
@@ -148,7 +148,7 @@ LW6SYS_INT32
  * it can contain invalid dirs (-1) in case we are just here and
  * need not move.
  */
-LW6SYS_INT32
+int32_t
   _LW6KER_TABLES_STRAIGHT_DIRS[LW6KER_NB_PARITIES][_LW6KER_NB_STRAIGHT_DIRS] =
 {
   {				// parity 0
