@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -26,18 +26,18 @@
 #include "ker.h"
 #include "ker-internal.h"
 
-LW6SYS_BOOL
-_lw6ker_team_init (LW6KER_TEAM * team, LW6KER_MAP_STRUCT * map_struct,
-		   LW6OPT_STATIC * options)
+int
+_lw6ker_team_init (lw6ker_team_t * team, lw6ker_map_struct_t * map_struct,
+		   lw6map_options_t * options)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
   int i;
 
   team->active = 0;
   team->map_struct = map_struct;
   team->gradient =
-    (LW6KER_ZONE_STATE *) LW6SYS_CALLOC (map_struct->nb_zones *
-					 sizeof (LW6KER_ZONE_STATE));
+    (lw6ker_zone_state_t *) LW6SYS_CALLOC (map_struct->nb_zones *
+					   sizeof (lw6ker_zone_state_t));
   team->cursor_ref_pot = options->cursor_pot_init;
   team->last_spread_dir = LW6KER_DIR_NNE;
   lw6ker_cursor_array_clear (&(team->cursor_array));
@@ -62,35 +62,34 @@ _lw6ker_team_init (LW6KER_TEAM * team, LW6KER_MAP_STRUCT * map_struct,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
-		  _("unable to allocate gradient"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to allocate gradient"));
     }
 
   return ret;
 }
 
 void
-_lw6ker_team_clear (LW6KER_TEAM * team)
+_lw6ker_team_clear (lw6ker_team_t * team)
 {
   if (team->gradient)
     {
       LW6SYS_FREE (team->gradient);
     }
 
-  memset (team, 0, sizeof (LW6KER_TEAM));
+  memset (team, 0, sizeof (lw6ker_team_t));
 }
 
-LW6SYS_BOOL
-_lw6ker_team_copy (LW6KER_TEAM * dst, LW6KER_TEAM * src)
+int
+_lw6ker_team_copy (lw6ker_team_t * dst, lw6ker_team_t * src)
 {
-  LW6SYS_BOOL ret = 0;
+  int ret = 0;
 
   if (dst && src && dst->map_struct && src->map_struct
       && dst->map_struct == src->map_struct)
     {
       dst->active = src->active;
       memcpy (dst->gradient, src->gradient,
-	      src->map_struct->nb_zones * sizeof (LW6KER_ZONE_STATE));
+	      src->map_struct->nb_zones * sizeof (lw6ker_zone_state_t));
       dst->cursor_ref_pot = src->cursor_ref_pot;
       dst->last_spread_dir = src->last_spread_dir;
       dst->cursor_array = src->cursor_array;
@@ -98,7 +97,7 @@ _lw6ker_team_copy (LW6KER_TEAM * dst, LW6KER_TEAM * src)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("team_copy only works if dst and src point to the same map_struct"));
     }
@@ -107,7 +106,7 @@ _lw6ker_team_copy (LW6KER_TEAM * dst, LW6KER_TEAM * src)
 }
 
 void
-_lw6ker_team_update_checksum (LW6KER_TEAM * team, LW6SYS_UINT32 * checksum)
+_lw6ker_team_update_checksum (lw6ker_team_t * team, u_int32_t * checksum)
 {
   int i;
 
@@ -123,27 +122,27 @@ _lw6ker_team_update_checksum (LW6KER_TEAM * team, LW6SYS_UINT32 * checksum)
 }
 
 void
-lw6ker_team_activate (LW6KER_TEAM * team,
-		      LW6SYS_INT32 nb_cursors, LW6SYS_XY pos)
+lw6ker_team_activate (lw6ker_team_t * team, int32_t nb_cursors,
+		      lw6sys_xy_t pos)
 {
   team->active = 1;
   _lw6ker_cursor_array_activate (&(team->cursor_array), nb_cursors, pos);
 }
 
 void
-lw6ker_team_unactivate (LW6KER_TEAM * team)
+lw6ker_team_unactivate (lw6ker_team_t * team)
 {
   team->active = 0;
   lw6ker_cursor_array_clear (&(team->cursor_array));
 }
 
 void
-lw6ker_team_apply_cursors (LW6KER_TEAM * team, LW6OPT_STATIC * options)
+lw6ker_team_apply_cursors (lw6ker_team_t * team, lw6map_options_t * options)
 {
-  LW6SYS_INT32 i;
-  LW6SYS_INT32 zone_id;
-  LW6SYS_INT32 max_pot = 0;
-  LW6SYS_INT32 round_delta = options->round_delta;
+  int32_t i;
+  int32_t zone_id;
+  int32_t max_pot = 0;
+  int32_t round_delta = options->round_delta;
 
   /*
    * Wizardry to determine a new cursor_ref_pot. In most cases
@@ -249,7 +248,7 @@ lw6ker_team_apply_cursors (LW6KER_TEAM * team, LW6OPT_STATIC * options)
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+	      lw6sys_log (LW6SYS_LOG_WARNING,
 			  _
 			  ("unable to apply cursor, neither pos (%d,%d) nor last_applied_pos (%d,%d) seem to point on a valid zone"),
 			  team->cursor_array.cursors[i].pos.x,
@@ -261,8 +260,8 @@ lw6ker_team_apply_cursors (LW6KER_TEAM * team, LW6OPT_STATIC * options)
     }
 }
 
-static LW6SYS_INT32
-next_dir (LW6SYS_INT32 dir)
+static int32_t
+next_dir (int32_t dir)
 {
   int ret;
   /*
@@ -289,15 +288,15 @@ next_dir (LW6SYS_INT32 dir)
  * Highest potential = closest to the cursor
  */
 void
-lw6ker_team_spread_gradient (LW6KER_TEAM * team)
+lw6ker_team_spread_gradient (lw6ker_team_t * team)
 {
-  LW6SYS_INT32 i;
-  LW6SYS_INT32 n;
-  LW6SYS_INT32 zone_id;
-  LW6SYS_INT32 new_potential;
-  LW6KER_ZONE_STRUCT *zone_structs;
-  LW6KER_ZONE_STATE *zone_states;
-  LW6SYS_INT32 dir;
+  int32_t i;
+  int32_t n;
+  int32_t zone_id;
+  int32_t new_potential;
+  lw6ker_zone_struct_t *zone_structs;
+  lw6ker_zone_state_t *zone_states;
+  int32_t dir;
 
   n = team->map_struct->nb_zones;
   zone_structs = team->map_struct->zones;
@@ -345,21 +344,21 @@ lw6ker_team_spread_gradient (LW6KER_TEAM * team)
 	}
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to spread gradient, incorrect dir=%d"), dir);
       break;
     }
 }
 
 void
-lw6ker_team_normalize_pot (LW6KER_TEAM * team, LW6OPT_STATIC * options)
+lw6ker_team_normalize_pot (lw6ker_team_t * team, lw6map_options_t * options)
 {
-  LW6SYS_INT32 i;
-  LW6SYS_INT32 n;
-  LW6SYS_UINT32 min_pot = options->max_cursor_pot;
-  LW6SYS_UINT32 max_pot = 0;
-  LW6SYS_UINT32 delta;
-  LW6KER_ZONE_STATE *zone_states = team->gradient;
+  int32_t i;
+  int32_t n;
+  u_int32_t min_pot = options->max_cursor_pot;
+  u_int32_t max_pot = 0;
+  u_int32_t delta;
+  lw6ker_zone_state_t *zone_states = team->gradient;
 
   n = team->map_struct->nb_zones;
   for (i = 0; i < n; ++i)
@@ -391,7 +390,7 @@ lw6ker_team_normalize_pot (LW6KER_TEAM * team, LW6OPT_STATIC * options)
   team->cursor_ref_pot = max_pot - delta;
   if (team->cursor_ref_pot <= 0 || team->cursor_ref_pot > max_pot)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "ker",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("inconsistent cursor_ref_pot=%d (max_pot=%d, delta=%d)"),
 		  team->cursor_ref_pot, max_pot, delta);
       team->cursor_ref_pot = options->cursor_pot_init;
