@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,16 +20,16 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
-
-#include <libpng12/png.h>
+#include <string.h>
 
 #include "config.h"
 #include "map.h"
-#include "map-internal.h"
+
+#define DEFAULT_WIDTH 100
+#define DEFAULT_HEIGHT 75
 
 void
-lw6map_depth_block_up_down (LW6MAP_DEPTH * depth)
+lw6map_depth_block_up_down (lw6map_depth_t * depth)
 {
   int x;
 
@@ -41,7 +41,7 @@ lw6map_depth_block_up_down (LW6MAP_DEPTH * depth)
 }
 
 void
-lw6map_depth_block_left_right (LW6MAP_DEPTH * depth)
+lw6map_depth_block_left_right (lw6map_depth_t * depth)
 {
   int y;
 
@@ -53,72 +53,7 @@ lw6map_depth_block_left_right (LW6MAP_DEPTH * depth)
 }
 
 static int
-read_png (LW6MAP_DEPTH * depth, char *map_dot_png,
-	  LW6OPT_STATIC * static_options)
-{
-  int ret = 0;
-  _LW6MAP_IMAGE_BW image;
-
-  memset (&image, 0, sizeof (_LW6MAP_IMAGE_BW));
-
-  if (_lw6map_bw_read (&image, map_dot_png))
-    {
-      LW6MAP_RESAMPLER resampler;
-      lw6map_resampler_init (&resampler, static_options, &(image.shape));
-
-      depth->shape = resampler.target_shape;
-      depth->data =
-	(unsigned char *) LW6SYS_MALLOC (depth->shape.w * depth->shape.h *
-					 sizeof (unsigned char *));
-
-      if (depth->data)
-	{
-	  int row, col, row2, col2;
-	  unsigned int value;
-
-	  for (row = 0; row < depth->shape.h; ++row)
-	    {
-	      for (col = 0; col < depth->shape.w; ++col)
-		{
-		  lw6map_resampler_target2source (&resampler, &col2, &row2,
-						  col, row);
-
-		  value = image.data[row2][col2 * image.step];
-		  /*
-		   * For now we do not handle depth the full way. There's
-		   * a big TODO here, one could read in another file (say
-		   * an XML file) a parameter that would state "maximum depth
-		   * is 5" and maybe even the various thresholds for the
-		   * different levels. For now using depth 0 or 1 is just like
-		   * in Liquid War 5, we have flat levels, will be fine for
-		   * a some time anyway.
-		   */
-		  value = (value > 127) ? 1 : 0;
-		  lw6map_depth_set (depth, col, row, value);
-		}
-	    }
-
-	  ret = 1;
-	}
-      else
-	{
-	  lw6sys_log (LW6SYS_LOG_ERROR, "map",
-		      _("unable to allocate memory for depth"));
-	}
-
-      _lw6map_bw_clear (&image);
-    }
-
-  if (!ret)
-    {
-      lw6map_depth_clear (depth);
-    }
-
-  return ret;
-}
-
-static int
-find_first_free_point (LW6MAP_DEPTH * depth, int *found_x, int *found_y)
+find_first_free_point (lw6map_depth_t * depth, int *found_x, int *found_y)
 {
   int ret = 0;
   int x, y;
@@ -145,7 +80,7 @@ find_first_free_point (LW6MAP_DEPTH * depth, int *found_x, int *found_y)
  * Updates a depth point if needed, returns true if value was changed
  */
 static int
-update_if_needed (LW6MAP_DEPTH * dst, LW6MAP_DEPTH * src, int x, int y)
+update_if_needed (lw6map_depth_t * dst, lw6map_depth_t * src, int x, int y)
 {
   int ret = 0;
 
@@ -162,11 +97,11 @@ update_if_needed (LW6MAP_DEPTH * dst, LW6MAP_DEPTH * src, int x, int y)
  * Checks the maps for "holes", that is fight zones that wouldn't
  * be connected with the main area, and fills them with walls.
  */
-static int
-check_and_fix_holes (LW6MAP_DEPTH * depth)
+int
+lw6map_depth_check_and_fix_holes (lw6map_depth_t * depth)
 {
   int ret = 0;
-  LW6MAP_DEPTH fixed_depth;
+  lw6map_depth_t fixed_depth;
   int x, y;
 
   fixed_depth.shape.w = depth->shape.w;
@@ -234,58 +169,71 @@ check_and_fix_holes (LW6MAP_DEPTH * depth)
   return ret;
 }
 
-/*
- * Read a depth map. Pointer to depth must be valid,
- * it's modified in-place.
- */
-int
-lw6map_depth_read (LW6MAP_DEPTH * depth, char *dirname,
-		   LW6OPT_STATIC * static_options)
+static int
+rectangle (lw6map_depth_t * depth, int width, int height)
 {
   int ret = 0;
-  char *map_dot_png;
+  int x, y;
 
-  lw6map_depth_clear (depth);
+  depth->shape.w = width;
+  depth->shape.h = height;
+  depth->data =
+    (unsigned char *) LW6SYS_CALLOC (depth->shape.w * depth->shape.h *
+				     sizeof (unsigned char *));
 
-  map_dot_png = lw6sys_str_concat (dirname, LW6MAP_FILE_MAP_PNG);
-  if (map_dot_png)
+  if (depth->data)
     {
-      ret = read_png (depth, map_dot_png, static_options);
-      if (ret)
+      for (y = 0; y < depth->shape.h; ++y)
 	{
-	  if (static_options->x_polarity == 0)
+	  for (x = 0; x < depth->shape.w; ++x)
 	    {
-	      lw6map_depth_block_left_right (depth);
+	      lw6map_depth_set (depth, x, y, 0);
 	    }
-	  if (static_options->y_polarity == 0)
-	    {
-	      lw6map_depth_block_up_down (depth);
-	    }
-	  ret = check_and_fix_holes (depth);
 	}
 
-      LW6SYS_FREE (map_dot_png);
+      for (y = 1; y < depth->shape.h - 1; ++y)
+	{
+	  for (x = 1; x < depth->shape.w - 1; ++x)
+	    {
+	      lw6map_depth_set (depth, x, y, 1);
+	    }
+	}
+      ret = 1;
     }
 
   return ret;
 }
 
+void
+lw6map_depth_defaults (lw6map_depth_t * depth)
+{
+  lw6map_depth_clear (depth);
+
+  if (!rectangle (depth, DEFAULT_WIDTH, DEFAULT_HEIGHT))
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to construct default map depth"));
+      depth->shape.w = 0;
+      depth->shape.h = 0;
+    }
+}
+
 /*
  * Clears a depth map.
  */
 void
-lw6map_depth_clear (LW6MAP_DEPTH * depth)
+lw6map_depth_clear (lw6map_depth_t * depth)
 {
   if (depth->data)
     {
       LW6SYS_FREE (depth->data);
     }
 
-  memset (depth, 0, sizeof (LW6MAP_DEPTH));
+  memset (depth, 0, sizeof (lw6map_depth_t));
 }
 
 void
-lw6map_depth_fill (LW6MAP_DEPTH * depth, unsigned char value)
+lw6map_depth_fill (lw6map_depth_t * depth, unsigned char value)
 {
   int x, y;
 
@@ -297,3 +245,47 @@ lw6map_depth_fill (LW6MAP_DEPTH * depth, unsigned char value)
 	}
     }
 }
+
+int
+lw6map_depth_coord_from_texture (lw6map_level_t * level, int *depth_x,
+				 int *depth_y, int texture_x, int texture_y)
+{
+  int ret = 0;
+
+  if (level->texture.shape.w > 0 && level->texture.shape.h > 0)
+    {
+      (*depth_x) =
+	(texture_x * level->depth.shape.w) / level->texture.shape.w;
+      (*depth_y) =
+	(texture_y * level->depth.shape.h) / level->texture.shape.h;
+      (*depth_x) =
+	lw6sys_max (0, lw6sys_min (level->depth.shape.w - 1, *depth_x));
+      (*depth_y) =
+	lw6sys_max (0, lw6sys_min (level->depth.shape.h - 1, *depth_y));
+      ret = 1;
+    }
+  else
+    {
+      (*depth_x) = 0;
+      (*depth_y) = 0;
+    }
+
+  return ret;
+}
+
+unsigned char
+lw6map_depth_get_with_texture_coord (lw6map_level_t * level, int texture_x,
+				     int texture_y)
+{
+  unsigned char ret = 0;
+  int depth_x;
+  int depth_y;
+
+  if (lw6map_depth_coord_from_texture
+      (level, &depth_x, &depth_y, texture_x, texture_y))
+    {
+      ret = lw6map_depth_get (&level->depth, depth_x, depth_y);
+    }
+
+  return ret;
+}
