@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,36 +21,47 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
-
 #include "config.h"
 #include "../snd.h"
 #include "mod-csound-internal.h"
 
-_CSOUND_CONTEXT *
-_mod_csound_init (float sound_volume, float music_volume)
+_mod_csound_context_t *
+_mod_csound_init (int argc, char *argv[], float sound_volume,
+		  float music_volume)
 {
-  _CSOUND_CONTEXT *snd_context = NULL;
+  _mod_csound_context_t *csound_context = NULL;
+  int ok = 0;
 
-  snd_context = (_CSOUND_CONTEXT *) LW6SYS_CALLOC (sizeof (_CSOUND_CONTEXT));
-  if (!snd_context)
-    {
-      /*
-       * No use to continue if this basic malloc fails...
-       */
-      exit (1);
-    }
-
-  lw6sys_log (LW6SYS_LOG_INFO, "snd-mod-csound",
+  lw6sys_log (LW6SYS_LOG_INFO,
 	      _("csound init volume=%01.2f/%01.2f"), sound_volume,
 	      music_volume);
 
-  return snd_context;
+  csound_context =
+    (_mod_csound_context_t *) LW6SYS_CALLOC (sizeof (_mod_csound_context_t));
+  if (csound_context)
+    {
+      if (_mod_csound_path_init (csound_context, argc, argv))
+	{
+	  _mod_csound_set_sound_volume (csound_context, sound_volume);
+	  _mod_csound_set_music_volume (csound_context, music_volume);
+
+	  ok = 1;
+	}
+    }
+
+  if (!ok)
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to init csound module"));
+      _mod_csound_quit (csound_context);
+    }
+
+  return csound_context;
 }
 
 void
-_mod_csound_quit (_CSOUND_CONTEXT * snd_context)
+_mod_csound_quit (_mod_csound_context_t * csound_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, "snd-mod-csound", _("csound quit"));
-  LW6SYS_FREE (snd_context);
+  lw6sys_log (LW6SYS_LOG_INFO, _("csound quit"));
+  _mod_csound_path_quit (csound_context);
+  LW6SYS_FREE (csound_context);
 }
