@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,7 +26,7 @@
 #include "mod-csound-internal.h"
 
 extern int
-_mod_csound_play_sound (_CSOUND_CONTEXT * snd_context, int sound_id)
+_mod_csound_play_sound (_mod_csound_context_t * csound_context, int sound_id)
 {
   int ret = 0;
 
