@@ -1,7 +1,7 @@
 
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,22 +22,20 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-#include <locale.h>
 
 #include "config.h"
 #include "../../cfg/cfg.h"
 #include "mod-ogg-internal.h"
 
-#define CONST_FILE "snd/ogg/const.xml"
+#define CONST_FILE "ogg-const.xml"
 
 static void
 read_callback (void *callback_data, char *element, char *key, char *value)
 {
-  _MOD_OGG_CONST_DATA *const_data;
+  _mod_ogg_const_data_t *const_data;
 
-  const_data = (_MOD_OGG_CONST_DATA *) callback_data;
+  const_data = (_mod_ogg_const_data_t *) callback_data;
 
   if (!strcmp (element, "int"))
     {
@@ -56,12 +54,12 @@ read_callback (void *callback_data, char *element, char *key, char *value)
  * Loads constants.
  */
 int
-_mod_ogg_load_consts (_MOD_OGG_CONTEXT * context)
+_mod_ogg_load_consts (_mod_ogg_context_t * context)
 {
   int ret = 0;
   char *const_file = NULL;
 
-  const_file = lw6sys_find_data_file (CONST_FILE);
+  const_file = lw6sys_path_concat (context->path.data_dir, CONST_FILE);
 
   if (const_file)
     {
@@ -82,7 +80,7 @@ _mod_ogg_load_consts (_MOD_OGG_CONTEXT * context)
  * Unload constants, free memory
  */
 void
-_mod_ogg_unload_consts (_MOD_OGG_CONTEXT * context)
+_mod_ogg_unload_consts (_mod_ogg_context_t * context)
 {
-  memset (&context->const_data, 0, sizeof (_MOD_OGG_CONST_DATA));
+  memset (&context->const_data, 0, sizeof (_mod_ogg_const_data_t));
 }
