@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,14 +22,18 @@
 */
 
 #include "config.h"
-#include "lw6-config.h"
 #include "../snd.h"
 #include "mod-ogg-internal.h"
 
-#define SOUND_FILE_MASK "snd/ogg/sound/%s.ogg"
+#define SOUND_FILE_MASK "sound/%s.ogg"
+
+#define SOUND_SPLASH_FILE      "splash"
+#define SOUND_BEEP_VALID_FILE  "beep-valid"
+#define SOUND_BEEP_SELECT_FILE "beep-select"
+#define SOUND_START_FILE       "start"
 
 int
-_mod_ogg_play_sound (_MOD_OGG_CONTEXT * snd_context, int sound_id)
+_mod_ogg_play_sound (_mod_ogg_context_t * snd_context, int sound_id)
 {
   int ret = 0;
 
@@ -57,7 +62,7 @@ _mod_ogg_play_sound (_MOD_OGG_CONTEXT * snd_context, int sound_id)
 }
 
 static Mix_Chunk *
-load_sound (char *key)
+load_sound (_mod_ogg_context_t * ogg_context, char *key)
 {
   char *path1 = NULL;
   char *path2 = NULL;
@@ -67,7 +72,7 @@ load_sound (char *key)
 
   if (path1)
     {
-      path2 = lw6sys_find_data_file (path1);
+      path2 = lw6sys_path_concat (ogg_context->path.data_dir, path1);
       if (path2)
 	{
 	  lw6sys_log (LW6SYS_LOG_INFO, "snd-mod-ogg", "loading sound \"%s\"",
@@ -82,30 +87,43 @@ load_sound (char *key)
 }
 
 int
-_mod_ogg_load_sounds (_MOD_OGG_CONTEXT * context)
+_mod_ogg_load_sounds (_mod_ogg_context_t * ogg_context)
 {
   int ret = 0;
+  int i;
 
-  context->sounds.sounds[LW6SND_SOUND_SPLASH] = load_sound ("splash");
-  context->sounds.sounds[LW6SND_SOUND_BEEP_ENTER] = load_sound ("beep-enter");
-  context->sounds.sounds[LW6SND_SOUND_BEEP_SELECT] =
-    load_sound ("beep-select");
-  context->sounds.sounds[LW6SND_SOUND_START] = load_sound ("start");
+  ogg_context->sounds.sounds[LW6SND_SOUND_SPLASH] =
+    load_sound (ogg_context, SOUND_SPLASH_FILE);
+  ogg_context->sounds.sounds[LW6SND_SOUND_BEEP_VALID] =
+    load_sound (ogg_context, SOUND_BEEP_VALID_FILE);
+  ogg_context->sounds.sounds[LW6SND_SOUND_BEEP_SELECT] =
+    load_sound (ogg_context, SOUND_BEEP_SELECT_FILE);
+  ogg_context->sounds.sounds[LW6SND_SOUND_START] =
+    load_sound (ogg_context, SOUND_START_FILE);
+
+  ret = 1;
+  for (i = 0; i < LW6SND_NB_SOUNDS; ++i)
+    {
+      if (!ogg_context->sounds.sounds[i])
+	{
+	  ret = 0;
+	}
+    }
 
   return ret;
 }
 
 void
-_mod_ogg_unload_sounds (_MOD_OGG_CONTEXT * context)
+_mod_ogg_unload_sounds (_mod_ogg_context_t * ogg_context)
 {
   int i;
 
   for (i = 0; i < LW6SND_NB_SOUNDS; ++i)
     {
-      if (context->sounds.sounds[i])
+      if (ogg_context->sounds.sounds[i])
 	{
-	  Mix_FreeChunk (context->sounds.sounds[i]);
+	  Mix_FreeChunk (ogg_context->sounds.sounds[i]);
 	}
-      context->sounds.sounds[i] = NULL;
+      ogg_context->sounds.sounds[i] = NULL;
     }
 }
