@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,13 +26,17 @@
 #include "mod-ogg-internal.h"
 
 extern void
-_mod_ogg_set_sound_volume (_MOD_OGG_CONTEXT * snd_context, float volume)
+_mod_ogg_set_sound_volume (_mod_ogg_context_t * ogg_context, float volume)
 {
+  ogg_context->volume.sound = volume;
+
   // todo...
 }
 
 extern void
-_mod_ogg_set_music_volume (_MOD_OGG_CONTEXT * snd_context, float volume)
+_mod_ogg_set_music_volume (_mod_ogg_context_t * ogg_context, float volume)
 {
+  ogg_context->volume.music = volume;
+
   // todo...
 }
