@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,20 +21,18 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
-
 #include "config.h"
 #include "snd.h"
 
 static void
 warning (char *func_name)
 {
-  lw6sys_log (LW6SYS_LOG_WARNING, "snd",
+  lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("snd backend function \"%s\" is not defined"), func_name);
 }
 
 int
-lw6snd_play_sound (LW6SND_BACKEND * backend, int sound_id)
+lw6snd_play_sound (lw6snd_backend_t * backend, int sound_id)
 {
   int ret = 0;
 
@@ -50,7 +49,7 @@ lw6snd_play_sound (LW6SND_BACKEND * backend, int sound_id)
 }
 
 int
-lw6snd_play_music (LW6SND_BACKEND * backend, char *music_name)
+lw6snd_play_music (lw6snd_backend_t * backend, char *music_name)
 {
   int ret = 0;
 
@@ -67,11 +66,14 @@ lw6snd_play_music (LW6SND_BACKEND * backend, char *music_name)
 }
 
 int
-lw6snd_init (LW6SND_BACKEND * backend, float sound_volume, float music_volume)
+lw6snd_init (lw6snd_backend_t * backend, float sound_volume,
+	     float music_volume)
 {
   if (backend->init)
     {
-      backend->snd_context = backend->init (sound_volume, music_volume);
+      backend->snd_context =
+	backend->init (backend->argc, backend->argv, sound_volume,
+		       music_volume);
     }
   else
     {
@@ -82,7 +84,7 @@ lw6snd_init (LW6SND_BACKEND * backend, float sound_volume, float music_volume)
 }
 
 void
-lw6snd_set_sound_volume (LW6SND_BACKEND * backend, float volume)
+lw6snd_set_sound_volume (lw6snd_backend_t * backend, float volume)
 {
   if (backend->set_sound_volume)
     {
@@ -95,7 +97,7 @@ lw6snd_set_sound_volume (LW6SND_BACKEND * backend, float volume)
 }
 
 void
-lw6snd_set_music_volume (LW6SND_BACKEND * backend, float volume)
+lw6snd_set_music_volume (lw6snd_backend_t * backend, float volume)
 {
   if (backend->set_music_volume)
     {
@@ -108,7 +110,7 @@ lw6snd_set_music_volume (LW6SND_BACKEND * backend, float volume)
 }
 
 void
-lw6snd_quit (LW6SND_BACKEND * backend)
+lw6snd_quit (lw6snd_backend_t * backend)
 {
   if (backend->quit)
     {
