@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,22 +26,22 @@
 #include "config.h"
 #include "snd.h"
 
-LW6SYS_ASSOC *
-lw6snd_get_backends ()
+lw6sys_assoc_t *
+lw6snd_get_backends (int argc, char *argv[])
 {
-  LW6SYS_ASSOC *ret = NULL;
+  lw6sys_assoc_t *ret = NULL;
   char *path;
 
   ret = lw6sys_assoc_new (NULL);
   if (ret)
     {
-      path = lw6dyn_path_find_backend ("snd", "ogg");
+      path = lw6dyn_path_find_backend (argc, argv, "snd", "ogg");
       if (path)
 	{
 	  lw6sys_assoc_set (&ret, "ogg", (void *) _("Ogg Vorbis"));
 	  LW6SYS_FREE (path);
 	}
-      path = lw6dyn_path_find_backend ("snd", "csound");
+      path = lw6dyn_path_find_backend (argc, argv, "snd", "csound");
       if (path)
 	{
 	  lw6sys_assoc_set (&ret, "csound", (void *) _("Csound"));
@@ -51,18 +52,18 @@ lw6snd_get_backends ()
   return ret;
 }
 
-LW6SND_BACKEND *
-lw6snd_create_backend (char *name)
+lw6snd_backend_t *
+lw6snd_create_backend (int argc, char *argv[], char *name)
 {
-  LW6SND_BACKEND *backend = NULL;
-  LW6DYN_DL_HANDLE *backend_handle = NULL;
+  lw6snd_backend_t *backend = NULL;
+  lw6dyn_dl_handle_t *backend_handle = NULL;
 
-  backend_handle = lw6dyn_dlopen_backend ("snd", name);
+  backend_handle = lw6dyn_dlopen_backend (argc, argv, "snd", name);
 
   if (backend_handle)
     {
       char *init_func_name;
-      LW6SND_BACKEND *(*init_func) ();
+      lw6snd_backend_t *(*init_func) ();
 
       init_func_name = lw6sys_new_sprintf ("mod_%s_create_backend", name);
       if (init_func_name)
@@ -74,7 +75,7 @@ lw6snd_create_backend (char *name)
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, "snd",
+	      lw6sys_log (LW6SYS_LOG_WARNING,
 			  _
 			  ("unable to find function \"%s\" in sound backend \"%s\""),
 			  init_func_name, name);
@@ -88,10 +89,12 @@ lw6snd_create_backend (char *name)
   if (backend && backend_handle)
     {
       backend->dl_handle = backend_handle;
+      backend->argc = argc;
+      backend->argv = argv;
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "snd",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to open sound backend \"%s\""), name);
     }
 
@@ -99,7 +102,7 @@ lw6snd_create_backend (char *name)
 }
 
 void
-lw6snd_destroy_backend (LW6SND_BACKEND * backend)
+lw6snd_destroy_backend (lw6snd_backend_t * backend)
 {
   lw6dyn_dlclose_backend (backend->dl_handle);
   LW6SYS_FREE (backend);
