@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,13 +21,31 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
 #include "config.h"
 #include "sys.h"
 
+int
+lw6sys_clear_file (char *filename)
+{
+  int ret = 0;
+  FILE *f = NULL;
+
+  f = fopen (filename, "w");
+  if (f)
+    {
+      ret = 1;
+    }
+  else
+    {
+      // unwise to log something here, call be called from log_...
+    }
+
+  return ret;
+}
+
 /*
  * Read all the contents of a file, put it in a dynamically
  * allocated string. You need to free the pointer afterwards.
@@ -57,7 +76,7 @@ lw6sys_read_file_content (char *filename)
 		}
 	      if (read != size)
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING, "sys",
+		  lw6sys_log (LW6SYS_LOG_WARNING,
 			      _
 			      ("couldn't read all of file \"%s\", size was supposed to be %d but only read %d"),
 			      filename, size, read);
@@ -68,9 +87,39 @@ lw6sys_read_file_content (char *filename)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "sys",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("can't open file \"%s\" for reading"), filename);
     }
 
   return file_content;
 }
+
+int
+lw6sys_write_file_content (char *filename, char *content)
+{
+  FILE *f = NULL;
+  int ret = 0;
+
+  f = fopen (filename, "w");
+  if (f)
+    {
+      if (strlen (content) == fprintf (f, "%s", content))
+	{
+	  ret = 1;
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("unable to write %d bytes in file \"%s\""),
+		      strlen (content), filename);
+	}
+      fclose (f);
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable open file \"%s\" for reading"), filename);
+    }
+
+  return ret;
+}
