@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,10 +21,8 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdlib.h>
 #include <string.h>
 #include <iconv.h>
-#include <locale.h>
 #include <langinfo.h>
 
 #include "config.h"
@@ -80,7 +79,7 @@ lw6sys_locale_to_utf8 (char *string)
 
 	      if (iconv (cd, &iptr, &ileft, &optr, &oleft) == (size_t) - 1)
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING, "sys", "iconv error \"%s\"",
+		  lw6sys_log (LW6SYS_LOG_WARNING, "iconv error \"%s\"",
 			      string);
 		}
 	    }
@@ -88,7 +87,7 @@ lw6sys_locale_to_utf8 (char *string)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "sys", "unable to open iconv");
+	  lw6sys_log (LW6SYS_LOG_WARNING, "unable to open iconv");
 	}
     }
 
@@ -105,8 +104,7 @@ lw6sys_locale_to_utf8 (char *string)
 
   if (utf8 == NULL)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "sys",
-		  "unable to translate string to utf8");
+      lw6sys_log (LW6SYS_LOG_WARNING, "unable to translate string to utf8");
     }
 
   return utf8;
