@@ -1,6 +1,7 @@
+
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -21,6 +22,7 @@
 */
 
 #include <time.h>
+#include <sys/select.h>
 
 #include "config.h"
 #include "sys.h"
@@ -28,7 +30,7 @@
 /*
  * Simple wrapper on time function.
  */
-long long
+int64_t
 lw6sys_timestamp ()
 {
   return time (NULL);
